@@ -13,8 +13,8 @@ from __future__ import print_function
 import os, sys, time, shutil
 
 # Check python version
-if not hasattr(sys, 'version_info') or sys.version_info < (2,6):
-  sys.exit('ERROR: Python version 2.6 or higher is required')
+if not hasattr(sys, 'version_info') or sys.version_info < (2,7):
+  sys.exit('ERROR: Python version 2.7 or higher is required')
 
 def WriteModulesFile(modules,version,sdir):
   ''' Write the contents of the Modules file '''
@@ -88,7 +88,7 @@ import slepc, petsc
 slepc = slepc.SLEPc(argdb,log)
 petsc = petsc.PETSc(argdb,log)
 
-# Check enviroment and PETSc version
+# Check environment and PETSc version
 if not showhelp:
   log.Print('Checking environment...')
   petsc.InitDir(slepc.prefixdir)
@@ -104,10 +104,9 @@ else:
   packagesinpetsc = ''
 
 # Load classes for packages and process their command-line options
-import arpack, blopex, blzpack, elemental, elpa, evsl, feast, hpddm, primme, scalapack, slepc4py, slicot, trlan, sowing, lapack
+import arpack, blopex, elemental, elpa, evsl, feast, hpddm, primme, scalapack, slepc4py, slicot, trlan, sowing, lapack
 arpack    = arpack.Arpack(argdb,log)
 blopex    = blopex.Blopex(argdb,log)
-blzpack   = blzpack.Blzpack(argdb,log)
 elemental = elemental.Elemental(argdb,log,packagesinpetsc)
 elpa      = elpa.Elpa(argdb,log)
 evsl      = evsl.Evsl(argdb,log)
@@ -121,7 +120,7 @@ slepc4py  = slepc4py.Slepc4py(argdb,log)
 slicot    = slicot.Slicot(argdb,log)
 hpddm     = hpddm.HPDDM(argdb,log)
 
-externalpackages = [arpack, blopex, blzpack, elpa, evsl, hpddm, primme, slicot, trlan]
+externalpackages = [arpack, blopex, elpa, evsl, hpddm, primme, slicot, trlan]
 petscpackages    = [lapack, elemental, feast, scalapack]
 specialpackages  = [slepc, petsc, slepc4py, sowing]
 checkpackages    = specialpackages + petscpackages + externalpackages
@@ -218,7 +217,10 @@ with slepc.CreateFile(confdir,'slepcvariables') as slepcvars:
     with slepc.CreateFile(includedir,'slepcconf.h') as slepcconf:
       for pkg in checkpackages:
         pkg.Process(slepcconf,slepcvars,slepcrules,slepc,petsc,archdir)
-      slepcconf.write('\n#endif\n')
+      slepcconf.write('#define SLEPC_HAVE_PACKAGES ":')
+      for pkg in petscpackages + externalpackages:
+        if hasattr(pkg,'havepackage') and pkg.havepackage: slepcconf.write(pkg.packagename+':')
+      slepcconf.write('"\n#endif\n')
 
 log.NewSection('Writing various configuration files...')
 
