@@ -16,7 +16,7 @@ try:
 except ImportError:
   from urllib.request import urlretrieve
 try:
-  import urlparse as urlparse_local
+  import urlparse as urlparse_local # novermin
 except ImportError:
   from urllib import parse as urlparse_local
 if sys.version_info < (3,):
@@ -78,6 +78,8 @@ class Package:
         self.packagedir = string
       string,found = argdb.PopString('with-'+self.packagename+'-lib')
       if found:
+        if self.packagedir:
+          self.log.Exit('Specify either "--with-'+self.packagename+'-dir" or "--with-'+self.packagename+'-lib%s", but not both!' % (' --with-'+self.packagename+'-include' if self.hasheaders else ''))
         self.requested = True
         self.packagelibs = string.split(',')
       if self.hasheaders:
@@ -279,7 +281,7 @@ Downloaded package %s from: %s is not a tarball.
 
   def ShowInfo(self):
     if self.havepackage:
-      if hasattr(self,'version'):
+      if hasattr(self,'version') and self.downloadpackage:
         packagename = self.packagename.upper()+' version '+self.version
       else:
         packagename = self.packagename.upper()
