@@ -73,7 +73,7 @@ class SLEPc(package.Package):
     if 'SLEPC_DIR' in os.environ:
       self.dir = os.path.normpath(os.environ['SLEPC_DIR'])
       if not os.path.exists(self.dir) or not os.path.exists(os.path.join(self.dir,'config')):
-        self.log.Exit('SLEPC_DIR enviroment variable is not valid')
+        self.log.Exit('SLEPC_DIR environment variable is not valid')
       if os.path.realpath(os.getcwd()) != os.path.realpath(self.dir):
         self.log.Exit('SLEPC_DIR is not the current directory')
     else:
@@ -107,18 +107,25 @@ class SLEPc(package.Package):
     self.isrepo = False
     if os.path.exists(os.path.join(self.dir,'src','docs')):
       self.isrepo = True
-      (status, output) = self.RunCommand('git rev-parse')
+      (status, output) = self.RunCommand('git help')
       if status:
         self.log.Warn('SLEPC_DIR appears to be a git working copy, but git is not found in PATH')
         self.gitrev = 'N/A'
         self.gitdate = 'N/A'
         self.branch = 'N/A'
       else:
-        (status, self.gitrev) = self.RunCommand('git describe')
-        if not self.gitrev:
-          (status, self.gitrev) = self.RunCommand('git log -1 --pretty=format:%H')
-        (status, self.gitdate) = self.RunCommand('git log -1 --pretty=format:%ci')
-        (status, self.branch) = self.RunCommand('git describe --contains --all HEAD')
+        (status, output) = self.RunCommand('git rev-parse')
+        if status:
+          self.log.Warn('SLEPC_DIR appears to be a git working copy, but the .git folder is missing')
+          self.gitrev = 'N/A'
+          self.gitdate = 'N/A'
+          self.branch = 'N/A'
+        else:
+          (status, self.gitrev) = self.RunCommand('git describe')
+          if not self.gitrev:
+            (status, self.gitrev) = self.RunCommand('git log -1 --pretty=format:%H')
+          (status, self.gitdate) = self.RunCommand('git log -1 --pretty=format:%ci')
+          (status, self.branch) = self.RunCommand('git describe --contains --all HEAD')
 
   def CreateFile(self,basedir,fname):
     ''' Create file basedir/fname and return path string '''
