@@ -14,6 +14,7 @@
 
 #include "petsc/finclude/petscmat.h"
 #include "slepc/finclude/slepcfn.h"
+#include "slepc/finclude/slepcrg.h"
 
 #define DS type(tDS)
 
@@ -29,6 +30,7 @@
 #define DSGNHEP     'gnhep'
 #define DSNHEPTS    'nhepts'
 #define DSSVD       'svd'
+#define DSGSVD      'gsvd'
 #define DSPEP       'pep'
 #define DSNEP       'nep'
 
