@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -23,12 +23,14 @@ typedef struct _DSOps *DSOps;
 
 struct _DSOps {
   PetscErrorCode (*allocate)(DS,PetscInt);
+  PetscErrorCode (*setfromoptions)(PetscOptionItems*,DS);
   PetscErrorCode (*view)(DS,PetscViewer);
   PetscErrorCode (*vectors)(DS,DSMatType,PetscInt*,PetscReal*);
   PetscErrorCode (*solve[DS_MAX_SOLVE])(DS,PetscScalar*,PetscScalar*);
   PetscErrorCode (*sort)(DS,PetscScalar*,PetscScalar*,PetscScalar*,PetscScalar*,PetscInt*);
   PetscErrorCode (*sortperm)(DS,PetscInt*,PetscScalar*,PetscScalar*);
-  PetscErrorCode (*truncate)(DS,PetscInt);
+  PetscErrorCode (*gettruncatesize)(DS,PetscInt,PetscInt,PetscInt*);
+  PetscErrorCode (*truncate)(DS,PetscInt,PetscBool);
   PetscErrorCode (*update)(DS);
   PetscErrorCode (*cond)(DS,PetscReal*);
   PetscErrorCode (*transharm)(DS,PetscScalar,PetscReal,PetscBool,PetscScalar*,PetscReal*);
@@ -50,12 +52,11 @@ struct _p_DS {
   PetscInt       ld;                 /* leading dimension */
   PetscInt       l;                  /* number of locked (inactive) leading columns */
   PetscInt       n;                  /* current dimension */
-  PetscInt       m;                  /* current column dimension (for SVD only) */
   PetscInt       k;                  /* intermediate dimension (e.g. position of arrow) */
   PetscInt       t;                  /* length of decomposition when it was truncated */
   PetscInt       bs;                 /* block size */
   SlepcSC        sc;                 /* sorting criterion */
-  DSParallelType pmode;              /* parallel mode (redundant or synchronized) */
+  DSParallelType pmode;              /* parallel mode (redundant, synchronized, distributed) */
 
   /*----------------- Status variables and working data ----------------*/
   PetscScalar    *mat[DS_NUM_MAT];   /* the matrices */
@@ -75,10 +76,10 @@ struct _p_DS {
 */
 #if !defined(PETSC_USE_DEBUG)
 
-#define DSCheckAlloc(h,arg) do {} while (0)
-#define DSCheckSolved(h,arg) do {} while (0)
-#define DSCheckValidMat(ds,m,arg) do {} while (0)
-#define DSCheckValidMatReal(ds,m,arg) do {} while (0)
+#define DSCheckAlloc(h,arg) do {(void)(h);} while (0)
+#define DSCheckSolved(h,arg) do {(void)(h);} while (0)
+#define DSCheckValidMat(ds,m,arg) do {(void)(ds);} while (0)
+#define DSCheckValidMatReal(ds,m,arg) do {(void)(ds);} while (0)
 
 #else
 
@@ -112,10 +113,12 @@ PETSC_STATIC_INLINE PetscErrorCode DSAllocateMatReal_Private(DS ds,DSMatType m)
 SLEPC_INTERN PetscErrorCode DSAllocateWork_Private(DS,PetscInt,PetscInt,PetscInt);
 SLEPC_INTERN PetscErrorCode DSSortEigenvalues_Private(DS,PetscScalar*,PetscScalar*,PetscInt*,PetscBool);
 SLEPC_INTERN PetscErrorCode DSSortEigenvaluesReal_Private(DS,PetscReal*,PetscInt*);
-SLEPC_INTERN PetscErrorCode DSPermuteColumns_Private(DS,PetscInt,PetscInt,DSMatType,PetscInt*);
-SLEPC_INTERN PetscErrorCode DSPermuteRows_Private(DS,PetscInt,PetscInt,DSMatType,PetscInt*);
-SLEPC_INTERN PetscErrorCode DSPermuteBoth_Private(DS,PetscInt,PetscInt,DSMatType,DSMatType,PetscInt*);
+SLEPC_INTERN PetscErrorCode DSPermuteColumns_Private(DS,PetscInt,PetscInt,PetscInt,DSMatType,PetscInt*);
+SLEPC_INTERN PetscErrorCode DSPermuteColumnsTwo_Private(DS,PetscInt,PetscInt,PetscInt,DSMatType,DSMatType,PetscInt*);
+SLEPC_INTERN PetscErrorCode DSPermuteRows_Private(DS,PetscInt,PetscInt,PetscInt,DSMatType,PetscInt*);
+SLEPC_INTERN PetscErrorCode DSPermuteBoth_Private(DS,PetscInt,PetscInt,PetscInt,PetscInt,DSMatType,DSMatType,PetscInt*);
 SLEPC_INTERN PetscErrorCode DSCopyMatrix_Private(DS,DSMatType,DSMatType);
+SLEPC_INTERN PetscErrorCode DSGetTruncateSize_Default(DS,PetscInt,PetscInt,PetscInt*);
 
 SLEPC_INTERN PetscErrorCode DSGHIEPOrthogEigenv(DS,DSMatType,PetscScalar*,PetscScalar*,PetscBool);
 SLEPC_INTERN PetscErrorCode DSGHIEPComplexEigs(DS,PetscInt,PetscInt,PetscScalar*,PetscScalar*);
@@ -125,6 +128,10 @@ SLEPC_INTERN PetscErrorCode DSSwitchFormat_GHIEP(DS,PetscBool);
 SLEPC_INTERN PetscErrorCode DSGHIEPRealBlocks(DS);
 SLEPC_INTERN PetscErrorCode DSSolve_GHIEP_HZ(DS,PetscScalar*,PetscScalar*);
 
+SLEPC_INTERN PetscErrorCode DSSolve_NHEP_Private(DS,PetscScalar*,PetscScalar*,PetscScalar*,PetscScalar*);
+SLEPC_INTERN PetscErrorCode DSSort_NHEP_Total(DS,PetscScalar*,PetscScalar*,PetscScalar*,PetscScalar*);
+SLEPC_INTERN PetscErrorCode DSSortWithPermutation_NHEP_Private(DS,PetscInt*,PetscScalar*,PetscScalar*,PetscScalar*,PetscScalar*);
+
 SLEPC_INTERN PetscErrorCode BDC_dibtdc_(const char*,PetscBLASInt,PetscBLASInt,PetscBLASInt*,PetscReal*,PetscBLASInt,PetscBLASInt,PetscReal*,PetscBLASInt*,PetscBLASInt,PetscBLASInt,PetscReal,PetscReal*,PetscReal*,PetscBLASInt,PetscReal*,PetscBLASInt,PetscBLASInt*,PetscBLASInt,PetscBLASInt*,PetscBLASInt);
 SLEPC_INTERN PetscErrorCode BDC_dlaed3m_(const char*,const char*,PetscBLASInt,PetscBLASInt,PetscBLASInt,PetscReal*,PetscReal*,PetscBLASInt,PetscReal,PetscReal*,PetscReal*,PetscBLASInt*,PetscBLASInt*,PetscReal*,PetscReal*,PetscBLASInt*,PetscBLASInt,PetscBLASInt);
 SLEPC_INTERN PetscErrorCode BDC_dmerg2_(const char*,PetscBLASInt,PetscBLASInt,PetscReal*,PetscReal*,PetscBLASInt,PetscBLASInt*,PetscReal*,PetscReal*,PetscBLASInt,PetscReal*,PetscBLASInt,PetscBLASInt,PetscReal*,PetscBLASInt,PetscBLASInt*,PetscReal,PetscBLASInt*,PetscBLASInt);
