@@ -18,7 +18,7 @@ SLEPC_EXTERN PetscBool NEPRegisterAllCalled;
 SLEPC_EXTERN PetscBool NEPMonitorRegisterAllCalled;
 SLEPC_EXTERN PetscErrorCode NEPRegisterAll(void);
 SLEPC_EXTERN PetscErrorCode NEPMonitorRegisterAll(void);
-SLEPC_EXTERN PetscLogEvent NEP_SetUp,NEP_Solve,NEP_Refine,NEP_FunctionEval,NEP_JacobianEval,NEP_Resolvent;
+SLEPC_EXTERN PetscLogEvent NEP_SetUp,NEP_Solve,NEP_Refine,NEP_FunctionEval,NEP_JacobianEval,NEP_Resolvent,NEP_CISS_SVD;
 
 typedef struct _NEPOps *NEPOps;
 
