@@ -15,6 +15,7 @@
 #define SLEPCDS_H
 #include <slepcsc.h>
 #include <slepcfn.h>
+#include <slepcrg.h>
 
 #define DS_MAX_SOLVE 6
 
@@ -46,6 +47,7 @@ typedef const char* DSType;
 #define DSGNHEP  "gnhep"
 #define DSNHEPTS "nhepts"
 #define DSSVD    "svd"
+#define DSGSVD   "gsvd"
 #define DSPEP    "pep"
 #define DSNEP    "nep"
 
@@ -80,7 +82,7 @@ SLEPC_EXTERN const char *DSStateTypes[];
 .   DS_MAT_X  - right eigenvectors
 .   DS_MAT_Y  - left eigenvectors
 .   DS_MAT_U  - left singular vectors
-.   DS_MAT_VT - right singular vectors
+.   DS_MAT_V  - right singular vectors
 .   DS_MAT_W  - workspace matrix
 -   DS_MAT_Ex - extra matrices (x=0,..,9)
 
@@ -105,7 +107,7 @@ typedef enum { DS_MAT_A,
                DS_MAT_X,
                DS_MAT_Y,
                DS_MAT_U,
-               DS_MAT_VT,
+               DS_MAT_V,
                DS_MAT_W,
                DS_MAT_E0,
                DS_MAT_E1,
@@ -131,7 +133,8 @@ SLEPC_EXTERN DSMatType DSMatExtra[];
 .seealso: DSSetParallel()
 E*/
 typedef enum { DS_PARALLEL_REDUNDANT,
-               DS_PARALLEL_SYNCHRONIZED } DSParallelType;
+               DS_PARALLEL_SYNCHRONIZED,
+               DS_PARALLEL_DISTRIBUTED } DSParallelType;
 SLEPC_EXTERN const char *DSParallelTypes[];
 
 SLEPC_EXTERN PetscErrorCode DSCreate(MPI_Comm,DS*);
@@ -152,8 +155,8 @@ SLEPC_EXTERN PetscErrorCode DSAllocate(DS,PetscInt);
 SLEPC_EXTERN PetscErrorCode DSGetLeadingDimension(DS,PetscInt*);
 SLEPC_EXTERN PetscErrorCode DSSetState(DS,DSStateType);
 SLEPC_EXTERN PetscErrorCode DSGetState(DS,DSStateType*);
-SLEPC_EXTERN PetscErrorCode DSSetDimensions(DS,PetscInt,PetscInt,PetscInt,PetscInt);
-SLEPC_EXTERN PetscErrorCode DSGetDimensions(DS,PetscInt*,PetscInt*,PetscInt*,PetscInt*,PetscInt*);
+SLEPC_EXTERN PetscErrorCode DSSetDimensions(DS,PetscInt,PetscInt,PetscInt);
+SLEPC_EXTERN PetscErrorCode DSGetDimensions(DS,PetscInt*,PetscInt*,PetscInt*,PetscInt*);
 SLEPC_EXTERN PetscErrorCode DSSetBlockSize(DS,PetscInt);
 SLEPC_EXTERN PetscErrorCode DSGetBlockSize(DS,PetscInt*);
 SLEPC_EXTERN PetscErrorCode DSGetTruncateSize(DS,PetscInt,PetscInt,PetscInt*);
@@ -194,6 +197,11 @@ SLEPC_EXTERN PetscErrorCode DSPseudoOrthogonalize(DS,DSMatType,PetscInt,PetscRea
 
 /* --------- options specific to particular solvers -------- */
 
+SLEPC_EXTERN PetscErrorCode DSSVDSetDimensions(DS,PetscInt);
+SLEPC_EXTERN PetscErrorCode DSSVDGetDimensions(DS,PetscInt*);
+SLEPC_EXTERN PetscErrorCode DSGSVDSetDimensions(DS,PetscInt,PetscInt);
+SLEPC_EXTERN PetscErrorCode DSGSVDGetDimensions(DS,PetscInt*,PetscInt*);
+
 SLEPC_EXTERN PetscErrorCode DSPEPSetDegree(DS,PetscInt);
 SLEPC_EXTERN PetscErrorCode DSPEPGetDegree(DS,PetscInt*);
 SLEPC_EXTERN PetscErrorCode DSPEPSetCoefficients(DS,PetscReal*);
@@ -202,7 +210,18 @@ SLEPC_EXTERN PetscErrorCode DSPEPGetCoefficients(DS,PetscReal**);
 SLEPC_EXTERN PetscErrorCode DSNEPSetFN(DS,PetscInt,FN*);
 SLEPC_EXTERN PetscErrorCode DSNEPGetFN(DS,PetscInt,FN*);
 SLEPC_EXTERN PetscErrorCode DSNEPGetNumFN(DS,PetscInt*);
-SLEPC_EXTERN PetscErrorCode DSNEPSetComputeMatrixFunction(DS,PetscErrorCode (*fun)(DS,PetscScalar,PetscBool,DSMatType,void*),void *ctx);
+SLEPC_EXTERN PetscErrorCode DSNEPSetMinimality(DS,PetscInt);
+SLEPC_EXTERN PetscErrorCode DSNEPGetMinimality(DS,PetscInt*);
+SLEPC_EXTERN PetscErrorCode DSNEPSetRefine(DS,PetscReal,PetscInt);
+SLEPC_EXTERN PetscErrorCode DSNEPGetRefine(DS,PetscReal*,PetscInt*);
+SLEPC_EXTERN PetscErrorCode DSNEPSetIntegrationPoints(DS,PetscInt);
+SLEPC_EXTERN PetscErrorCode DSNEPGetIntegrationPoints(DS,PetscInt*);
+SLEPC_EXTERN PetscErrorCode DSNEPSetSamplingSize(DS,PetscInt);
+SLEPC_EXTERN PetscErrorCode DSNEPGetSamplingSize(DS,PetscInt*);
+SLEPC_EXTERN PetscErrorCode DSNEPSetRG(DS,RG);
+SLEPC_EXTERN PetscErrorCode DSNEPGetRG(DS,RG*);
+SLEPC_EXTERN PetscErrorCode DSNEPSetComputeMatrixFunction(DS,PetscErrorCode (*)(DS,PetscScalar,PetscBool,DSMatType,void*),void*);
+SLEPC_EXTERN PetscErrorCode DSNEPGetComputeMatrixFunction(DS,PetscErrorCode (**)(DS,PetscScalar,PetscBool,DSMatType,void*),void**);
 
 SLEPC_EXTERN PetscFunctionList DSList;
 SLEPC_EXTERN PetscErrorCode DSRegister(const char[],PetscErrorCode(*)(DS));
