@@ -53,7 +53,6 @@ typedef const char* EPSType;
 #define EPSLYAPII      "lyapii"
 #define EPSLAPACK      "lapack"
 #define EPSARPACK      "arpack"
-#define EPSBLZPACK     "blzpack"
 #define EPSTRLAN       "trlan"
 #define EPSBLOPEX      "blopex"
 #define EPSPRIMME      "primme"
@@ -276,7 +275,7 @@ SLEPC_EXTERN PetscErrorCode EPSSetLeftInitialSpace(EPS,PetscInt,Vec[]);
 SLEPC_EXTERN PetscErrorCode EPSMonitor(EPS,PetscInt,PetscInt,PetscScalar*,PetscScalar*,PetscReal*,PetscInt);
 SLEPC_EXTERN PetscErrorCode EPSMonitorSet(EPS,PetscErrorCode (*)(EPS,PetscInt,PetscInt,PetscScalar*,PetscScalar*,PetscReal*,PetscInt,void*),void*,PetscErrorCode (*)(void**));
 SLEPC_EXTERN PetscErrorCode EPSMonitorCancel(EPS);
-SLEPC_EXTERN PetscErrorCode EPSGetMonitorContext(EPS,void**);
+SLEPC_EXTERN PetscErrorCode EPSGetMonitorContext(EPS,void*);
 
 SLEPC_EXTERN PetscErrorCode EPSMonitorSetFromOptions(EPS,const char[],const char[],void*,PetscBool);
 SLEPC_EXTERN PetscErrorCode EPSMonitorLGCreate(MPI_Comm,const char[],const char[],const char[],PetscInt,const char*[],int,int,int,int,PetscDrawLG*);
@@ -370,11 +369,6 @@ SLEPC_EXTERN const char *EPSLanczosReorthogTypes[];
 SLEPC_EXTERN PetscErrorCode EPSLanczosSetReorthog(EPS,EPSLanczosReorthogType);
 SLEPC_EXTERN PetscErrorCode EPSLanczosGetReorthog(EPS,EPSLanczosReorthogType*);
 
-SLEPC_EXTERN PetscErrorCode EPSBlzpackSetBlockSize(EPS,PetscInt);
-SLEPC_EXTERN PetscErrorCode EPSBlzpackGetBlockSize(EPS,PetscInt*);
-SLEPC_EXTERN PetscErrorCode EPSBlzpackSetNSteps(EPS,PetscInt);
-SLEPC_EXTERN PetscErrorCode EPSBlzpackGetNSteps(EPS,PetscInt*);
-
 /*E
     EPSPRIMMEMethod - determines the method selected in the PRIMME library
 
