@@ -28,6 +28,8 @@
 #  define SLEPC_DEFAULT_TOL   1e-2
 #endif
 
+#define SlepcDefaultTol(tol) (((tol)==PETSC_DEFAULT)?SLEPC_DEFAULT_TOL:(tol))
+
 /*@C
    SlepcAbs - Returns sqrt(x**2+y**2), taking care not to cause unnecessary
    overflow. It is based on LAPACK's DLAPY2.
@@ -73,6 +75,8 @@ PETSC_STATIC_INLINE PetscReal SlepcAbs(PetscReal x,PetscReal y)
    This function computes sqrt(x**2+y**2), taking care not to cause unnecessary
    overflow. It is based on LAPACK's DLAPY2.
 
+   In complex scalars, only the first argument is used.
+
    This function is not available from Fortran.
 
    Level: developer
@@ -85,20 +89,17 @@ M*/
 
 #endif
 
-
 /*
    SlepcSetFlushToZero - Set the FTZ flag in floating-point arithmetic.
 */
 PETSC_STATIC_INLINE PetscErrorCode SlepcSetFlushToZero(unsigned int *state)
 {
   PetscFunctionBegin;
-#if defined(PETSC_HAVE_XMMINTRIN_H)
-#if defined(_MM_FLUSH_ZERO_ON) && defined(__SSE__)
+#if defined(PETSC_HAVE_XMMINTRIN_H) && defined(_MM_FLUSH_ZERO_ON) && defined(__SSE__)
   *state = _MM_GET_FLUSH_ZERO_MODE();
   _MM_SET_FLUSH_ZERO_MODE(_MM_FLUSH_ZERO_ON);
 #else
   *state = 0;
-#endif
 #endif
   PetscFunctionReturn(0);
 }
@@ -109,10 +110,10 @@ PETSC_STATIC_INLINE PetscErrorCode SlepcSetFlushToZero(unsigned int *state)
 PETSC_STATIC_INLINE PetscErrorCode SlepcResetFlushToZero(unsigned int *state)
 {
   PetscFunctionBegin;
-#if defined(PETSC_HAVE_XMMINTRIN_H)
-#if defined(_MM_FLUSH_ZERO_MASK) && defined(__SSE__)
+#if defined(PETSC_HAVE_XMMINTRIN_H) && defined(_MM_FLUSH_ZERO_MASK) && defined(__SSE__)
   _MM_SET_FLUSH_ZERO_MODE(*state & _MM_FLUSH_ZERO_MASK);
-#endif
+#else
+  *state = 0;
 #endif
   PetscFunctionReturn(0);
 }
