@@ -92,6 +92,7 @@ SLEPC_EXTERN const char *SVDErrorTypes[];
 E*/
 typedef enum { SVD_CONV_ABS,
                SVD_CONV_REL,
+               SVD_CONV_NORM,
                SVD_CONV_MAXIT,
                SVD_CONV_USER } SVDConv;
 
@@ -160,6 +161,7 @@ SLEPC_EXTERN PetscErrorCode SVDSetConvergenceTest(SVD,SVDConv);
 SLEPC_EXTERN PetscErrorCode SVDGetConvergenceTest(SVD,SVDConv*);
 SLEPC_EXTERN PetscErrorCode SVDConvergedAbsolute(SVD,PetscReal,PetscReal,PetscReal*,void*);
 SLEPC_EXTERN PetscErrorCode SVDConvergedRelative(SVD,PetscReal,PetscReal,PetscReal*,void*);
+SLEPC_EXTERN PetscErrorCode SVDConvergedNorm(SVD,PetscReal,PetscReal,PetscReal*,void*);
 SLEPC_EXTERN PetscErrorCode SVDConvergedMaxIt(SVD,PetscReal,PetscReal,PetscReal*,void*);
 SLEPC_EXTERN PetscErrorCode SVDSetStoppingTestFunction(SVD,PetscErrorCode (*)(SVD,PetscInt,PetscInt,PetscInt,PetscInt,SVDConvergedReason*,void*),void*,PetscErrorCode (*)(void*));
 SLEPC_EXTERN PetscErrorCode SVDSetStoppingTest(SVD,SVDStop);
@@ -193,7 +195,7 @@ SLEPC_EXTERN PetscErrorCode SVDGetTrackAll(SVD,PetscBool*);
 SLEPC_EXTERN PetscErrorCode SVDMonitor(SVD,PetscInt,PetscInt,PetscReal*,PetscReal*,PetscInt);
 SLEPC_EXTERN PetscErrorCode SVDMonitorSet(SVD,PetscErrorCode (*)(SVD,PetscInt,PetscInt,PetscReal*,PetscReal*,PetscInt,void*),void*,PetscErrorCode (*)(void**));
 SLEPC_EXTERN PetscErrorCode SVDMonitorCancel(SVD);
-SLEPC_EXTERN PetscErrorCode SVDGetMonitorContext(SVD,void **);
+SLEPC_EXTERN PetscErrorCode SVDGetMonitorContext(SVD,void*);
 
 SLEPC_EXTERN PetscErrorCode SVDMonitorSetFromOptions(SVD,const char[],const char[],void*,PetscBool);
 SLEPC_EXTERN PetscErrorCode SVDMonitorLGCreate(MPI_Comm,const char[],const char[],const char[],PetscInt,const char*[],int,int,int,int,PetscDrawLG*);
@@ -233,8 +235,33 @@ SLEPC_EXTERN PetscErrorCode SVDCyclicGetEPS(SVD,EPS*);
 SLEPC_EXTERN PetscErrorCode SVDLanczosSetOneSide(SVD,PetscBool);
 SLEPC_EXTERN PetscErrorCode SVDLanczosGetOneSide(SVD,PetscBool*);
 
+/*E
+    SVDTRLanczosGBidiag - determines the bidiagonalization choice for the
+    TRLanczos GSVD solver
+
+    Level: advanced
+
+.seealso: SVDTRLanczosSetGBidiag(), SVDTRLanczosGetGBidiag()
+E*/
+typedef enum {
+  SVD_TRLANCZOS_GBIDIAG_SINGLE, /* single bidiagonalization (Qa) */
+  SVD_TRLANCZOS_GBIDIAG_UPPER,  /* joint bidiagonalization, both Qa and Qb in upper bidiagonal form */
+  SVD_TRLANCZOS_GBIDIAG_LOWER   /* joint bidiagonalization, Qa lower bidiagonal, Qb upper bidiagonal */
+} SVDTRLanczosGBidiag;
+SLEPC_EXTERN const char *SVDTRLanczosGBidiags[];
+
+SLEPC_EXTERN PetscErrorCode SVDTRLanczosSetGBidiag(SVD,SVDTRLanczosGBidiag);
+SLEPC_EXTERN PetscErrorCode SVDTRLanczosGetGBidiag(SVD,SVDTRLanczosGBidiag*);
 SLEPC_EXTERN PetscErrorCode SVDTRLanczosSetOneSide(SVD,PetscBool);
 SLEPC_EXTERN PetscErrorCode SVDTRLanczosGetOneSide(SVD,PetscBool*);
+SLEPC_EXTERN PetscErrorCode SVDTRLanczosSetKSP(SVD,KSP);
+SLEPC_EXTERN PetscErrorCode SVDTRLanczosGetKSP(SVD,KSP*);
+SLEPC_EXTERN PetscErrorCode SVDTRLanczosSetRestart(SVD,PetscReal);
+SLEPC_EXTERN PetscErrorCode SVDTRLanczosGetRestart(SVD,PetscReal*);
+SLEPC_EXTERN PetscErrorCode SVDTRLanczosSetLocking(SVD,PetscBool);
+SLEPC_EXTERN PetscErrorCode SVDTRLanczosGetLocking(SVD,PetscBool*);
+SLEPC_EXTERN PetscErrorCode SVDTRLanczosSetExplicitMatrix(SVD,PetscBool);
+SLEPC_EXTERN PetscErrorCode SVDTRLanczosGetExplicitMatrix(SVD,PetscBool*);
 
 /*E
     SVDPRIMMEMethod - determines the SVD method selected in the PRIMME library
