@@ -30,7 +30,7 @@ typedef struct {
   PetscReal    lastTol;            /* last tol for dynamic stopping criterion */
   PetscReal    fix;                /* tolerance for using the approx. eigenvalue */
   PetscBool    dynamic;            /* if the dynamic stopping criterion is applied */
-  dvdDashboard *d;                 /* the currect dvdDashboard reference */
+  dvdDashboard *d;                 /* the current dvdDashboard reference */
   PC           old_pc;             /* old pc in ksp */
   BV           KZ;                 /* KZ vecs for the projector KZ*inv(X'*KZ)*X' */
   BV           U;                  /* new X vectors */
@@ -61,13 +61,13 @@ static PetscErrorCode dvd_improvex_apply_proj(dvdDashboard *d,Vec *V,PetscInt cV
 #endif
 
   PetscFunctionBegin;
-  if (cV > 2) SETERRQ(PETSC_COMM_SELF,1,"Consistency broken");
+  if (cV > 2) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"Consistency broken");
 
   /* h <- X'*V */
   ierr = PetscMalloc1(data->size_iXKZ*cV,&h);CHKERRQ(ierr);
   ldh = data->size_iXKZ;
   ierr = BVGetActiveColumns(data->U,&l,&k);CHKERRQ(ierr);
-  if (ldh!=k) SETERRQ(PETSC_COMM_SELF,1,"Consistency broken");
+  if (ldh!=k) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"Consistency broken");
   ierr = BVSetActiveColumns(data->U,0,k);CHKERRQ(ierr);
   for (i=0;i<cV;i++) {
     ierr = BVDotVec(data->U,V[i],&h[ldh*i]);CHKERRQ(ierr);
@@ -81,7 +81,6 @@ static PetscErrorCode dvd_improvex_apply_proj(dvdDashboard *d,Vec *V,PetscInt cV
   ierr = PetscBLASIntCast(cV,&cV_);CHKERRQ(ierr);
   ierr = PetscBLASIntCast(data->size_iXKZ,&n);CHKERRQ(ierr);
   ierr = PetscBLASIntCast(data->ldiXKZ,&ld);CHKERRQ(ierr);
-  PetscValidScalarPointer(data->iXKZ,0);
   ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
   PetscStackCallBLAS("LAPACKgetrs",LAPACKgetrs_("N",&n,&cV_,data->iXKZ,&ld,data->iXKZPivots,h,&n,&info));
   ierr = PetscFPTrapPop();CHKERRQ(ierr);
@@ -114,13 +113,13 @@ static PetscErrorCode dvd_improvex_applytrans_proj(dvdDashboard *d,Vec *V,PetscI
 #endif
 
   PetscFunctionBegin;
-  if (cV > 2) SETERRQ(PETSC_COMM_SELF,1,"Consistency broken");
+  if (cV > 2) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"Consistency broken");
 
   /* h <- KZ'*V */
   ierr = PetscMalloc1(data->size_iXKZ*cV,&h);CHKERRQ(ierr);
   ldh = data->size_iXKZ;
   ierr = BVGetActiveColumns(data->U,&l,&k);CHKERRQ(ierr);
-  if (ldh!=k) SETERRQ(PETSC_COMM_SELF,1,"Consistency broken");
+  if (ldh!=k) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"Consistency broken");
   ierr = BVSetActiveColumns(data->KZ,0,k);CHKERRQ(ierr);
   for (i=0;i<cV;i++) {
     ierr = BVDotVec(data->KZ,V[i],&h[ldh*i]);CHKERRQ(ierr);
@@ -134,7 +133,6 @@ static PetscErrorCode dvd_improvex_applytrans_proj(dvdDashboard *d,Vec *V,PetscI
   ierr = PetscBLASIntCast(cV,&cV_);CHKERRQ(ierr);
   ierr = PetscBLASIntCast(data->size_iXKZ,&n);CHKERRQ(ierr);
   ierr = PetscBLASIntCast(data->ldiXKZ,&ld);CHKERRQ(ierr);
-  PetscValidScalarPointer(data->iXKZ,0);
   ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
   PetscStackCallBLAS("LAPACKgetrs",LAPACKgetrs_("C",&n,&cV_,data->iXKZ,&ld,data->iXKZPivots,h,&n,&info));
   ierr = PetscFPTrapPop();CHKERRQ(ierr);
@@ -284,7 +282,7 @@ static PetscErrorCode PCApplyBA_dvd(PC pc,PCSide side,Vec in,Vec out,Vec w)
 
   PetscFunctionBegin;
   ierr = PCGetOperators(pc,&A,NULL);CHKERRQ(ierr);
-  ierr = MatShellGetContext(A,(void**)&data);CHKERRQ(ierr);
+  ierr = MatShellGetContext(A,&data);CHKERRQ(ierr);
   ierr = VecCompGetSubVecs(in,NULL,&inx);CHKERRQ(ierr);
   ierr = VecCompGetSubVecs(out,NULL,&outx);CHKERRQ(ierr);
   ierr = VecCompGetSubVecs(w,NULL,&wx);CHKERRQ(ierr);
@@ -324,7 +322,7 @@ static PetscErrorCode PCApplyBA_dvd(PC pc,PCSide side,Vec in,Vec out,Vec w)
     }
     break;
   default:
-    SETERRQ(PETSC_COMM_SELF,1,"Unsupported KSP side");
+    SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"Unsupported KSP side");
   }
   /* out <- out - v*(u'*out) */
   ierr = dvd_improvex_apply_proj(data->d,(Vec*)outx,n);CHKERRQ(ierr);
@@ -342,7 +340,7 @@ static PetscErrorCode PCApply_dvd(PC pc,Vec in,Vec out)
 
   PetscFunctionBegin;
   ierr = PCGetOperators(pc,&A,NULL);CHKERRQ(ierr);
-  ierr = MatShellGetContext(A,(void**)&data);CHKERRQ(ierr);
+  ierr = MatShellGetContext(A,&data);CHKERRQ(ierr);
   ierr = VecCompGetSubVecs(in,NULL,&inx);CHKERRQ(ierr);
   ierr = VecCompGetSubVecs(out,NULL,&outx);CHKERRQ(ierr);
   n = data->r_e - data->r_s;
@@ -366,7 +364,7 @@ static PetscErrorCode PCApplyTranspose_dvd(PC pc,Vec in,Vec out)
 
   PetscFunctionBegin;
   ierr = PCGetOperators(pc,&A,NULL);CHKERRQ(ierr);
-  ierr = MatShellGetContext(A,(void**)&data);CHKERRQ(ierr);
+  ierr = MatShellGetContext(A,&data);CHKERRQ(ierr);
   ierr = VecCompGetSubVecs(in,NULL,&inx);CHKERRQ(ierr);
   ierr = VecCompGetSubVecs(out,NULL,&outx);CHKERRQ(ierr);
   n = data->r_e - data->r_s;
@@ -394,7 +392,7 @@ static PetscErrorCode MatMult_dvd_jd(Mat A,Vec in,Vec out)
   PCSide         side;
 
   PetscFunctionBegin;
-  ierr = MatShellGetContext(A,(void**)&data);CHKERRQ(ierr);
+  ierr = MatShellGetContext(A,&data);CHKERRQ(ierr);
   ierr = VecCompGetSubVecs(in,NULL,&inx);CHKERRQ(ierr);
   ierr = VecCompGetSubVecs(out,NULL,&outx);CHKERRQ(ierr);
   n = data->r_e - data->r_s;
@@ -418,7 +416,7 @@ static PetscErrorCode MatMultTranspose_dvd_jd(Mat A,Vec in,Vec out)
   PCSide         side;
 
   PetscFunctionBegin;
-  ierr = MatShellGetContext(A,(void**)&data);CHKERRQ(ierr);
+  ierr = MatShellGetContext(A,&data);CHKERRQ(ierr);
   ierr = VecCompGetSubVecs(in,NULL,&inx);CHKERRQ(ierr);
   ierr = VecCompGetSubVecs(out,NULL,&outx);CHKERRQ(ierr);
   n = data->r_e - data->r_s;
@@ -449,7 +447,7 @@ static PetscErrorCode MatCreateVecs_dvd_jd(Mat A,Vec *right,Vec *left)
   PetscInt       n,i;
 
   PetscFunctionBegin;
-  ierr = MatShellGetContext(A,(void**)&data);CHKERRQ(ierr);
+  ierr = MatShellGetContext(A,&data);CHKERRQ(ierr);
   n = data->ksp_max_size;
   if (right) {
     ierr = PetscMalloc1(n,&r);CHKERRQ(ierr);
@@ -574,7 +572,7 @@ static PetscErrorCode dvd_improvex_jd_proj_cuv(dvdDashboard *d,PetscInt i_s,Pets
   /* Check consistency */
   ierr = BVGetActiveColumns(d->eps->V,&lv,&kv);CHKERRQ(ierr);
   V_new = lv - data->size_cX;
-  if (V_new > data->old_size_X) SETERRQ(PETSC_COMM_SELF,1,"Consistency broken");
+  if (V_new > data->old_size_X) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"Consistency broken");
   data->old_size_X = n;
   data->size_cX = lv;
 
@@ -657,8 +655,8 @@ static PetscErrorCode dvd_improvex_jd_gen(dvdDashboard *d,PetscInt r_s,PetscInt
   }
 
   n = PetscMin(PetscMin(data->size_X, max_size_D), r_e-r_s);
-  if (n == 0) SETERRQ(PETSC_COMM_SELF,1,"n == 0");
-  if (data->size_X < r_e-r_s) SETERRQ(PETSC_COMM_SELF,1,"size_X < r_e-r_s");
+  if (n == 0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"n == 0");
+  if (data->size_X < r_e-r_s) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"size_X < r_e-r_s");
 
   ierr = DSGetLeadingDimension(d->eps->ds,&ld);CHKERRQ(ierr);
 
