@@ -41,7 +41,7 @@ PetscErrorCode EPSGetArbitraryValues(EPS eps,PetscScalar *rr,PetscScalar *ri)
 
   PetscFunctionBegin;
   ierr = DSGetLeadingDimension(eps->ds,&ld);CHKERRQ(ierr);
-  ierr = DSGetDimensions(eps->ds,&n,NULL,&l,NULL,NULL);CHKERRQ(ierr);
+  ierr = DSGetDimensions(eps->ds,&n,&l,NULL,NULL);CHKERRQ(ierr);
   for (i=l;i<n;i++) {
     re = eps->eigr[i];
     im = eps->eigi[i];
@@ -123,7 +123,7 @@ static PetscErrorCode EPSSetUp_KrylovSchur_Filter(EPS eps)
   }
   if (eps->ncv==PETSC_DEFAULT && eps->nev==1) eps->nev = 40;  /* user did not provide nev estimation */
   ierr = EPSSetDimensions_Default(eps,eps->nev,&eps->ncv,&eps->mpd);CHKERRQ(ierr);
-  if (eps->ncv>eps->nev+eps->mpd) SETERRQ(PetscObjectComm((PetscObject)eps),1,"The value of ncv must not be larger than nev+mpd");
+  if (eps->ncv>eps->nev+eps->mpd) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_USER_INPUT,"The value of ncv must not be larger than nev+mpd");
   if (eps->max_it==PETSC_DEFAULT) eps->max_it = PetscMax(100,2*eps->n/eps->ncv);
   PetscFunctionReturn(0);
 }
@@ -148,7 +148,7 @@ PetscErrorCode EPSSetUp_KrylovSchur(EPS eps)
     }
   } else {
     ierr = EPSSetDimensions_Default(eps,eps->nev,&eps->ncv,&eps->mpd);CHKERRQ(ierr);
-    if (eps->ncv>eps->nev+eps->mpd) SETERRQ(PetscObjectComm((PetscObject)eps),1,"The value of ncv must not be larger than nev+mpd");
+    if (eps->ncv>eps->nev+eps->mpd) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_USER_INPUT,"The value of ncv must not be larger than nev+mpd");
     if (eps->max_it==PETSC_DEFAULT) eps->max_it = PetscMax(100,2*eps->n/eps->ncv);
     if (!eps->which) { ierr = EPSSetWhichEigenpairs_Default(eps);CHKERRQ(ierr); }
   }
@@ -164,7 +164,7 @@ PetscErrorCode EPSSetUp_KrylovSchur(EPS eps)
   ierr = EPS_SetInnerProduct(eps);CHKERRQ(ierr);
   if (eps->arbitrary) {
     ierr = EPSSetWorkVecs(eps,2);CHKERRQ(ierr);
-  } else if (eps->ishermitian && !eps->ispositive){
+  } else if (eps->ishermitian && !eps->ispositive) {
     ierr = EPSSetWorkVecs(eps,1);CHKERRQ(ierr);
   }
 
@@ -230,7 +230,7 @@ PetscErrorCode EPSSetUp_KrylovSchur(EPS eps)
       ierr = DSAllocate(eps->ds,eps->ncv+1);CHKERRQ(ierr);
       ierr = DSSetExtraRow(eps->ds,PETSC_TRUE);CHKERRQ(ierr);
       break;
-    default: SETERRQ(PetscObjectComm((PetscObject)eps),1,"Unexpected error");
+    default: SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_PLIB,"Unexpected error");
   }
   PetscFunctionReturn(0);
 }
@@ -272,8 +272,8 @@ PetscErrorCode EPSSolve_KrylovSchur_Default(EPS eps)
   PetscErrorCode  ierr;
   EPS_KRYLOVSCHUR *ctx = (EPS_KRYLOVSCHUR*)eps->data;
   PetscInt        j,*pj,k,l,nv,ld,nconv;
-  Mat             U,Op;
-  PetscScalar     *S,*g;
+  Mat             U,Op,H;
+  PetscScalar     *g;
   PetscReal       beta,gamma=1.0,*a,*b;
   PetscBool       breakdown,harmonic,hermitian;
 
@@ -295,6 +295,7 @@ PetscErrorCode EPSSolve_KrylovSchur_Default(EPS eps)
 
     /* Compute an nv-step Arnoldi factorization */
     nv = PetscMin(eps->nconv+eps->mpd,eps->ncv);
+    ierr = DSSetDimensions(eps->ds,nv,eps->nconv,eps->nconv+l);CHKERRQ(ierr);
     ierr = STGetOperator(eps->st,&Op);CHKERRQ(ierr);
     if (hermitian) {
       ierr = DSGetArrayReal(eps->ds,DS_MAT_T,&a);CHKERRQ(ierr);
@@ -303,12 +304,12 @@ PetscErrorCode EPSSolve_KrylovSchur_Default(EPS eps)
       beta = b[nv-1];
       ierr = DSRestoreArrayReal(eps->ds,DS_MAT_T,&a);CHKERRQ(ierr);
     } else {
-      ierr = DSGetArray(eps->ds,DS_MAT_A,&S);CHKERRQ(ierr);
-      ierr = BVMatArnoldi(eps->V,Op,S,ld,eps->nconv+l,&nv,&beta,&breakdown);CHKERRQ(ierr);
-      ierr = DSRestoreArray(eps->ds,DS_MAT_A,&S);CHKERRQ(ierr);
+      ierr = DSGetMat(eps->ds,DS_MAT_A,&H);CHKERRQ(ierr);
+      ierr = BVMatArnoldi(eps->V,Op,H,eps->nconv+l,&nv,&beta,&breakdown);CHKERRQ(ierr);
+      ierr = DSRestoreMat(eps->ds,DS_MAT_A,&H);CHKERRQ(ierr);
     }
     ierr = STRestoreOperator(eps->st,&Op);CHKERRQ(ierr);
-    ierr = DSSetDimensions(eps->ds,nv,0,eps->nconv,eps->nconv+l);CHKERRQ(ierr);
+    ierr = DSSetDimensions(eps->ds,nv,eps->nconv,eps->nconv+l);CHKERRQ(ierr);
     if (l==0) {
       ierr = DSSetState(eps->ds,DS_STATE_INTERMEDIATE);CHKERRQ(ierr);
     } else {
@@ -359,14 +360,14 @@ PetscErrorCode EPSSolve_KrylovSchur_Default(EPS eps)
       } else {
         /* Undo translation of Krylov decomposition */
         if (harmonic) {
-          ierr = DSSetDimensions(eps->ds,nv,0,k,l);CHKERRQ(ierr);
+          ierr = DSSetDimensions(eps->ds,nv,k,l);CHKERRQ(ierr);
           ierr = DSTranslateHarmonic(eps->ds,0.0,beta,PETSC_TRUE,g,&gamma);CHKERRQ(ierr);
           /* gamma u^ = u - U*g~ */
           ierr = BVSetActiveColumns(eps->V,0,nv);CHKERRQ(ierr);
           ierr = BVMultColumn(eps->V,-1.0,1.0,nv,g);CHKERRQ(ierr);
           ierr = BVScaleColumn(eps->V,nv,1.0/gamma);CHKERRQ(ierr);
           ierr = BVSetActiveColumns(eps->V,eps->nconv,nv);CHKERRQ(ierr);
-          ierr = DSSetDimensions(eps->ds,nv,0,k,nv);CHKERRQ(ierr);
+          ierr = DSSetDimensions(eps->ds,nv,k,nv);CHKERRQ(ierr);
         }
         /* Prepare the Rayleigh quotient for restart */
         ierr = DSTruncate(eps->ds,k+l,PETSC_FALSE);CHKERRQ(ierr);
@@ -1110,7 +1111,7 @@ static PetscErrorCode EPSKrylovSchurGetSubcommPairs_KrylovSchur(EPS eps,PetscInt
 
    Collective on the subcommunicator (if v is given)
 
-   Input Parameter:
+   Input Parameters:
 +  eps - the eigenproblem solver context
 -  i   - index of the solution
 
@@ -1333,11 +1334,13 @@ PetscErrorCode EPSKrylovSchurGetChildEPS(EPS eps,EPS *child)
 
       /* Duplicate matrices */
       ierr = MatCreateRedundantMatrix(A,0,PetscSubcommChild(ctx->subc),MAT_INITIAL_MATRIX,&Ar);CHKERRQ(ierr);
+      ierr = PetscLogObjectParent((PetscObject)eps,(PetscObject)Ar);CHKERRQ(ierr);
       ctx->Astate = Astate;
       ctx->Aid = Aid;
       ierr = MatPropagateSymmetryOptions(A,Ar);CHKERRQ(ierr);
       if (B) {
         ierr = MatCreateRedundantMatrix(B,0,PetscSubcommChild(ctx->subc),MAT_INITIAL_MATRIX,&Br);CHKERRQ(ierr);
+        ierr = PetscLogObjectParent((PetscObject)eps,(PetscObject)Br);CHKERRQ(ierr);
         ctx->Bstate = Bstate;
         ctx->Bid = Bid;
         ierr = MatPropagateSymmetryOptions(B,Br);CHKERRQ(ierr);
