@@ -43,7 +43,7 @@ static const char citation[] =
 
 #define InertiaMismatch(h,d) \
   do { \
-    SETERRQ1(PetscObjectComm((PetscObject)h),1,"Mismatch between number of values found and information from inertia%s",d?"":", consider using EPSKrylovSchurSetDetectZeros()"); \
+    SETERRQ1(PetscObjectComm((PetscObject)h),PETSC_ERR_PLIB,"Mismatch between number of values found and information from inertia%s",d?"":", consider using EPSKrylovSchurSetDetectZeros()"); \
   } while (0)
 
 static PetscErrorCode EPSSliceResetSR(EPS eps)
@@ -302,6 +302,7 @@ PetscErrorCode EPSSetUp_KrylovSchur_Slice(EPS eps)
     EPSCheckSinvertCayleyCondition(eps,PETSC_TRUE," with spectrum slicing");
     if (eps->inta==eps->intb) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"This solver does not support computing all eigenvalues unless you provide a computational interval with EPSSetInterval()");
     if (eps->intb >= PETSC_MAX_REAL && eps->inta <= PETSC_MIN_REAL) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_WRONG,"The defined computational interval should have at least one of their sides bounded");
+    if (eps->nds) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Spectrum slicing not supported in combination with deflation space");
     EPSCheckUnsupportedCondition(eps,EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_STOPPING,PETSC_TRUE," with spectrum slicing");
     EPSCheckIgnoredCondition(eps,EPS_FEATURE_BALANCE,PETSC_TRUE," with spectrum slicing");
     if (eps->tol==PETSC_DEFAULT) {
@@ -685,7 +686,7 @@ static PetscErrorCode EPSSliceGatherSolution(EPS eps)
     ierr = PetscMPIIntCast(ns,&aux);CHKERRQ(ierr);
     ierr = MPI_Allgatherv(shifts_loc,aux,MPIU_REAL,ctx->shifts,ns_loc,disp,MPIU_REAL,ctx->commrank);CHKERRMPI(ierr); /* shifts */
     ierr = MPI_Allgatherv(inertias_loc,aux,MPIU_INT,ctx->inertias,ns_loc,disp,MPIU_INT,ctx->commrank);CHKERRMPI(ierr); /* inertias */
-    ierr = MPIU_Allreduce(&sr_loc->itsKs,&eps->its,1,MPIU_INT,MPI_SUM,ctx->commrank);CHKERRQ(ierr);
+    ierr = MPIU_Allreduce(&sr_loc->itsKs,&eps->its,1,MPIU_INT,MPI_SUM,ctx->commrank);CHKERRMPI(ierr);
   } else { /* subcommunicators with different size */
     ierr = MPI_Comm_rank(PetscSubcommChild(ctx->subc),&rank);CHKERRMPI(ierr);
     if (!rank) {
@@ -696,7 +697,7 @@ static PetscErrorCode EPSSliceGatherSolution(EPS eps)
       ierr = PetscMPIIntCast(ns,&aux);CHKERRQ(ierr);
       ierr = MPI_Allgatherv(shifts_loc,aux,MPIU_REAL,ctx->shifts,ns_loc,disp,MPIU_REAL,ctx->commrank);CHKERRMPI(ierr); /* shifts */
       ierr = MPI_Allgatherv(inertias_loc,aux,MPIU_INT,ctx->inertias,ns_loc,disp,MPIU_INT,ctx->commrank);CHKERRMPI(ierr); /* inertias */
-      ierr = MPIU_Allreduce(&sr_loc->itsKs,&eps->its,1,MPIU_INT,MPI_SUM,ctx->commrank);CHKERRQ(ierr);
+      ierr = MPIU_Allreduce(&sr_loc->itsKs,&eps->its,1,MPIU_INT,MPI_SUM,ctx->commrank);CHKERRMPI(ierr);
     }
     ierr = PetscMPIIntCast(eps->nconv,&aux);CHKERRQ(ierr);
     ierr = MPI_Bcast(eps->eigr,aux,MPIU_SCALAR,0,PetscSubcommChild(ctx->subc));CHKERRMPI(ierr);
@@ -799,8 +800,8 @@ static PetscErrorCode EPSPrepareRational(EPS eps)
   }
   sr->nS = k;
   ierr = DSRestoreArray(eps->ds,DS_MAT_A,&A);CHKERRQ(ierr);
-  ierr = DSGetDimensions(eps->ds,&nv,NULL,NULL,NULL,NULL);CHKERRQ(ierr);
-  ierr = DSSetDimensions(eps->ds,nv,0,0,k);CHKERRQ(ierr);
+  ierr = DSGetDimensions(eps->ds,&nv,NULL,NULL,NULL);CHKERRQ(ierr);
+  ierr = DSSetDimensions(eps->ds,nv,0,k);CHKERRQ(ierr);
   /* Append u to V */
   ierr = BVGetColumn(sr->Vnext,sr->nS,&v);CHKERRQ(ierr);
   ierr = BVCopyVec(eps->V,sr->nv,v);CHKERRQ(ierr);
@@ -879,8 +880,8 @@ static PetscErrorCode EPSKrylovSchur_Slice(EPS eps)
   if (!sPres->rep && sr->nS > 0 && (sPres->neighb[0] == sr->sPrev || sPres->neighb[1] == sr->sPrev)) {
     /* Rational Krylov */
     ierr = DSTranslateRKS(eps->ds,sr->sPrev->value-sPres->value);CHKERRQ(ierr);
-    ierr = DSGetDimensions(eps->ds,NULL,NULL,NULL,&l,NULL);CHKERRQ(ierr);
-    ierr = DSSetDimensions(eps->ds,l+1,0,0,0);CHKERRQ(ierr);
+    ierr = DSGetDimensions(eps->ds,NULL,NULL,&l,NULL);CHKERRQ(ierr);
+    ierr = DSSetDimensions(eps->ds,l+1,0,0);CHKERRQ(ierr);
     ierr = BVSetActiveColumns(eps->V,0,l+1);CHKERRQ(ierr);
     ierr = DSGetMat(eps->ds,DS_MAT_Q,&U);CHKERRQ(ierr);
     ierr = BVMultInPlace(eps->V,U,0,l+1);CHKERRQ(ierr);
@@ -903,7 +904,7 @@ static PetscErrorCode EPSKrylovSchur_Slice(EPS eps)
     sr->nv = nv;
     beta = b[nv-1];
     ierr = DSRestoreArrayReal(eps->ds,DS_MAT_T,&a);CHKERRQ(ierr);
-    ierr = DSSetDimensions(eps->ds,nv,0,eps->nconv,eps->nconv+l);CHKERRQ(ierr);
+    ierr = DSSetDimensions(eps->ds,nv,eps->nconv,eps->nconv+l);CHKERRQ(ierr);
     if (l==0) {
       ierr = DSSetState(eps->ds,DS_STATE_INTERMEDIATE);CHKERRQ(ierr);
     } else {
@@ -1058,7 +1059,7 @@ static PetscErrorCode EPSGetNewShiftValue(EPS eps,PetscInt side,PetscReal *newS)
         *newS = sPres->value + 10*(sr->dir)*PetscAbsReal(sPres->value - sPres->neighb[0]->value);
         sr->nleap++;
         /* Stops when the interval is open and no values are found in the last 5 shifts (there might be infinite eigenvalues) */
-        if (!sr->hasEnd && sr->nleap > 5) SETERRQ(PetscObjectComm((PetscObject)eps),1,"Unable to compute the wanted eigenvalues with open interval");
+        if (!sr->hasEnd && sr->nleap > 5) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_PLIB,"Unable to compute the wanted eigenvalues with open interval");
       } else { /* First shift */
         if (eps->nconv != 0) {
           /* Unaccepted values give information for next shift */
@@ -1076,7 +1077,7 @@ static PetscErrorCode EPSGetNewShiftValue(EPS eps,PetscInt side,PetscReal *newS)
           }
           *newS = sPres->value + ((sr->dir)*d_prev*eps->nev)/2;
         } else { /* No values found, no information for next shift */
-          SETERRQ(PetscObjectComm((PetscObject)eps),1,"First shift renders no information");
+          SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_PLIB,"First shift renders no information");
         }
       }
     } else { /* Accepted values found */
@@ -1157,7 +1158,7 @@ static PetscErrorCode EPSStoreEigenpairs(EPS eps)
     err = eps->errest[eps->perm[i]];
 
     if ((sr->dir)*(lambda - sPres->ext[0]) > 0 && (sr->dir)*(sPres->ext[1] - lambda) > 0) {/* Valid value */
-      if (count>=sr->numEigs) SETERRQ(PetscObjectComm((PetscObject)eps),1,"Unexpected error in Spectrum Slicing");
+      if (count>=sr->numEigs) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_PLIB,"Unexpected error in Spectrum Slicing");
       sr->eigr[count] = lambda;
       sr->errest[count] = err;
       /* Explicit purification */
