@@ -61,7 +61,7 @@ PetscErrorCode EPSSetUp_LyapII(EPS eps)
   PetscFunctionBegin;
   EPSCheckSinvert(eps);
   if (eps->ncv!=PETSC_DEFAULT) {
-    if (eps->ncv<eps->nev+1) SETERRQ(PetscObjectComm((PetscObject)eps),1,"The value of ncv must be at least nev+1");
+    if (eps->ncv<eps->nev+1) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_USER_INPUT,"The value of ncv must be at least nev+1");
   } else eps->ncv = eps->nev+1;
   if (eps->mpd!=PETSC_DEFAULT) { ierr = PetscInfo(eps,"Warning: parameter mpd ignored\n");CHKERRQ(ierr); }
   if (eps->max_it==PETSC_DEFAULT) eps->max_it = PetscMax(1000*eps->nev,100*eps->n);
@@ -97,7 +97,7 @@ static PetscErrorCode MatMult_EPSLyapIIOperator(Mat M,Vec x,Vec r)
   EPS_LYAPII_MATSHELL *matctx;
 
   PetscFunctionBegin;
-  ierr = MatShellGetContext(M,(void**)&matctx);CHKERRQ(ierr);
+  ierr = MatShellGetContext(M,&matctx);CHKERRQ(ierr);
   ierr = MatMult(matctx->S,x,r);CHKERRQ(ierr);
   ierr = BVOrthogonalizeVec(matctx->Q,r,NULL,NULL,NULL);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -109,7 +109,7 @@ static PetscErrorCode MatDestroy_EPSLyapIIOperator(Mat M)
   EPS_LYAPII_MATSHELL *matctx;
 
   PetscFunctionBegin;
-  ierr = MatShellGetContext(M,(void**)&matctx);CHKERRQ(ierr);
+  ierr = MatShellGetContext(M,&matctx);CHKERRQ(ierr);
   ierr = MatDestroy(&matctx->S);CHKERRQ(ierr);
   ierr = PetscFree(matctx);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -127,7 +127,7 @@ static PetscErrorCode MatMult_EigOperator(Mat M,Vec x,Vec y)
 #endif
 
   PetscFunctionBegin;
-  ierr = MatShellGetContext(M,(void**)&matctx);CHKERRQ(ierr);
+  ierr = MatShellGetContext(M,&matctx);CHKERRQ(ierr);
 
 #if defined(PETSC_USE_COMPLEX)
   ierr = MatMult(matctx->B,x,matctx->w);CHKERRQ(ierr);
@@ -162,7 +162,7 @@ static PetscErrorCode MatDestroy_EigOperator(Mat M)
   EPS_EIG_MATSHELL *matctx;
 
   PetscFunctionBegin;
-  ierr = MatShellGetContext(M,(void**)&matctx);CHKERRQ(ierr);
+  ierr = MatShellGetContext(M,&matctx);CHKERRQ(ierr);
 #if defined(PETSC_USE_COMPLEX)
   ierr = MatDestroy(&matctx->A);CHKERRQ(ierr);
   ierr = MatDestroy(&matctx->B);CHKERRQ(ierr);
@@ -180,39 +180,21 @@ static PetscErrorCode EV2x2(PetscScalar *M,PetscInt ld,PetscScalar *wr,PetscScal
 {
   PetscErrorCode ierr;
   PetscBLASInt   lwork=10,ld_;
-#if !defined(PETSC_HAVE_ESSL)
   PetscScalar    work[10];
   PetscBLASInt   two=2,info;
-#else
-  PetscInt       i;
-  PetscBLASInt   idummy,io=1;
-  PetscScalar    wri[4];
-#endif
-#if defined(PETSC_HAVE_ESSL) || defined(PETSC_USE_COMPLEX)
+#if defined(PETSC_USE_COMPLEX)
   PetscReal      rwork[6];
 #endif
 
   PetscFunctionBegin;
   ierr = PetscBLASIntCast(ld,&ld_);CHKERRQ(ierr);
   ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
-#if !defined(PETSC_HAVE_ESSL)
 #if !defined(PETSC_USE_COMPLEX)
   PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_("N","V",&two,M,&ld_,wr,wi,NULL,&ld_,vec,&ld_,work,&lwork,&info));
 #else
   PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_("N","V",&two,M,&ld_,wr,NULL,&ld_,vec,&ld_,work,&lwork,rwork,&info));
 #endif
   SlepcCheckLapackInfo("geev",info);
-#else /* defined(PETSC_HAVE_ESSL) */
-  PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_(&io,M,&ld_,wri,vec,&ld_,&idummy,&ld_,rwork,&lwork));
-#if !defined(PETSC_USE_COMPLEX)
-  for (i=0;i<2;i++) {
-    wr[i] = wri[2*i];
-    wi[i] = wri[2*i+1];
-  }
-#else
-  for (i=0;i<2;i++) wr[i] = wri[i];
-#endif
-#endif
   ierr = PetscFPTrapPop();CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -295,7 +277,7 @@ static PetscErrorCode LyapIIBuildEigenMat(LME lme,Mat S,Mat *Op,Vec *v0)
     ierr = MatShellSetOperation(*Op,MATOP_DESTROY,(void(*)(void))MatDestroy_EigOperator);CHKERRQ(ierr);
     ierr = MatCreateVecs(*Op,NULL,v0);CHKERRQ(ierr);
   } else {
-    ierr = MatShellGetContext(*Op,(void**)&matctx);CHKERRQ(ierr);
+    ierr = MatShellGetContext(*Op,&matctx);CHKERRQ(ierr);
 #if defined(PETSC_USE_COMPLEX)
     ierr = MatZeroEntries(matctx->A);CHKERRQ(ierr);
 #endif
@@ -404,7 +386,8 @@ PetscErrorCode EPSSolve_LyapII(EPS eps)
     ierr = MatDestroy(&Y);CHKERRQ(ierr);
 
     /* SVD of the solution: [Q,R]=qr(V); [U,Sigma,~]=svd(R) */
-    ierr = DSSetDimensions(ctx->ds,nv,nv,0,0);CHKERRQ(ierr);
+    ierr = DSSetDimensions(ctx->ds,nv,0,0);CHKERRQ(ierr);
+    ierr = DSSVDSetDimensions(ctx->ds,nv);CHKERRQ(ierr);
     ierr = DSGetMat(ctx->ds,DS_MAT_A,&R);CHKERRQ(ierr);
     ierr = BVOrthogonalize(V,R);CHKERRQ(ierr);
     ierr = DSRestoreMat(ctx->ds,DS_MAT_A,&R);CHKERRQ(ierr);
@@ -422,7 +405,8 @@ PetscErrorCode EPSSolve_LyapII(EPS eps)
     ierr = MatDestroy(&U);CHKERRQ(ierr);
 
     /* Rank reduction */
-    ierr = DSSetDimensions(ctx->ds,rk,rk,0,0);CHKERRQ(ierr);
+    ierr = DSSetDimensions(ctx->ds,rk,0,0);CHKERRQ(ierr);
+    ierr = DSSVDSetDimensions(ctx->ds,rk);CHKERRQ(ierr);
     ierr = DSGetMat(ctx->ds,DS_MAT_A,&W);CHKERRQ(ierr);
     ierr = BVMatProject(V,S,V,W);CHKERRQ(ierr);
     ierr = LyapIIBuildEigenMat(ctx->lme,W,&Op,&v0);CHKERRQ(ierr); /* Op=A\B, A=kron(I,S)+kron(S,I), B=-2*kron(S,S) */
@@ -521,7 +505,7 @@ PetscErrorCode EPSSolve_LyapII(EPS eps)
       eps->nconv += k;
       ierr = BVSetActiveColumns(eps->V,eps->nconv-rk,eps->nconv);CHKERRQ(ierr);
       ierr = BVOrthogonalize(eps->V,NULL);CHKERRQ(ierr);
-      ierr = DSSetDimensions(eps->ds,eps->nconv,0,0,0);CHKERRQ(ierr);
+      ierr = DSSetDimensions(eps->ds,eps->nconv,0,0);CHKERRQ(ierr);
       ierr = DSGetMat(eps->ds,DS_MAT_A,&W);CHKERRQ(ierr);
       ierr = BVMatProject(eps->V,matctx->S,eps->V,W);CHKERRQ(ierr);
       ierr = DSRestoreMat(eps->ds,DS_MAT_A,&W);CHKERRQ(ierr);
