@@ -12,7 +12,7 @@
 */
 
 #include <slepc/private/epsimpl.h>   /*I "slepceps.h" I*/
-#include <slepc/private/bvimpl.h>    /*I "slepcbv.h" I*/
+#include <slepc/private/bvimpl.h>
 #include <petscdraw.h>
 
 PetscErrorCode EPSComputeVectors(EPS eps)
@@ -49,7 +49,7 @@ static PetscErrorCode EPSComputeValues(EPS eps)
         } else SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_PLIB,"Internal error, spectral transform should have a backtransform operation");
       } else {
         /* compute eigenvalues from Rayleigh quotient */
-        ierr = DSGetDimensions(eps->ds,&n,NULL,NULL,NULL,NULL);CHKERRQ(ierr);
+        ierr = DSGetDimensions(eps->ds,&n,NULL,NULL,NULL);CHKERRQ(ierr);
         if (!n) break;
         ierr = EPSGetOperators(eps,&A,&B);CHKERRQ(ierr);
         ierr = BVSetActiveColumns(eps->V,0,n);CHKERRQ(ierr);
@@ -575,7 +575,7 @@ PetscErrorCode EPSGetLeftEigenvector(EPS eps,PetscInt i,Vec Wr,Vec Wi)
 
    Not Collective
 
-   Input Parameter:
+   Input Parameters:
 +  eps - eigensolver context
 -  i   - index of eigenpair
 
@@ -673,7 +673,7 @@ PetscErrorCode EPSComputeResidualNorm_Private(EPS eps,PetscBool trans,PetscScala
 
    Collective on eps
 
-   Input Parameter:
+   Input Parameters:
 +  eps  - the eigensolver context
 .  i    - the solution index
 -  type - the type of error to compute
@@ -821,8 +821,8 @@ PetscErrorCode EPSGetStartVector(EPS eps,PetscInt i,PetscBool *breakdown)
   ierr = BVOrthogonalizeColumn(eps->V,i,NULL,&norm,&lindep);CHKERRQ(ierr);
   if (breakdown) *breakdown = lindep;
   else if (lindep || norm == 0.0) {
-    if (i==0) SETERRQ(PetscObjectComm((PetscObject)eps),1,"Initial vector is zero or belongs to the deflation space");
-    else SETERRQ(PetscObjectComm((PetscObject)eps),1,"Unable to generate more start vectors");
+    if (i==0) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_PLIB,"Initial vector is zero or belongs to the deflation space");
+    else SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_CONV_FAILED,"Unable to generate more start vectors");
   }
   ierr = BVScaleColumn(eps->V,i,1.0/norm);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -851,8 +851,8 @@ PetscErrorCode EPSGetLeftStartVector(EPS eps,PetscInt i,PetscBool *breakdown)
   ierr = BVOrthogonalizeColumn(eps->W,i,NULL,&norm,&lindep);CHKERRQ(ierr);
   if (breakdown) *breakdown = lindep;
   else if (lindep || norm == 0.0) {
-    if (i==0) SETERRQ(PetscObjectComm((PetscObject)eps),1,"Left initial vector is zero");
-    else SETERRQ(PetscObjectComm((PetscObject)eps),1,"Unable to generate more left start vectors");
+    if (i==0) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_PLIB,"Left initial vector is zero");
+    else SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_CONV_FAILED,"Unable to generate more left start vectors");
   }
   ierr = BVScaleColumn(eps->W,i,1.0/norm);CHKERRQ(ierr);
   PetscFunctionReturn(0);
