@@ -135,10 +135,6 @@ int main(int argc,char **argv)
          suffix: 1_trlan
          args: -eps_type trlan
          requires: trlan
-      test:
-         suffix: 1_blzpack
-         args: -eps_type blzpack -st_type sinvert -eps_target 2.7
-         requires: blzpack
       test:
          suffix: 1_scalapack
          args: -eps_type scalapack
