@@ -142,10 +142,6 @@ int main(int argc,char **argv)
         suffix: 2_blopex
         args: -eps_type blopex
         requires: blopex
-      test:
-        suffix: 2_blzpack
-        args: -eps_type blzpack
-        requires: blzpack
       test:
         suffix: 2_trlan
         args: -eps_type trlan
