@@ -121,14 +121,15 @@ int main(int argc,char **argv)
          args: -library_preload
 
    testset:
-      args: -n 30 -eps_type ciss -terse
-      requires: double
+      args: -n 30 -eps_type ciss -eps_ciss_realmats -terse
+      requires: !single
       output_file: output/ex2_ciss.out
       filter: grep -v method
       test:
          suffix: ciss_1
          nsize: 1
-         args: -rg_type interval -rg_interval_endpoints 1.1,1.25
+         args: -rg_type interval -rg_interval_endpoints 1.1,1.25,-.1,.1
+         requires: complex
       test:
          suffix: ciss_1_hpddm
          nsize: 1
@@ -138,6 +139,10 @@ int main(int argc,char **argv)
          suffix: ciss_2
          nsize: 2
          args: -rg_type ellipse -rg_ellipse_center 1.175 -rg_ellipse_radius 0.075 -eps_ciss_partitions 2
+      test:
+         suffix: ciss_2_block
+         args: -rg_type ellipse -rg_ellipse_center 1.175 -rg_ellipse_radius 0.075 -eps_ciss_blocksize 3 -eps_ciss_moments 2
+         requires: complex
       test:
          suffix: ciss_2_hpddm
          nsize: 2
