@@ -33,8 +33,7 @@ static char help[] = "Use the matrix exponential to compute rightmost eigenvalue
         tau2 = delta2/(h*L)^2
 
    but it builds A explicitly, as opposed to ex9.c
- */
-
+*/
 
 /* Routines for shell spectral transformation */
 PetscErrorCode STApply_Exp(ST,Vec,Vec);
@@ -161,7 +160,7 @@ int main(int argc,char **argv)
   ierr = MatDestroy(&A);CHKERRQ(ierr);
   if (isShell) { ierr = MFNDestroy(&mfn);CHKERRQ(ierr); }
 #else
-  SETERRQ(PETSC_COMM_WORLD,1,"This example requires C99 complex numbers");
+  SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_SUP,"This example requires C99 complex numbers");
 #endif
   ierr = SlepcFinalize();
   return ierr;
@@ -192,7 +191,7 @@ PetscErrorCode STBackTransform_Exp(ST st,PetscInt n,PetscScalar *eigr,PetscScala
 #endif
 
   PetscFunctionBeginUser;
-  ierr = STShellGetContext(st,(void**)&mfn);CHKERRQ(ierr);
+  ierr = STShellGetContext(st,&mfn);CHKERRQ(ierr);
   ierr = MFNGetFN(mfn,&fn);CHKERRQ(ierr);
   ierr = FNGetScale(fn,&tau,&eta);CHKERRQ(ierr);
   for (j=0;j<n;j++) {
@@ -227,7 +226,7 @@ PetscErrorCode STApply_Exp(ST st,Vec x,Vec y)
   PetscErrorCode ierr;
 
   PetscFunctionBeginUser;
-  ierr = STShellGetContext(st,(void**)&mfn);CHKERRQ(ierr);
+  ierr = STShellGetContext(st,&mfn);CHKERRQ(ierr);
   ierr = MFNSolve(mfn,x,y);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -260,5 +259,4 @@ PetscErrorCode STApply_Exp(ST st,Vec x,Vec y)
       requires: c99_complex !single
       filter: sed -e "s/-3.37036-3.55528i, -3.37036+3.55528i/-3.37036+3.55528i, -3.37036-3.55528i/" -e "s/-1.79853-3.03216i, -1.79853+3.03216i/-1.79853+3.03216i, -1.79853-3.03216i/" -e "s/-0.67471-2.52856i, -0.67471+2.52856i/-0.67471+2.52856i, -0.67471-2.52856i/" -e "s/0.00002-2.13950i, 0.00002+2.13950i/0.00002+2.13950i, 0.00002-2.13950i/"
 
-
 TEST*/
