@@ -35,7 +35,7 @@ int main(int argc,char **argv)
 
   ierr = PetscPrintf(PETSC_COMM_WORLD,"\nEigenproblem stored in file.\n\n");CHKERRQ(ierr);
   ierr = PetscOptionsGetString(NULL,NULL,"-file",filename,sizeof(filename),&flg);CHKERRQ(ierr);
-  if (!flg) SETERRQ(PETSC_COMM_WORLD,1,"Must indicate a file name with the -file option");
+  if (!flg) SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_USER_INPUT,"Must indicate a file name with the -file option");
 
 #if defined(PETSC_USE_COMPLEX)
   ierr = PetscPrintf(PETSC_COMM_WORLD," Reading COMPLEX matrix from a binary file...\n");CHKERRQ(ierr);
@@ -110,11 +110,16 @@ int main(int argc,char **argv)
    test:
       suffix: 1
       args: -file ${SLEPC_DIR}/share/slepc/datafiles/matrices/rdb200.petsc -eps_nev 4 -terse
-      requires: double !complex !define(PETSC_USE_64BIT_INDICES)
+      requires: double !complex !defined(PETSC_USE_64BIT_INDICES)
 
-   test:
-      suffix: ciss_1
-      args: -file ${DATAFILESPATH}/matrices/complex/qc324.petsc -eps_type ciss -rg_type ellipse -rg_ellipse_center -.012-.08i -rg_ellipse_radius .05 -terse
-      requires: double complex datafilespath !define(PETSC_USE_64BIT_INDICES)
+   testset:
+      args: -file ${DATAFILESPATH}/matrices/complex/qc324.petsc -eps_type ciss -terse
+      requires: double complex datafilespath !defined(PETSC_USE_64BIT_INDICES)
+      test:
+         suffix: ciss_1
+         args: -rg_type ellipse -rg_ellipse_center -.012-.08i -rg_ellipse_radius .05
+      test:
+         suffix: ciss_2
+         args: -rg_type interval -rg_interval_endpoints -0.062,.038,-.13,-.03 -eps_max_it 1
 
 TEST*/
