@@ -46,7 +46,7 @@ PetscErrorCode NEPSetUp_Interpol(NEP nep)
 
   PetscFunctionBegin;
   ierr = NEPSetDimensions_Default(nep,nep->nev,&nep->ncv,&nep->mpd);CHKERRQ(ierr);
-  if (nep->ncv>nep->nev+nep->mpd) SETERRQ(PetscObjectComm((PetscObject)nep),1,"The value of ncv must not be larger than nev+mpd");
+  if (nep->ncv>nep->nev+nep->mpd) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_USER_INPUT,"The value of ncv must not be larger than nev+mpd");
   if (nep->max_it==PETSC_DEFAULT) nep->max_it = PetscMax(5000,2*nep->n/nep->ncv);
   if (!nep->which) nep->which = NEP_TARGET_MAGNITUDE;
   if (nep->which!=NEP_TARGET_MAGNITUDE) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"This solver supports only target magnitude eigenvalues");
@@ -63,7 +63,7 @@ PetscErrorCode NEPSetUp_Interpol(NEP nep)
   }
   ierr = PEPSetDimensions(ctx->pep,nep->nev,nep->ncv,nep->mpd);CHKERRQ(ierr);
   ierr = PEPGetTolerances(ctx->pep,&tol,&its);CHKERRQ(ierr);
-  if (tol==PETSC_DEFAULT) tol = (nep->tol==PETSC_DEFAULT)?SLEPC_DEFAULT_TOL:nep->tol;
+  if (tol==PETSC_DEFAULT) tol = SlepcDefaultTol(nep->tol);
   if (ctx->tol==PETSC_DEFAULT) ctx->tol = tol;
   if (its==PETSC_DEFAULT) its = nep->max_it;
   ierr = PEPSetTolerances(ctx->pep,tol,its);CHKERRQ(ierr);
@@ -95,7 +95,7 @@ PetscErrorCode NEPSetUp_Interpol(NEP nep)
 /*
   Input:
     d, number of nodes to compute
-    a,b, interval extrems
+    a,b, interval extremes
   Output:
     *x, array containing the d Chebyshev nodes of the interval [a,b]
     *dct2, coefficients to compute a discrete cosine transformation (DCT-II)
@@ -331,7 +331,7 @@ static PetscErrorCode NEPInterpolGetInterpolation_Interpol(NEP nep,PetscReal *to
    Input Parameter:
 .  nep - nonlinear eigenvalue solver
 
-   Output Parameter:
+   Output Parameters:
 +  tol - tolerance to stop computing polynomial coefficients
 -  deg - maximum degree of interpolation
 
