@@ -61,16 +61,11 @@ static PetscErrorCode NEPNLEIGSAuxiliarPRootFinder(PetscInt deg,PetscScalar *pol
   PetscScalar    *C;
   PetscBLASInt   n_,lwork;
   PetscInt       i;
-#if defined(PETSC_USE_COMPLEX) || defined(PETSC_HAVE_ESSL)
+#if defined(PETSC_USE_COMPLEX)
   PetscReal      *rwork=NULL;
 #endif
-#if defined(PETSC_HAVE_ESSL)
-  PetscScalar    sdummy,*wri;
-  PetscBLASInt   idummy,io=0;
-#else
   PetscScalar    *work;
   PetscBLASInt   info;
-#endif
 
   PetscFunctionBegin;
   *avail = PETSC_TRUE;
@@ -85,7 +80,6 @@ static PetscErrorCode NEPNLEIGSAuxiliarPRootFinder(PetscInt deg,PetscScalar *pol
     ierr = PetscBLASIntCast(3*deg,&lwork);CHKERRQ(ierr);
 
     ierr = PetscFPTrapPush(PETSC_FP_TRAP_OFF);CHKERRQ(ierr);
-#if !defined(PETSC_HAVE_ESSL)
 #if !defined(PETSC_USE_COMPLEX)
     ierr = PetscMalloc1(lwork,&work);CHKERRQ(ierr);
     PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_("N","N",&n_,C,&n_,wr,wi,NULL,&n_,NULL,&n_,work,&lwork,&info));
@@ -96,19 +90,6 @@ static PetscErrorCode NEPNLEIGSAuxiliarPRootFinder(PetscInt deg,PetscScalar *pol
     PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_("N","N",&n_,C,&n_,wr,NULL,&n_,NULL,&n_,work,&lwork,rwork,&info));
     if (info) *avail = PETSC_FALSE;
     ierr = PetscFree2(rwork,work);CHKERRQ(ierr);
-#endif
-#else /* defined(PETSC_HAVE_ESSL) */
-    ierr = PetscMalloc2(lwork,&rwork,2*deg,&wri);CHKERRQ(ierr);
-    PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_(&io,C,&n_,wri,&sdummy,&idummy,&idummy,&n_,rwork,&lwork));
-#if !defined(PETSC_USE_COMPLEX)
-    for (i=0;i<deg;i++) {
-      wr[i] = wri[2*i];
-      wi[i] = wri[2*i+1];
-    }
-#else
-    for (i=0;i<deg;i++) wr[i] = wri[i];
-#endif
-    ierr = PetscFree2(rwork,wri);CHKERRQ(ierr);
 #endif
     ierr = PetscFPTrapPop();CHKERRQ(ierr);
     ierr = PetscFree(C);CHKERRQ(ierr);
@@ -280,7 +261,7 @@ static PetscErrorCode NEPNLEIGSAAAComputation(NEP nep,PetscInt ndpt,PetscScalar
     if (err <= ctx->ddtol*norm) break;
   }
 
-  if (k==ndpt-1) SETERRQ(PetscObjectComm((PetscObject)nep),1,"Failed to determine singularities automatically in general problem");
+  if (k==ndpt-1) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_CONV_FAILED,"Failed to determine singularities automatically in general problem");
   /* poles */
   ierr = PetscArrayzero(C,ndpt*ndpt);CHKERRQ(ierr);
   ierr = PetscArrayzero(A,ndpt*ndpt);CHKERRQ(ierr);
@@ -317,7 +298,7 @@ static PetscErrorCode NEPNLEIGSAAASingularities(NEP nep,PetscInt ndpt,PetscScala
 {
   PetscErrorCode ierr;
   Vec            u,v,w;
-  PetscRandom    rand;
+  PetscRandom    rand=NULL;
   PetscScalar    *F,*isol;
   PetscInt       i,k,nisol,nt;
   Mat            T;
@@ -345,7 +326,7 @@ static PetscErrorCode NEPNLEIGSAAASingularities(NEP nep,PetscInt ndpt,PetscScala
     ierr = MatCreateVecs(nep->function,&u,NULL);CHKERRQ(ierr);
     ierr = VecDuplicate(u,&v);CHKERRQ(ierr);
     ierr = VecDuplicate(u,&w);CHKERRQ(ierr);
-    ierr = BVGetRandomContext(nep->V,&rand);CHKERRQ(ierr);
+    if (nep->V) { ierr = BVGetRandomContext(nep->V,&rand);CHKERRQ(ierr); }
     ierr = VecSetRandom(u,rand);CHKERRQ(ierr);
     ierr = VecNormalize(u,NULL);CHKERRQ(ierr);
     ierr = VecSetRandom(v,rand);CHKERRQ(ierr);
@@ -389,7 +370,7 @@ static PetscErrorCode NEPNLEIGSLejaBagbyPoints(NEP nep)
     if (nep->problem_type==NEP_RATIONAL) {
       /* Select a segment in the real axis */
       ierr = RGComputeBoundingBox(nep->rg,&a,&b,NULL,NULL);CHKERRQ(ierr);
-      if (a<=-PETSC_MAX_REAL || b>=PETSC_MAX_REAL) SETERRQ(PetscObjectComm((PetscObject)nep),1,"NLEIGS requires a bounded target set");
+      if (a<=-PETSC_MAX_REAL || b>=PETSC_MAX_REAL) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_USER_INPUT,"NLEIGS requires a bounded target set");
       h = (b-a)/ndpt;
       for (i=0;i<ndpt;i++) {ds[i] = a+h*i; dsi[i] = 0.0;}
     } else SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"NLEIGS with real arithmetic requires the target set to be included in the real axis");
@@ -401,7 +382,7 @@ static PetscErrorCode NEPNLEIGSLejaBagbyPoints(NEP nep)
   } else {
     if (nep->problem_type==NEP_RATIONAL) {
       ierr = NEPNLEIGSRationalSingularities(nep,&ndptx,dxi,&rational);CHKERRQ(ierr);
-      if (!rational) SETERRQ(PetscObjectComm((PetscObject)nep),1,"Failed to determine singularities automatically in rational problem; consider solving the problem as general");
+      if (!rational) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_CONV_FAILED,"Failed to determine singularities automatically in rational problem; consider solving the problem as general");
     } else {
       /* AAA algorithm */
       ierr = NEPNLEIGSAAASingularities(nep,ndpt,ds,&ndptx,dxi);CHKERRQ(ierr);
@@ -410,7 +391,7 @@ static PetscErrorCode NEPNLEIGSLejaBagbyPoints(NEP nep)
   /* Look for Leja-Bagby points in the discretization sets */
   s[0]    = ds[0];
   xi[0]   = (ndptx>0)?dxi[0]:PETSC_INFINITY;
-  if (PetscAbsScalar(xi[0])<10*PETSC_MACHINE_EPSILON) SETERRQ2(PetscObjectComm((PetscObject)nep),1,"Singularity point %D is nearly zero: %g; consider removing the singularity or shifting the problem",0,(double)PetscAbsScalar(xi[0]));
+  if (PetscAbsScalar(xi[0])<10*PETSC_MACHINE_EPSILON) SETERRQ2(PetscObjectComm((PetscObject)nep),PETSC_ERR_USER_INPUT,"Singularity point %D is nearly zero: %g; consider removing the singularity or shifting the problem",0,(double)PetscAbsScalar(xi[0]));
   beta[0] = 1.0; /* scaling factors are also computed here */
   for (i=0;i<ndpt;i++) {
     nrs[i] = 1.0;
@@ -428,7 +409,7 @@ static PetscErrorCode NEPNLEIGSLejaBagbyPoints(NEP nep)
         nrxi[i] *= ((dxi[i]-s[k-1])/(1.0-dxi[i]/xi[k-1]))/beta[k-1];
         if (PetscAbsScalar(nrxi[i])<minnrxi) {minnrxi = PetscAbsScalar(nrxi[i]); xi[k] = dxi[i];}
       }
-      if (PetscAbsScalar(xi[k])<10*PETSC_MACHINE_EPSILON) SETERRQ2(PetscObjectComm((PetscObject)nep),1,"Singularity point %D is nearly zero: %g; consider removing the singularity or shifting the problem",k,(double)PetscAbsScalar(xi[k]));
+      if (PetscAbsScalar(xi[k])<10*PETSC_MACHINE_EPSILON) SETERRQ2(PetscObjectComm((PetscObject)nep),PETSC_ERR_USER_INPUT,"Singularity point %D is nearly zero: %g; consider removing the singularity or shifting the problem",k,(double)PetscAbsScalar(xi[k]));
     } else xi[k] = PETSC_INFINITY;
     beta[k] = maxnrs;
   }
@@ -457,7 +438,7 @@ static PetscErrorCode MatMult_Fun(Mat A,Vec x,Vec y)
   PetscInt            i;
 
   PetscFunctionBeginUser;
-  ierr = MatShellGetContext(A,(void**)&ctx);CHKERRQ(ierr);
+  ierr = MatShellGetContext(A,&ctx);CHKERRQ(ierr);
   ierr = MatMult(ctx->A[0],x,y);CHKERRQ(ierr);
   if (ctx->coeff[0]!=1.0) { ierr = VecScale(y,ctx->coeff[0]);CHKERRQ(ierr); }
   for (i=1;i<ctx->nmat;i++) {
@@ -474,7 +455,7 @@ static PetscErrorCode MatMultTranspose_Fun(Mat A,Vec x,Vec y)
   PetscInt            i;
 
   PetscFunctionBeginUser;
-  ierr = MatShellGetContext(A,(void**)&ctx);CHKERRQ(ierr);
+  ierr = MatShellGetContext(A,&ctx);CHKERRQ(ierr);
   ierr = MatMultTranspose(ctx->A[0],x,y);CHKERRQ(ierr);
   if (ctx->coeff[0]!=1.0) { ierr = VecScale(y,ctx->coeff[0]);CHKERRQ(ierr); }
   for (i=1;i<ctx->nmat;i++) {
@@ -491,7 +472,7 @@ static PetscErrorCode MatGetDiagonal_Fun(Mat A,Vec diag)
   PetscInt            i;
 
   PetscFunctionBeginUser;
-  ierr = MatShellGetContext(A,(void**)&ctx);CHKERRQ(ierr);
+  ierr = MatShellGetContext(A,&ctx);CHKERRQ(ierr);
   ierr = MatGetDiagonal(ctx->A[0],diag);CHKERRQ(ierr);
   if (ctx->coeff[0]!=1.0) { ierr = VecScale(diag,ctx->coeff[0]);CHKERRQ(ierr); }
   for (i=1;i<ctx->nmat;i++) {
@@ -503,13 +484,13 @@ static PetscErrorCode MatGetDiagonal_Fun(Mat A,Vec diag)
 
 static PetscErrorCode MatDuplicate_Fun(Mat A,MatDuplicateOption op,Mat *B)
 {
-  PetscInt            n,i;
+  PetscInt            m,n,M,N,i;
   NEP_NLEIGS_MATSHELL *ctxnew,*ctx;
   void                (*fun)(void);
   PetscErrorCode      ierr;
 
   PetscFunctionBeginUser;
-  ierr = MatShellGetContext(A,(void**)&ctx);CHKERRQ(ierr);
+  ierr = MatShellGetContext(A,&ctx);CHKERRQ(ierr);
   ierr = PetscNew(&ctxnew);CHKERRQ(ierr);
   ctxnew->nmat = ctx->nmat;
   ctxnew->maxnmat = ctx->maxnmat;
@@ -519,9 +500,10 @@ static PetscErrorCode MatDuplicate_Fun(Mat A,MatDuplicateOption op,Mat *B)
     ctxnew->A[i] = ctx->A[i];
     ctxnew->coeff[i] = ctx->coeff[i];
   }
-  ierr = MatGetSize(ctx->A[0],&n,NULL);CHKERRQ(ierr);
+  ierr = MatGetSize(ctx->A[0],&M,&N);CHKERRQ(ierr);
+  ierr = MatGetLocalSize(ctx->A[0],&m,&n);CHKERRQ(ierr);
   ierr = VecDuplicate(ctx->t,&ctxnew->t);CHKERRQ(ierr);
-  ierr = MatCreateShell(PetscObjectComm((PetscObject)A),n,n,n,n,(void*)ctxnew,B);CHKERRQ(ierr);
+  ierr = MatCreateShell(PetscObjectComm((PetscObject)A),m,n,M,N,(void*)ctxnew,B);CHKERRQ(ierr);
   ierr = MatShellSetManageScalingShifts(*B);CHKERRQ(ierr);
   ierr = MatShellGetOperation(A,MATOP_MULT,&fun);CHKERRQ(ierr);
   ierr = MatShellSetOperation(*B,MATOP_MULT,fun);CHKERRQ(ierr);
@@ -546,7 +528,7 @@ static PetscErrorCode MatDestroy_Fun(Mat A)
 
   PetscFunctionBeginUser;
   if (A) {
-    ierr = MatShellGetContext(A,(void**)&ctx);CHKERRQ(ierr);
+    ierr = MatShellGetContext(A,&ctx);CHKERRQ(ierr);
     for (i=0;i<ctx->nmat;i++) {
       ierr = MatDestroy(&ctx->A[i]);CHKERRQ(ierr);
     }
@@ -565,8 +547,8 @@ static PetscErrorCode MatAXPY_Fun(Mat Y,PetscScalar a,Mat X,MatStructure str)
   PetscBool           found;
 
   PetscFunctionBeginUser;
-  ierr = MatShellGetContext(Y,(void**)&ctxY);CHKERRQ(ierr);
-  ierr = MatShellGetContext(X,(void**)&ctxX);CHKERRQ(ierr);
+  ierr = MatShellGetContext(Y,&ctxY);CHKERRQ(ierr);
+  ierr = MatShellGetContext(X,&ctxX);CHKERRQ(ierr);
   for (i=0;i<ctxX->nmat;i++) {
     found = PETSC_FALSE;
     for (j=0;!found&&j<ctxY->nmat;j++) {
@@ -591,30 +573,31 @@ static PetscErrorCode MatScale_Fun(Mat M,PetscScalar a)
   PetscInt            i;
 
   PetscFunctionBeginUser;
-  ierr = MatShellGetContext(M,(void**)&ctx);CHKERRQ(ierr);
+  ierr = MatShellGetContext(M,&ctx);CHKERRQ(ierr);
   for (i=0;i<ctx->nmat;i++) ctx->coeff[i] *= a;
   PetscFunctionReturn(0);
 }
 
-static PetscErrorCode NLEIGSMatToMatShellArray(Mat M,Mat *Ms,PetscInt maxnmat)
+static PetscErrorCode NLEIGSMatToMatShellArray(Mat A,Mat *Ms,PetscInt maxnmat)
 {
   PetscErrorCode      ierr;
   NEP_NLEIGS_MATSHELL *ctx;
-  PetscInt            n;
+  PetscInt            m,n,M,N;
   PetscBool           has;
 
   PetscFunctionBegin;
-  ierr = MatHasOperation(M,MATOP_DUPLICATE,&has);CHKERRQ(ierr);
-  if (!has) SETERRQ(PetscObjectComm((PetscObject)M),1,"MatDuplicate operation required");
+  ierr = MatHasOperation(A,MATOP_DUPLICATE,&has);CHKERRQ(ierr);
+  if (!has) SETERRQ(PetscObjectComm((PetscObject)A),PETSC_ERR_USER,"MatDuplicate operation required");
   ierr = PetscNew(&ctx);CHKERRQ(ierr);
   ctx->maxnmat = maxnmat;
   ierr = PetscMalloc2(ctx->maxnmat,&ctx->A,ctx->maxnmat,&ctx->coeff);CHKERRQ(ierr);
-  ierr = MatDuplicate(M,MAT_COPY_VALUES,&ctx->A[0]);CHKERRQ(ierr);
+  ierr = MatDuplicate(A,MAT_COPY_VALUES,&ctx->A[0]);CHKERRQ(ierr);
   ctx->nmat = 1;
   ctx->coeff[0] = 1.0;
-  ierr = MatCreateVecs(M,&ctx->t,NULL);CHKERRQ(ierr);
-  ierr = MatGetSize(M,&n,NULL);CHKERRQ(ierr);
-  ierr = MatCreateShell(PetscObjectComm((PetscObject)M),n,n,n,n,(void*)ctx,Ms);CHKERRQ(ierr);
+  ierr = MatCreateVecs(A,&ctx->t,NULL);CHKERRQ(ierr);
+  ierr = MatGetSize(A,&M,&N);CHKERRQ(ierr);
+  ierr = MatGetLocalSize(A,&m,&n);CHKERRQ(ierr);
+  ierr = MatCreateShell(PetscObjectComm((PetscObject)A),m,n,M,N,(void*)ctx,Ms);CHKERRQ(ierr);
   ierr = MatShellSetManageScalingShifts(*Ms);CHKERRQ(ierr);
   ierr = MatShellSetOperation(*Ms,MATOP_MULT,(void(*)(void))MatMult_Fun);CHKERRQ(ierr);
   ierr = MatShellSetOperation(*Ms,MATOP_MULT_TRANSPOSE,(void(*)(void))MatMultTranspose_Fun);CHKERRQ(ierr);
@@ -626,6 +609,24 @@ static PetscErrorCode NLEIGSMatToMatShellArray(Mat M,Mat *Ms,PetscInt maxnmat)
   PetscFunctionReturn(0);
 }
 
+/*
+   MatIsShellAny - returns true if any of the n matrices is a shell matrix
+ */
+static PetscErrorCode MatIsShellAny(Mat *A,PetscInt n,PetscBool *shell)
+{
+  PetscErrorCode ierr;
+  PetscInt       i;
+  PetscBool      flg;
+
+  PetscFunctionBegin;
+  *shell = PETSC_FALSE;
+  for (i=0;i<n;i++) {
+    ierr = MatIsShell(A[i],&flg);CHKERRQ(ierr);
+    if (flg) { *shell = PETSC_TRUE; break; }
+  }
+  PetscFunctionReturn(0);
+}
+
 static PetscErrorCode NEPNLEIGSDividedDifferences_split(NEP nep)
 {
   PetscErrorCode ierr;
@@ -666,7 +667,7 @@ static PetscErrorCode NEPNLEIGSDividedDifferences_split(NEP nep)
     ierr = FNEvaluateFunctionMat(nep->f[j],H,K);
     PetscPopErrorHandler();
     if (!ierr) {
-      for (i=0;i<nmax;i++) { ctx->coeffD[j+i*nep->nt] = pK[i]*beta[0]; }
+      for (i=0;i<nmax;i++) ctx->coeffD[j+i*nep->nt] = pK[i]*beta[0];
     } else {
       matrix = PETSC_FALSE;
       ierr = PetscFPTrapPop();CHKERRQ(ierr);
@@ -712,7 +713,7 @@ static PetscErrorCode NEPNLEIGSDividedDifferences_split(NEP nep)
     }
   }
   if (!ctx->ksp) { ierr = NEPNLEIGSGetKSPs(nep,&ctx->nshiftsw,&ctx->ksp);CHKERRQ(ierr); }
-  ierr = MatIsShell(nep->A[0],&shell);CHKERRQ(ierr);
+  ierr = MatIsShellAny(nep->A,nep->nt,&shell);CHKERRQ(ierr);
   maxnmat = PetscMax(ctx->ddmaxit,nep->nt);
   for (i=0;i<ctx->nshiftsw;i++) {
     ierr = NEPNLEIGSEvalNRTFunct(nep,ctx->nmat-1,ctx->shifts[i],coeffs);CHKERRQ(ierr);
@@ -753,12 +754,12 @@ static PetscErrorCode NEPNLEIGSDividedDifferences_callback(NEP nep)
   PetscScalar    *s=ctx->s,*beta=ctx->beta,*b,*coeffs;
   Mat            *D=ctx->D,T;
   PetscBool      shell,has,vec=PETSC_FALSE;
-  PetscRandom    rand;
+  PetscRandom    rand=NULL;
   Vec            w[2];
 
   PetscFunctionBegin;
   ierr = PetscMalloc2(ctx->ddmaxit+1,&b,ctx->ddmaxit+1,&coeffs);CHKERRQ(ierr);
-  ierr = BVGetRandomContext(nep->V,&rand);CHKERRQ(ierr);
+  if (nep->V) { ierr = BVGetRandomContext(nep->V,&rand);CHKERRQ(ierr); }
   T = nep->function;
   ierr = NEPComputeFunction(nep,s[0],T,T);CHKERRQ(ierr);
   ierr = MatIsShell(T,&shell);CHKERRQ(ierr);
@@ -891,7 +892,7 @@ PetscErrorCode NEPSetUp_NLEIGS(NEP nep)
 
   PetscFunctionBegin;
   ierr = NEPSetDimensions_Default(nep,nep->nev,&nep->ncv,&nep->mpd);CHKERRQ(ierr);
-  if (nep->ncv>nep->nev+nep->mpd) SETERRQ(PetscObjectComm((PetscObject)nep),1,"The value of ncv must not be larger than nev+mpd");
+  if (nep->ncv>nep->nev+nep->mpd) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_USER_INPUT,"The value of ncv must not be larger than nev+mpd");
   if (nep->max_it==PETSC_DEFAULT) nep->max_it = PetscMax(5000,2*nep->n/nep->ncv);
   if (!ctx->ddmaxit) ctx->ddmaxit = LBPOINTS;
   ierr = RGIsTrivial(nep->rg,&istrivial);CHKERRQ(ierr);
@@ -970,7 +971,7 @@ static PetscErrorCode NEPTOARExtendBasis(NEP nep,PetscInt idxrktg,PetscScalar *S
   sigma = ctx->shifts[idxrktg];
   ierr = BVSetActiveColumns(nep->V,0,nv);CHKERRQ(ierr);
   ierr = PetscMalloc1(ctx->nmat,&coeffs);CHKERRQ(ierr);
-  if (PetscAbsScalar(s[deg-2]-sigma)<100*PETSC_MACHINE_EPSILON) SETERRQ(PETSC_COMM_SELF,1,"Breakdown in NLEIGS");
+  if (PetscAbsScalar(s[deg-2]-sigma)<100*PETSC_MACHINE_EPSILON) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_CONV_FAILED,"Breakdown in NLEIGS");
   /* i-part stored in (i-1) position */
   for (j=0;j<nv;j++) {
     r[(deg-2)*lr+j] = (S[(deg-2)*ls+j]+(beta[deg-1]/xi[deg-2])*S[(deg-1)*ls+j])/(s[deg-2]-sigma);
@@ -983,7 +984,7 @@ static PetscErrorCode NEPTOARExtendBasis(NEP nep,PetscInt idxrktg,PetscScalar *S
   ierr = BVMultVec(V,1.0,0.0,w,r+(deg-2)*lr);CHKERRQ(ierr);
   ierr = BVRestoreColumn(W,deg-2,&w);CHKERRQ(ierr);
   for (k=deg-2;k>0;k--) {
-    if (PetscAbsScalar(s[k-1]-sigma)<100*PETSC_MACHINE_EPSILON) SETERRQ(PETSC_COMM_SELF,1,"Breakdown in NLEIGS");
+    if (PetscAbsScalar(s[k-1]-sigma)<100*PETSC_MACHINE_EPSILON) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_CONV_FAILED,"Breakdown in NLEIGS");
     for (j=0;j<nv;j++) r[(k-1)*lr+j] = (S[(k-1)*ls+j]+(beta[k]/xi[k-1])*S[k*ls+j]-beta[k]*(1.0-sigma/xi[k-1])*r[(k)*lr+j])/(s[k-1]-sigma);
     ierr = BVGetColumn(W,k-1,&w);CHKERRQ(ierr);
     ierr = BVMultVec(V,1.0,0.0,w,r+(k-1)*lr);CHKERRQ(ierr);
@@ -1183,7 +1184,6 @@ PetscErrorCode NEPSolve_NLEIGS(NEP nep)
   } else { eigr = nep->eigr; eigi = nep->eigi; }
   ierr = BVDuplicateResize(nep->V,PetscMax(nep->nt-1,ctx->nmat-1),&W);CHKERRQ(ierr);
 
-
   /* clean projected matrix (including the extra-arrow) */
   ierr = DSGetArray(nep->ds,DS_MAT_A,&H);CHKERRQ(ierr);
   ierr = PetscArrayzero(H,ldds*ldds);CHKERRQ(ierr);
@@ -1213,7 +1213,7 @@ PetscErrorCode NEPSolve_NLEIGS(NEP nep)
       betak = K[(nv-1)*ldds+nv];
       ierr = DSRestoreArray(nep->ds,DS_MAT_A,&K);CHKERRQ(ierr);
     }
-    ierr = DSSetDimensions(nep->ds,nv,0,nep->nconv,nep->nconv+l);CHKERRQ(ierr);
+    ierr = DSSetDimensions(nep->ds,nv,nep->nconv,nep->nconv+l);CHKERRQ(ierr);
     if (l==0) {
       ierr = DSSetState(nep->ds,DS_STATE_INTERMEDIATE);CHKERRQ(ierr);
     } else {
@@ -1237,8 +1237,8 @@ PetscErrorCode NEPSolve_NLEIGS(NEP nep)
       ierr = DSGetTruncateSize(nep->ds,k,nv,&l);CHKERRQ(ierr);
       if (!breakdown) {
         /* Prepare the Rayleigh quotient for restart */
-        ierr = DSGetDimensions(nep->ds,&dsn,NULL,NULL,&dsk,NULL);CHKERRQ(ierr);
-        ierr = DSSetDimensions(nep->ds,dsn,0,k,dsk);CHKERRQ(ierr);
+        ierr = DSGetDimensions(nep->ds,&dsn,NULL,&dsk,NULL);CHKERRQ(ierr);
+        ierr = DSSetDimensions(nep->ds,dsn,k,dsk);CHKERRQ(ierr);
         ierr = DSTruncate(nep->ds,k+l,PETSC_FALSE);CHKERRQ(ierr);
       }
     }
@@ -1647,7 +1647,7 @@ static PetscErrorCode NEPNLEIGSGetInterpolation_NLEIGS(NEP nep,PetscReal *tol,Pe
    Input Parameter:
 .  nep - the nonlinear eigensolver context
 
-   Output Parameter:
+   Output Parameters:
 +  tol    - tolerance to stop computing divided differences
 -  degree - maximum degree of interpolation
 
@@ -1723,7 +1723,7 @@ PetscErrorCode NEPNLEIGSSetRKShifts(NEP nep,PetscInt ns,PetscScalar shifts[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
   PetscValidLogicalCollectiveInt(nep,ns,2);
-  if (ns) PetscValidScalarPointer(nep,shifts);
+  if (ns) PetscValidScalarPointer(shifts,3);
   ierr = PetscTryMethod(nep,"NEPNLEIGSSetRKShifts_C",(NEP,PetscInt,PetscScalar*),(nep,ns,shifts));CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -1752,7 +1752,7 @@ static PetscErrorCode NEPNLEIGSGetRKShifts_NLEIGS(NEP nep,PetscInt *ns,PetscScal
    Input Parameter:
 .  nep - the nonlinear eigensolver context
 
-   Output Parameter:
+   Output Parameters:
 +  ns     - number of shifts
 -  shifts - array of shifts
 
@@ -1769,8 +1769,8 @@ PetscErrorCode NEPNLEIGSGetRKShifts(NEP nep,PetscInt *ns,PetscScalar *shifts[])
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
-  PetscValidIntPointer(nep,ns);
-  PetscValidPointer(nep,shifts);
+  PetscValidIntPointer(ns,2);
+  PetscValidPointer(shifts,3);
   ierr = PetscTryMethod(nep,"NEPNLEIGSGetRKShifts_C",(NEP,PetscInt*,PetscScalar**),(nep,ns,shifts));CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -1794,7 +1794,7 @@ static PetscErrorCode NEPNLEIGSGetKSPs_NLEIGS(NEP nep,PetscInt *nsolve,KSP **ksp
       ierr = PetscLogObjectParent((PetscObject)nep,(PetscObject)ctx->ksp[i]);CHKERRQ(ierr);
       ierr = PetscObjectSetOptions((PetscObject)ctx->ksp[i],((PetscObject)nep)->options);CHKERRQ(ierr);
       ierr = KSPSetErrorIfNotConverged(ctx->ksp[i],PETSC_TRUE);CHKERRQ(ierr);
-      ierr = KSPSetTolerances(ctx->ksp[i],SLEPC_DEFAULT_TOL,PETSC_DEFAULT,PETSC_DEFAULT,PETSC_DEFAULT);CHKERRQ(ierr);
+      ierr = KSPSetTolerances(ctx->ksp[i],SlepcDefaultTol(nep->tol),PETSC_DEFAULT,PETSC_DEFAULT,PETSC_DEFAULT);CHKERRQ(ierr);
       ierr = KSPGetPC(ctx->ksp[i],&pc);CHKERRQ(ierr);
       ierr = KSPSetType(ctx->ksp[i],KSPPREONLY);CHKERRQ(ierr);
       ierr = PCSetType(pc,PCLU);CHKERRQ(ierr);
