@@ -15,6 +15,7 @@ static PetscBool NEPPackageInitialized = PETSC_FALSE;
 const char *NEPErrorTypes[] = {"ABSOLUTE","RELATIVE","BACKWARD","NEPErrorType","NEP_ERROR_",0};
 const char *NEPRefineTypes[] = {"NONE","SIMPLE","MULTIPLE","NEPRefine","NEP_REFINE_",0};
 const char *NEPRefineSchemes[] = {"","SCHUR","MBE","EXPLICIT","NEPRefineScheme","NEP_REFINE_SCHEME_",0};
+const char *NEPCISSExtractions[] = {"RITZ","HANKEL","CAA","NEPCISSExtraction","NEP_CISS_EXTRACTION_",0};
 const char *const NEPConvergedReasons_Shifted[] = {"DIVERGED_SUBSPACE_EXHAUSTED","DIVERGED_LINEAR_SOLVE","","DIVERGED_BREAKDOWN","DIVERGED_ITS","CONVERGED_ITERATING","CONVERGED_TOL","CONVERGED_USER","NEPConvergedReason","NEP_",0};
 const char *const*NEPConvergedReasons = NEPConvergedReasons_Shifted + 5;
 
@@ -73,6 +74,7 @@ PetscErrorCode NEPInitializePackage(void)
   ierr = PetscLogEventRegister("NEPFunctionEval",NEP_CLASSID,&NEP_FunctionEval);CHKERRQ(ierr);
   ierr = PetscLogEventRegister("NEPJacobianEval",NEP_CLASSID,&NEP_JacobianEval);CHKERRQ(ierr);
   ierr = PetscLogEventRegister("NEPResolvent",NEP_CLASSID,&NEP_Resolvent);CHKERRQ(ierr);
+  ierr = PetscLogEventRegister("NEPCISS_SVD",NEP_CLASSID,&NEP_CISS_SVD);CHKERRQ(ierr);
   /* Process Info */
   classids[0] = NEP_CLASSID;
   ierr = PetscInfoProcessClass("nep",1,&classids[0]);CHKERRQ(ierr);
