@@ -15,7 +15,7 @@
 
 /* Logging support */
 PetscClassId      NEP_CLASSID = 0;
-PetscLogEvent     NEP_SetUp = 0,NEP_Solve = 0,NEP_Refine = 0,NEP_FunctionEval = 0,NEP_JacobianEval = 0,NEP_Resolvent = 0;
+PetscLogEvent     NEP_SetUp = 0,NEP_Solve = 0,NEP_Refine = 0,NEP_FunctionEval = 0,NEP_JacobianEval = 0,NEP_Resolvent = 0,NEP_CISS_SVD = 0;
 
 /* List of registered NEP routines */
 PetscFunctionList NEPList = 0;
@@ -60,7 +60,7 @@ PetscErrorCode NEPCreate(MPI_Comm comm,NEP *outnep)
   nep->nini            = 0;
   nep->target          = 0.0;
   nep->tol             = PETSC_DEFAULT;
-  nep->conv            = NEP_CONV_NORM;
+  nep->conv            = NEP_CONV_REL;
   nep->stop            = NEP_STOP_BASIC;
   nep->which           = (NEPWhich)0;
   nep->problem_type    = (NEPProblemType)0;
@@ -462,8 +462,10 @@ PetscErrorCode NEPSetRG(NEP nep,RG rg)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
-  PetscValidHeaderSpecific(rg,RG_CLASSID,2);
-  PetscCheckSameComm(nep,1,rg,2);
+  if (rg) {
+    PetscValidHeaderSpecific(rg,RG_CLASSID,2);
+    PetscCheckSameComm(nep,1,rg,2);
+  }
   ierr = PetscObjectReference((PetscObject)rg);CHKERRQ(ierr);
   ierr = RGDestroy(&nep->rg);CHKERRQ(ierr);
   nep->rg = rg;
@@ -606,7 +608,7 @@ PetscErrorCode NEPRefineGetKSP(NEP nep,KSP *ksp)
     ierr = PetscObjectSetOptions((PetscObject)nep->refineksp,((PetscObject)nep)->options);CHKERRQ(ierr);
     ierr = KSPSetOptionsPrefix(*ksp,((PetscObject)nep)->prefix);CHKERRQ(ierr);
     ierr = KSPAppendOptionsPrefix(*ksp,"nep_refine_");CHKERRQ(ierr);
-    ierr = KSPSetTolerances(nep->refineksp,SLEPC_DEFAULT_TOL,PETSC_DEFAULT,PETSC_DEFAULT,PETSC_DEFAULT);CHKERRQ(ierr);
+    ierr = KSPSetTolerances(nep->refineksp,SlepcDefaultTol(nep->rtol),PETSC_DEFAULT,PETSC_DEFAULT,PETSC_DEFAULT);CHKERRQ(ierr);
   }
   *ksp = nep->refineksp;
   PetscFunctionReturn(0);
@@ -681,7 +683,7 @@ PetscErrorCode NEPGetTarget(NEP nep,PetscScalar* target)
    Input Parameters:
 +  nep - the NEP context
 .  A   - Function matrix
-.  B   - preconditioner matrix (usually same as the Function)
+.  B   - preconditioner matrix (usually same as A)
 .  fun - Function evaluation routine (if NULL then NEP retains any
          previously set value)
 -  ctx - [optional] user-defined context for private data for the Function
@@ -764,7 +766,7 @@ PetscErrorCode NEPGetFunction(NEP nep,Mat *A,Mat *B,PetscErrorCode (**fun)(NEP,P
 }
 
 /*@C
-   NEPSetJacobian - Sets the function to compute Jacobian T'(lambda) as well
+   NEPSetJacobian - Sets the function to compute the Jacobian T'(lambda) as well
    as the location to store the matrix.
 
    Logically Collective on nep
@@ -929,7 +931,7 @@ PetscErrorCode NEPSetSplitOperator(NEP nep,PetscInt nt,Mat A[],FN f[],MatStructu
 
    Not collective, though parallel Mats and FNs are returned if the NEP is parallel
 
-   Input Parameter:
+   Input Parameters:
 +  nep - the nonlinear eigensolver context
 -  k   - the index of the requested term (starting in 0)
 
