@@ -18,7 +18,7 @@
 */
 
 #include <slepc/private/nepimpl.h>       /*I "slepcnep.h" I*/
-#include <slepc/private/bvimpl.h>        /*I "slepcbv.h" I*/
+#include <slepc/private/bvimpl.h>
 #include <petscdraw.h>
 
 static PetscBool  cited = PETSC_FALSE;
@@ -27,9 +27,11 @@ static const char citation[] =
   "   author = \"C. Campos and J. E. Roman\",\n"
   "   title = \"{NEP}: a module for the parallel solution of nonlinear eigenvalue problems in {SLEPc}\",\n"
   "   journal = \"{ACM} Trans. Math. Software\",\n"
-  "   note = \"To appear\",\n"
-  "   url = \"https://arxiv.org/abs/1910.11712\",\n"
-  "   year = \"2021\"\n"
+  "   volume = \"47\",\n"
+  "   number = \"3\",\n"
+  "   pages = \"23:1--23:29\",\n"
+  "   year = \"2021\",\n"
+  "   doi = \"10.1145/3447544\"\n"
   "}\n";
 
 PetscErrorCode NEPComputeVectors(NEP nep)
@@ -181,8 +183,8 @@ PetscErrorCode NEPProjectOperator(NEP nep,PetscInt j0,PetscInt j1)
 
    Output Parameters:
 +  y   - result vector
-.  A   - Function matrix
--  B   - optional preconditioning matrix
+.  A   - (optional) Function matrix, for callback interface only
+-  B   - (unused) preconditioning matrix
 
    Note:
    If the nonlinear operator is represented in split form, the result
@@ -218,7 +220,8 @@ PetscErrorCode NEPApplyFunction(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
       ierr = VecAXPY(y,alpha,v);CHKERRQ(ierr);
     }
   } else {
-    ierr = NEPComputeFunction(nep,lambda,A,B);CHKERRQ(ierr);
+    if (!A) A = nep->function;
+    ierr = NEPComputeFunction(nep,lambda,A,A);CHKERRQ(ierr);
     ierr = MatMult(A,x,y);CHKERRQ(ierr);
   }
   PetscFunctionReturn(0);
@@ -237,8 +240,8 @@ PetscErrorCode NEPApplyFunction(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
 
    Output Parameters:
 +  y   - result vector
-.  A   - Function matrix
--  B   - optional preconditioning matrix
+.  A   - (optional) Function matrix, for callback interface only
+-  B   - (unused) preconditioning matrix
 
    Level: developer
 
@@ -249,6 +252,7 @@ PetscErrorCode NEPApplyAdjoint(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
   PetscErrorCode ierr;
   PetscInt       i;
   PetscScalar    alpha;
+  Vec            w;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
@@ -259,19 +263,22 @@ PetscErrorCode NEPApplyAdjoint(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
   if (A) PetscValidHeaderSpecific(A,MAT_CLASSID,6);
   if (B) PetscValidHeaderSpecific(B,MAT_CLASSID,7);
 
-  ierr = VecConjugate(x);CHKERRQ(ierr);
+  ierr = VecDuplicate(x,&w);CHKERRQ(ierr);
+  ierr = VecCopy(x,w);CHKERRQ(ierr);
+  ierr = VecConjugate(w);CHKERRQ(ierr);
   if (nep->fui==NEP_USER_INTERFACE_SPLIT) {
     ierr = VecSet(y,0.0);CHKERRQ(ierr);
     for (i=0;i<nep->nt;i++) {
       ierr = FNEvaluateFunction(nep->f[i],lambda,&alpha);CHKERRQ(ierr);
-      ierr = MatMultTranspose(nep->A[i],x,v);CHKERRQ(ierr);
+      ierr = MatMultTranspose(nep->A[i],w,v);CHKERRQ(ierr);
       ierr = VecAXPY(y,alpha,v);CHKERRQ(ierr);
     }
   } else {
-    ierr = NEPComputeFunction(nep,lambda,A,B);CHKERRQ(ierr);
-    ierr = MatMultTranspose(A,x,y);CHKERRQ(ierr);
+    if (!A) A = nep->function;
+    ierr = NEPComputeFunction(nep,lambda,A,A);CHKERRQ(ierr);
+    ierr = MatMultTranspose(A,w,y);CHKERRQ(ierr);
   }
-  ierr = VecConjugate(x);CHKERRQ(ierr);
+  ierr = VecDestroy(&w);CHKERRQ(ierr);
   ierr = VecConjugate(y);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -289,7 +296,7 @@ PetscErrorCode NEPApplyAdjoint(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
 
    Output Parameters:
 +  y   - result vector
--  A   - Jacobian matrix
+-  A   - (optional) Jacobian matrix, for callback interface only
 
    Note:
    If the nonlinear operator is represented in split form, the result
@@ -324,6 +331,7 @@ PetscErrorCode NEPApplyJacobian(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
       ierr = VecAXPY(y,alpha,v);CHKERRQ(ierr);
     }
   } else {
+    if (!A) A = nep->jacobian;
     ierr = NEPComputeJacobian(nep,lambda,A);CHKERRQ(ierr);
     ierr = MatMult(A,x,y);CHKERRQ(ierr);
   }
@@ -554,7 +562,7 @@ PetscErrorCode NEPGetLeftEigenvector(NEP nep,PetscInt i,Vec Wr,Vec Wi)
 
    Not Collective
 
-   Input Parameter:
+   Input Parameters:
 +  nep - nonlinear eigensolver context
 -  i   - index of eigenpair
 
@@ -599,9 +607,9 @@ PetscErrorCode NEPComputeResidualNorm_Private(NEP nep,PetscBool adj,PetscScalar
   y = w[0];
   if (nep->fui==NEP_USER_INTERFACE_SPLIT) z = w[1];
   if (adj) {
-    ierr = NEPApplyAdjoint(nep,lambda,x,z,y,nep->function,nep->function_pre);CHKERRQ(ierr);
+    ierr = NEPApplyAdjoint(nep,lambda,x,z,y,NULL,NULL);CHKERRQ(ierr);
   } else {
-    ierr = NEPApplyFunction(nep,lambda,x,z,y,nep->function,nep->function_pre);CHKERRQ(ierr);
+    ierr = NEPApplyFunction(nep,lambda,x,z,y,NULL,NULL);CHKERRQ(ierr);
   }
   ierr = VecNorm(y,NORM_2,norm);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -613,7 +621,7 @@ PetscErrorCode NEPComputeResidualNorm_Private(NEP nep,PetscBool adj,PetscScalar
 
    Collective on nep
 
-   Input Parameter:
+   Input Parameters:
 +  nep  - the nonlinear eigensolver context
 .  i    - the solution index
 -  type - the type of error to compute
@@ -665,7 +673,7 @@ PetscErrorCode NEPComputeError(NEP nep,PetscInt i,NEPErrorType type,PetscReal *e
   /* compute residual norms */
   ierr = NEPGetEigenpair(nep,i,&kr,&ki,xr,xi);CHKERRQ(ierr);
 #if !defined(PETSC_USE_COMPLEX)
-  if (ki) SETERRQ(PetscObjectComm((PetscObject)nep),1,"Not implemented for complex eigenvalues with real scalars");
+  if (ki) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"Not implemented for complex eigenvalues with real scalars");
 #endif
   ierr = NEPComputeResidualNorm_Private(nep,PETSC_FALSE,kr,xr,nep->work,error);CHKERRQ(ierr);
   ierr = VecNorm(xr,NORM_2,&er);CHKERRQ(ierr);
@@ -760,7 +768,7 @@ PetscErrorCode NEPComputeFunction(NEP nep,PetscScalar lambda,Mat A,Mat B)
       ierr = FNEvaluateFunction(nep->f[i],lambda,&alpha);CHKERRQ(ierr);
       ierr = MatAXPY(A,alpha,nep->A[i],nep->mstr);CHKERRQ(ierr);
     }
-    if (A != B) SETERRQ(PetscObjectComm((PetscObject)nep),1,"Not implemented");
+    if (A != B) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"Not implemented");
     break;
   }
   PetscFunctionReturn(0);
