@@ -190,6 +190,11 @@ int main(int argc,char **argv)
       filter: sed -e "s/[+-]0\.0*i//g"
       requires: !single
 
+   test:
+      suffix: 1_ciss
+      args: -nep_type ciss -nep_ciss_extraction {{ritz hankel caa}} -rg_type ellipse -rg_ellipse_center 10 -rg_ellipse_radius 9.5 -nep_ncv 24 -terse
+      requires: complex !single
+
    test:
       suffix: 2
       args: -nep_type interpol -nep_interpol_pep_extract {{none norm residual}} -rg_type interval -rg_interval_endpoints 5,20,-.1,.1 -nep_nev 3 -nep_target 5 -terse
