@@ -209,7 +209,7 @@ static PetscErrorCode PEPJDUpdateTV(PEP pep,PetscInt low,PetscInt high,Vec *w)
   t2 = w[1];
   ierr = PetscBLASIntCast(pjd->nlock,&n_);CHKERRQ(ierr);
   ierr = PetscBLASIntCast(pjd->ld,&ld_);CHKERRQ(ierr);
-  if (nconv){
+  if (nconv) {
     for (i=0;i<nconv;i++) {
       ierr = PetscArraycpy(pT+i*nconv,pjd->T+i*pep->ncv,nconv);CHKERRQ(ierr);
     }
@@ -358,7 +358,7 @@ static PetscErrorCode PEPJDExtendedPCApply(PC pc,Vec x,Vec y)
 
   PetscFunctionBegin;
   ierr = MPI_Comm_size(PetscObjectComm((PetscObject)pc),&np);CHKERRMPI(ierr);
-  ierr = PCShellGetContext(pc,(void**)&ctx);CHKERRQ(ierr);
+  ierr = PCShellGetContext(pc,&ctx);CHKERRQ(ierr);
   n  = ctx->n;
   if (n) {
     pjd = (PEP_JD*)ctx->pep->data;
@@ -425,7 +425,7 @@ static PetscErrorCode PCShellApply_PEPJD(PC pc,Vec x,Vec y)
 #endif
 
   PetscFunctionBegin;
-  ierr = PCShellGetContext(pc,(void**)&ctx);CHKERRQ(ierr);
+  ierr = PCShellGetContext(pc,&ctx);CHKERRQ(ierr);
   ierr = VecCompGetSubVecs(x,&sz,&xs);CHKERRQ(ierr);
   ierr = VecCompGetSubVecs(y,NULL,&ys);CHKERRQ(ierr);
   /* y = B\x apply extended PC */
@@ -756,7 +756,7 @@ static PetscErrorCode MatMult_PEPJD(Mat P,Vec x,Vec y)
 
   PetscFunctionBegin;
   ierr = MPI_Comm_size(PetscObjectComm((PetscObject)P),&np);CHKERRMPI(ierr);
-  ierr  = MatShellGetContext(P,(void**)&matctx);CHKERRQ(ierr);
+  ierr  = MatShellGetContext(P,&matctx);CHKERRQ(ierr);
   pjd   = (PEP_JD*)(matctx->pep->data);
   nconv = pjd->nlock;
   nmat  = matctx->pep->nmat;
@@ -889,12 +889,12 @@ static PetscErrorCode MatCreateVecs_PEPJD(Mat A,Vec *right,Vec *left)
   Vec             v[2];
 
   PetscFunctionBegin;
-  ierr  = MatShellGetContext(A,(void**)&matctx);CHKERRQ(ierr);
+  ierr  = MatShellGetContext(A,&matctx);CHKERRQ(ierr);
   pjd   = (PEP_JD*)(matctx->pep->data);
 #if !defined (PETSC_USE_COMPLEX)
   kspsf = 2;
 #endif
-  for (i=0;i<kspsf;i++){
+  for (i=0;i<kspsf;i++) {
     ierr = BVCreateVec(pjd->V,v+i);CHKERRQ(ierr);
   }
   if (right) {
@@ -921,7 +921,7 @@ static PetscErrorCode PEPJDUpdateExtendedPC(PEP pep,PetscScalar theta)
 
   PetscFunctionBegin;
   if (n) {
-    ierr = PCShellGetContext(pjd->pcshell,(void**)&pcctx);CHKERRQ(ierr);
+    ierr = PCShellGetContext(pjd->pcshell,&pcctx);CHKERRQ(ierr);
     pcctx->theta = theta;
     pcctx->n = n;
     M  = pcctx->M;
@@ -1000,8 +1000,8 @@ static PetscErrorCode PEPJDMatSetUp(PEP pep,PetscInt sz,PetscScalar *theta)
 
   PetscFunctionBegin;
   if (sz==2 && theta[1]==0.0) sz = 1;
-  ierr = MatShellGetContext(pjd->Pshell,(void**)&matctx);CHKERRQ(ierr);
-  ierr = PCShellGetContext(pjd->pcshell,(void**)&pcctx);CHKERRQ(ierr);
+  ierr = MatShellGetContext(pjd->Pshell,&matctx);CHKERRQ(ierr);
+  ierr = PCShellGetContext(pjd->pcshell,&pcctx);CHKERRQ(ierr);
   if (matctx->Pr && matctx->theta[0]==theta[0] && ((!matctx->Pi && sz==1) || (sz==2 && matctx->theta[1]==theta[1]))) {
     if (pcctx->n == pjd->nlock) PetscFunctionReturn(0);
     skipmat = PETSC_TRUE;
@@ -1260,7 +1260,7 @@ PetscErrorCode PEPJDSystemSetUp(PEP pep,PetscInt sz,PetscScalar *theta,Vec *u,Ve
 #endif
 
   PetscFunctionBegin;
-  ierr = PCShellGetContext(pjd->pcshell,(void**)&pcctx);CHKERRQ(ierr);
+  ierr = PCShellGetContext(pjd->pcshell,&pcctx);CHKERRQ(ierr);
   ierr = PEPJDMatSetUp(pep,sz,theta);CHKERRQ(ierr);
   pcctx->u[0] = u[0]; pcctx->u[1] = u[1];
   /* Compute r'. p is a work space vector */
@@ -1319,9 +1319,9 @@ PetscErrorCode PEPSolve_JD(PEP pep)
 
   /* Replace preconditioner with one containing projectors */
   ierr = PEPJDCreateShellPC(pep,ww);CHKERRQ(ierr);
-  ierr = PCShellGetContext(pjd->pcshell,(void**)&pcctx);CHKERRQ(ierr);
+  ierr = PCShellGetContext(pjd->pcshell,&pcctx);CHKERRQ(ierr);
 
-  /* Create auxiliar vectors */
+  /* Create auxiliary vectors */
   ierr = BVCreateVec(pjd->V,&u[0]);CHKERRQ(ierr);
   ierr = VecDuplicate(u[0],&p[0]);CHKERRQ(ierr);
   ierr = VecDuplicate(u[0],&r[0]);CHKERRQ(ierr);
@@ -1334,7 +1334,7 @@ PetscErrorCode PEPSolve_JD(PEP pep)
   /* Restart loop */
   while (pep->reason == PEP_CONVERGED_ITERATING) {
     pep->its++;
-    ierr = DSSetDimensions(pep->ds,nv,0,0,0);CHKERRQ(ierr);
+    ierr = DSSetDimensions(pep->ds,nv,0,0);CHKERRQ(ierr);
     ierr = BVSetActiveColumns(pjd->V,bupdated,nv);CHKERRQ(ierr);
     ierr = PEPJDUpdateTV(pep,bupdated,nv,ww);CHKERRQ(ierr);
     if (pjd->proj==PEP_JD_PROJECTION_HARMONIC) { ierr = BVSetActiveColumns(pjd->W,bupdated,nv);CHKERRQ(ierr); }
@@ -1432,7 +1432,7 @@ PetscErrorCode PEPSolve_JD(PEP pep)
       if (nv+sz>=pep->ncv-1) {
         /* Basis full, force restart */
         minv = PetscMin(nv,(PetscInt)(pjd->keep*pep->ncv));
-        ierr = DSGetDimensions(pep->ds,&dim,NULL,NULL,NULL,NULL);CHKERRQ(ierr);
+        ierr = DSGetDimensions(pep->ds,&dim,NULL,NULL,NULL);CHKERRQ(ierr);
         ierr = DSGetArray(pep->ds,DS_MAT_X,&pX);CHKERRQ(ierr);
         ierr = PEPJDOrthogonalize(dim,minv,pX,ld,&minv,NULL,NULL,ld);CHKERRQ(ierr);
         ierr = DSRestoreArray(pep->ds,DS_MAT_X,&pX);CHKERRQ(ierr);
@@ -1479,7 +1479,7 @@ PetscErrorCode PEPSolve_JD(PEP pep)
         ierr = BVRestoreColumn(pjd->V,nv,&t[0]);CHKERRQ(ierr);
         ierr = BVOrthogonalizeColumn(pjd->V,nv,NULL,&norm,&lindep);CHKERRQ(ierr);
         if (lindep || norm==0.0) {
-          if (sz==1) SETERRQ(PETSC_COMM_SELF,1,"Linearly dependent continuation vector");
+          if (sz==1) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_CONV_FAILED,"Linearly dependent continuation vector");
           else off = 1;
         } else {
           off = 0;
@@ -1496,7 +1496,7 @@ PetscErrorCode PEPSolve_JD(PEP pep)
           }
           ierr = BVOrthogonalizeColumn(pjd->V,nv+1-off,NULL,&norm,&lindep);CHKERRQ(ierr);
           if (lindep || norm==0.0) {
-            if (off) SETERRQ(PETSC_COMM_SELF,1,"Linearly dependent continuation vector");
+            if (off) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_CONV_FAILED,"Linearly dependent continuation vector");
             else off = 1;
           } else {
             ierr = BVScaleColumn(pjd->V,nv+1-off,1.0/norm);CHKERRQ(ierr);
@@ -1509,11 +1509,11 @@ PetscErrorCode PEPSolve_JD(PEP pep)
             ierr = BVInsertVec(pjd->W,nv+1,r[1]);CHKERRQ(ierr);
           }
           ierr = BVOrthogonalizeColumn(pjd->W,nv,NULL,&norm,&lindep);CHKERRQ(ierr);
-          if (lindep || norm==0.0) SETERRQ(PETSC_COMM_SELF,1,"Linearly dependent continuation vector");
+          if (lindep || norm==0.0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_CONV_FAILED,"Linearly dependent continuation vector");
           ierr = BVScaleColumn(pjd->W,nv,1.0/norm);CHKERRQ(ierr);
           if (sz==2 && !off) {
             ierr = BVOrthogonalizeColumn(pjd->W,nv+1,NULL,&norm,&lindep);CHKERRQ(ierr);
-            if (lindep || norm==0.0) SETERRQ(PETSC_COMM_SELF,1,"Linearly dependent continuation vector");
+            if (lindep || norm==0.0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_CONV_FAILED,"Linearly dependent continuation vector");
             ierr = BVScaleColumn(pjd->W,nv+1,1.0/norm);CHKERRQ(ierr);
           }
         }
@@ -1549,7 +1549,7 @@ PetscErrorCode PEPSolve_JD(PEP pep)
   ierr = KSPSetPC(ksp,pcctx->pc);CHKERRQ(ierr);
   ierr = VecDestroy(&pcctx->Bp[0]);CHKERRQ(ierr);
   ierr = VecDestroy(&pcctx->Bp[1]);CHKERRQ(ierr);
-  ierr = MatShellGetContext(pjd->Pshell,(void**)&matctx);CHKERRQ(ierr);
+  ierr = MatShellGetContext(pjd->Pshell,&matctx);CHKERRQ(ierr);
   ierr = MatDestroy(&matctx->Pr);CHKERRQ(ierr);
   ierr = MatDestroy(&matctx->Pi);CHKERRQ(ierr);
   ierr = MatDestroy(&pjd->Pshell);CHKERRQ(ierr);
