@@ -171,8 +171,7 @@ static PetscErrorCode PEPQSliceGetInertia(PEP pep,PetscReal shift,PetscInt *iner
   PetscErrorCode ierr;
   KSP            ksp;
   Mat            P;
-  PetscReal      nzshift=0.0;
-  PetscScalar    dot;
+  PetscReal      nzshift=0.0,dot;
   PetscRandom    rand;
   PetscInt       nconv;
   PEP_STOAR      *ctx=(PEP_STOAR*)pep->data;
@@ -221,8 +220,8 @@ static PetscErrorCode PEPQSliceGetInertia(PEP pep,PetscReal shift,PetscInt *iner
         ierr = MatMult(pep->A[1],sr->v[0],sr->v[1]);CHKERRQ(ierr);
         ierr = MatMult(pep->A[2],sr->v[0],sr->v[2]);CHKERRQ(ierr);
         ierr = VecAXPY(sr->v[1],2*nzshift,sr->v[2]);CHKERRQ(ierr);
-        ierr = VecDot(sr->v[1],sr->v[0],&dot);CHKERRQ(ierr);
-        if (PetscRealPart(dot)>0.0) *inertia = 2*pep->n-*inertia;
+        ierr = VecDotRealPart(sr->v[1],sr->v[0],&dot);CHKERRQ(ierr);
+        if (dot>0.0) *inertia = 2*pep->n-*inertia;
       }
     }
   } else if (correction<0) *inertia = 2*pep->n-*inertia;
@@ -241,7 +240,8 @@ static PetscErrorCode PEPQSliceCheckEigenvalueType(PEP pep,PetscReal shift,Petsc
   PEP            pep2;
   ST             st;
   PetscInt       nconv;
-  PetscScalar    lambda,dot;
+  PetscScalar    lambda;
+  PetscReal      dot;
   PEP_STOAR      *ctx=(PEP_STOAR*)pep->data;
   PEP_SR         sr=ctx->sr;
 
@@ -273,11 +273,11 @@ static PetscErrorCode PEPQSliceCheckEigenvalueType(PEP pep,PetscReal shift,Petsc
       ierr = MatMult(pep->A[1],pep2->work[0],pep2->work[1]);CHKERRQ(ierr);
       ierr = MatMult(pep->A[2],pep2->work[0],pep2->work[2]);CHKERRQ(ierr);
       ierr = VecAXPY(pep2->work[1],2.0*lambda*pep->sfactor,pep2->work[2]);CHKERRQ(ierr);
-      ierr = VecDot(pep2->work[1],pep2->work[0],&dot);CHKERRQ(ierr);
-      ierr = PetscInfo2(pep,"lambda=%g, %s type\n",(double)PetscRealPart(lambda),(PetscRealPart(dot)>0.0)?"positive":"negative");CHKERRQ(ierr);
-      if (!sr->type) sr->type = (PetscRealPart(dot)>0.0)?1:-1;
+      ierr = VecDotRealPart(pep2->work[1],pep2->work[0],&dot);CHKERRQ(ierr);
+      ierr = PetscInfo2(pep,"lambda=%g, %s type\n",(double)PetscRealPart(lambda),(dot>0.0)?"positive":"negative");CHKERRQ(ierr);
+      if (!sr->type) sr->type = (dot>0.0)?1:-1;
       else {
-        if (sr->type*PetscRealPart(dot)<0.0) SETERRQ1(((PetscObject)pep)->comm,PETSC_ERR_CONV_FAILED,"Different positive/negative type detected in eigenvalue %g",(double)PetscRealPart(lambda));
+        if (sr->type*dot<0.0) SETERRQ1(((PetscObject)pep)->comm,PETSC_ERR_CONV_FAILED,"Different positive/negative type detected in eigenvalue %g",(double)PetscRealPart(lambda));
       }
     }
     pep2->st = st;
@@ -289,19 +289,15 @@ static PetscErrorCode PEPQSliceCheckEigenvalueType(PEP pep,PetscReal shift,Petsc
 PETSC_STATIC_INLINE PetscErrorCode PEPQSliceDiscriminant(PEP pep,Vec u,Vec w,PetscReal *d,PetscReal *smas,PetscReal *smenos)
 {
   PetscReal      ap,bp,cp,dis;
-  PetscScalar    ts;
   PetscErrorCode ierr;
 
   PetscFunctionBegin;
   ierr = MatMult(pep->A[0],u,w);CHKERRQ(ierr);
-  ierr = VecDot(w,u,&ts);CHKERRQ(ierr);
-  cp = PetscRealPart(ts);
+  ierr = VecDotRealPart(w,u,&cp);CHKERRQ(ierr);
   ierr = MatMult(pep->A[1],u,w);CHKERRQ(ierr);
-  ierr = VecDot(w,u,&ts);CHKERRQ(ierr);
-  bp = PetscRealPart(ts);
+  ierr = VecDotRealPart(w,u,&bp);CHKERRQ(ierr);
   ierr = MatMult(pep->A[2],u,w);CHKERRQ(ierr);
-  ierr = VecDot(w,u,&ts);CHKERRQ(ierr);
-  ap = PetscRealPart(ts);
+  ierr = VecDotRealPart(w,u,&ap);CHKERRQ(ierr);
   dis = bp*bp-4*ap*cp;
   if (dis>=0.0 && smas) {
     if (ap>0) *smas = (-bp+PetscSqrtReal(dis))/(2*ap);
@@ -436,7 +432,7 @@ PetscErrorCode PEPCheckDefiniteQEP(PEP pep,PetscReal *xi,PetscReal *mu,PetscInt
     if (omg<omgp) hyp = -1;
   }
   if (check==1) *xi = mut;
-  if (hyp==-1 && ptypehyp) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Problem does not satisfy hyperbolic test; consider removing the hyperbolicity flag");
+  if (hyp==-1 && ptypehyp) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_PLIB,"Problem does not satisfy hyperbolic test; consider removing the hyperbolicity flag");
   if (check==1 && hyp==0) {
     ierr =  PEPQSliceMatGetInertia(pep,PETSC_MAX_REAL,&inertia,NULL);CHKERRQ(ierr);
     if (inertia == 0) hyp = 1;
@@ -718,7 +714,7 @@ static PetscErrorCode PEPGetNewShiftValue(PEP pep,PetscInt side,PetscReal *newS)
         *newS = sPres->value + 10*(sr->dir)*PetscAbsReal(sPres->value - sPres->neighb[0]->value);
         sr->nleap++;
         /* Stops when the interval is open and no values are found in the last 5 shifts (there might be infinite eigenvalues) */
-        if (!sr->hasEnd && sr->nleap > 5) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Unable to compute the wanted eigenvalues with open interval");
+        if (!sr->hasEnd && sr->nleap > 5) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_CONV_FAILED,"Unable to compute the wanted eigenvalues with open interval");
       } else { /* First shift */
         if (pep->nconv != 0) {
           /* Unaccepted values give information for next shift */
@@ -740,7 +736,7 @@ static PetscErrorCode PEPGetNewShiftValue(PEP pep,PetscInt side,PetscReal *newS)
           if (!sr->dirch) {
             sr->dirch = PETSC_TRUE;
             *newS = sr->int1;
-          } else SETERRQ(PetscObjectComm((PetscObject)pep),1,"First shift renders no information");
+          } else SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_PLIB,"First shift renders no information");
         }
       }
     } else { /* Accepted values found */
@@ -840,7 +836,7 @@ static PetscErrorCode PEPStoreEigenpairs(PEP pep)
       lambda = PetscRealPart(pep->eigr[pep->perm[i]]);
       err = pep->errest[pep->perm[i]];
       if ((sr->dir)*(lambda - sPres->ext[0]) > 0 && (sr->dir)*(sPres->ext[1] - lambda) > 0) {/* Valid value */
-        if (sr->indexEig+count-ndef>=sr->numEigs) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Unexpected error in Spectrum Slicing");
+        if (sr->indexEig+count-ndef>=sr->numEigs) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_PLIB,"Unexpected error in Spectrum Slicing");
         ierr = PEPQSliceCheckEigenvalueType(pep,lambda,PetscRealPart(omega[pep->perm[i]]),PETSC_FALSE);CHKERRQ(ierr);
         eigr[count] = lambda;
         errest[count] = err;
@@ -956,7 +952,7 @@ static PetscErrorCode PEPStoreEigenpairs(PEP pep)
   /* Check for completion */
   sPres->comp[0] = PetscNot(sPres->nconv[0] < sPres->nsch[0]);
   sPres->comp[1] = PetscNot(sPres->nconv[1] < sPres->nsch[1]);
-  if (sPres->nconv[0] > sPres->nsch[0] || sPres->nconv[1] > sPres->nsch[1]) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Mismatch between number of values found and information from inertia");
+  if (sPres->nconv[0] > sPres->nsch[0] || sPres->nconv[1] > sPres->nsch[1]) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_PLIB,"Mismatch between number of values found and information from inertia");
   if (divide) { ierr = BVDestroy(&tV);CHKERRQ(ierr); }
   PetscFunctionReturn(0);
 }
@@ -996,12 +992,12 @@ static PetscErrorCode PEPLookForDeflation(PEP pep)
   /* The number of values on each side are found */
   if (sPres->neighb[0]) {
     sPres->nsch[0] = (sr->dir)*(sPres->inertia - sPres->neighb[0]->inertia)-count0;
-    if (sPres->nsch[0]<0) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Mismatch between number of values found and information from inertia");
+    if (sPres->nsch[0]<0) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_PLIB,"Mismatch between number of values found and information from inertia");
   } else sPres->nsch[0] = 0;
 
   if (sPres->neighb[1]) {
     sPres->nsch[1] = (sr->dir)*(sPres->neighb[1]->inertia - sPres->inertia) - count1;
-    if (sPres->nsch[1]<0) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Mismatch between number of values found and information from inertia");
+    if (sPres->nsch[1]<0) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_PLIB,"Mismatch between number of values found and information from inertia");
   } else sPres->nsch[1] = (sr->dir)*(sr->inertia1 - sPres->inertia);
 
   /* Completing vector of indexes for deflation */
@@ -1039,7 +1035,7 @@ static PetscErrorCode PEPSTOARrun_QSlice(PEP pep,PetscReal *a,PetscReal *b,Petsc
 
   *breakdown = PETSC_FALSE; /* ----- */
   ierr = STGetShift(pep->st,&sigma);CHKERRQ(ierr);
-  ierr = DSGetDimensions(pep->ds,NULL,NULL,&l,NULL,NULL);CHKERRQ(ierr);
+  ierr = DSGetDimensions(pep->ds,NULL,&l,NULL,NULL);CHKERRQ(ierr);
   ierr = BVSetActiveColumns(ctx->V,0,m);CHKERRQ(ierr);
   ierr = BVSetActiveColumns(pep->V,0,nqt);CHKERRQ(ierr);
   for (j=k;j<m;j++) {
@@ -1251,7 +1247,7 @@ static PetscErrorCode PEPSTOAR_QSlice(PEP pep,Mat B)
     }
     ierr = DSRestoreArrayReal(pep->ds,DS_MAT_T,&a);CHKERRQ(ierr);
     ierr = DSRestoreArrayReal(pep->ds,DS_MAT_D,&omega);CHKERRQ(ierr);
-    ierr = DSSetDimensions(pep->ds,nv,0,pep->nconv,pep->nconv+l);CHKERRQ(ierr);
+    ierr = DSSetDimensions(pep->ds,nv,pep->nconv,pep->nconv+l);CHKERRQ(ierr);
     if (l==0) {
       ierr = DSSetState(pep->ds,DS_STATE_INTERMEDIATE);CHKERRQ(ierr);
     } else {
@@ -1267,7 +1263,7 @@ static PetscErrorCode PEPSTOAR_QSlice(PEP pep,Mat B)
     /* Check convergence */
     /* ierr = PEPSTOARpreKConvergence(pep,nv,&norm,pep->work);CHKERRQ(ierr);*/
     norm = 1.0;
-    ierr = DSGetDimensions(pep->ds,NULL,NULL,NULL,NULL,&t);CHKERRQ(ierr);
+    ierr = DSGetDimensions(pep->ds,NULL,NULL,NULL,&t);CHKERRQ(ierr);
     ierr = PEPKrylovConvergence(pep,PETSC_FALSE,pep->nconv,t-pep->nconv,PetscAbsReal(beta)*norm,&k);CHKERRQ(ierr);
     ierr = (*pep->stopping)(pep,pep->its,pep->max_it,k,pep->nev,&pep->reason,pep->stoppingctx);CHKERRQ(ierr);
     for (j=0;j<k;j++) back[j] = pep->eigr[j];
@@ -1347,9 +1343,9 @@ static PetscErrorCode PEPSTOAR_QSlice(PEP pep,Mat B)
   ierr = STScaleShift(pep->st,sinv?1.0/pep->sfactor:pep->sfactor);CHKERRQ(ierr);
   ierr = RGPopScale(pep->rg);CHKERRQ(ierr);
 
-  if (pep->reason == PEP_DIVERGED_SYMMETRY_LOST && nconv<sr->ndef0+sr->ndef1) SETERRQ1(PetscObjectComm((PetscObject)pep),1,"Symmetry lost at sigma=%g",(double)sr->sPres->value);
+  if (pep->reason == PEP_DIVERGED_SYMMETRY_LOST && nconv<sr->ndef0+sr->ndef1) SETERRQ1(PetscObjectComm((PetscObject)pep),PETSC_ERR_PLIB,"Symmetry lost at sigma=%g",(double)sr->sPres->value);
   if (pep->reason == PEP_DIVERGED_SYMMETRY_LOST && nconv==sr->ndef0+sr->ndef1) {
-    if (++sr->symmlost>10) SETERRQ1(PetscObjectComm((PetscObject)pep),1,"Symmetry lost at sigma=%g",(double)sr->sPres->value);
+    if (++sr->symmlost>10) SETERRQ1(PetscObjectComm((PetscObject)pep),PETSC_ERR_PLIB,"Symmetry lost at sigma=%g",(double)sr->sPres->value);
   } else sr->symmlost = 0;
 
   ierr = DSTruncate(pep->ds,pep->nconv,PETSC_TRUE);CHKERRQ(ierr);
