@@ -893,7 +893,7 @@ static PetscErrorCode PEPNRefForwardSubstitution(PEP pep,PetscInt k,PetscScalar
     }
   } else At = pep->A;
 
-  /* Main loop for computing the ith columns of dX and dS */
+  /* Main loop for computing the i-th columns of dX and dS */
   for (i=0;i<k;i++) {
     /* Compute and update i-th column of the right hand side */
     ierr = PetscArrayzero(Rh,k);CHKERRQ(ierr);
@@ -1072,7 +1072,7 @@ static PetscErrorCode PEPNRefSetUp(PEP pep,PetscInt k,PetscScalar *H,PetscInt ld
       ierr = MatGetOwnershipRangeColumn(E[1],&n1_,&m1_);CHKERRQ(ierr);
       /* T12 and T21 are computed from V and V*, so,
          they must have the same column and row ranges */
-      if (m0_-n0_ != m0-n0) SETERRQ(PETSC_COMM_SELF,1,"Inconsistent dimensions");
+      if (m0_-n0_ != m0-n0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"Inconsistent dimensions");
       ierr = MatCreateDense(comm,m0-n0,m1_-n1_,PETSC_DECIDE,PETSC_DECIDE,NULL,&B);CHKERRQ(ierr);
       ierr = MatAssemblyBegin(B,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
       ierr = MatAssemblyEnd(B,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
@@ -1259,6 +1259,7 @@ static PetscErrorCode NRefSubcommSetup(PEP pep,PetscInt k,PEP_REFINE_EXPLICIT *m
   ierr = PetscMalloc3(pep->nmat,&matctx->A,nsubc,&matctx->scatter_id,nsubc,&matctx->scatterp_id);CHKERRQ(ierr);
   for (i=0;i<pep->nmat;i++) {
     ierr = MatCreateRedundantMatrix(A[i],0,PetscSubcommChild(matctx->subc),MAT_INITIAL_MATRIX,&matctx->A[i]);CHKERRQ(ierr);
+    ierr = PetscLogObjectParent((PetscObject)pep,(PetscObject)matctx->A[i]);CHKERRQ(ierr);
   }
 
   /* Create Scatter */
@@ -1369,7 +1370,7 @@ PetscErrorCode PEPNewtonRefinement_TOAR(PEP pep,PetscScalar sigma,PetscInt *maxi
 
   PetscFunctionBegin;
   ierr = PetscLogEventBegin(PEP_Refine,pep,0,0,0);CHKERRQ(ierr);
-  if (k > pep->n) SETERRQ1(PetscObjectComm((PetscObject)pep),1,"Multiple Refinement available only for invariant pairs of dimension smaller than n=%D",pep->n);
+  if (k > pep->n) SETERRQ1(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"Multiple Refinement available only for invariant pairs of dimension smaller than n=%D",pep->n);
   /* the input tolerance is not being taken into account (by the moment) */
   its = *maxits;
   ierr = PetscMalloc3(k*k,&dH,nmat*k*k,&fH,k,&work);CHKERRQ(ierr);
@@ -1409,7 +1410,7 @@ PetscErrorCode PEPNewtonRefinement_TOAR(PEP pep,PetscScalar sigma,PetscInt *maxi
     ierr = DSRestoreArray(pep->ds,DS_MAT_A,&H);CHKERRQ(ierr);
     if (!flg) {
       /* Restore original values */
-      for (i=0;i<pep->nmat;i++){
+      for (i=0;i<pep->nmat;i++) {
         pep->pbc[pep->nmat+i] *= pep->sfactor;
         pep->pbc[2*pep->nmat+i] *= pep->sfactor*pep->sfactor;
       }
@@ -1429,19 +1430,19 @@ PetscErrorCode PEPNewtonRefinement_TOAR(PEP pep,PetscScalar sigma,PetscInt *maxi
   for (i=0;i<k-1;i++) {
     if (H[i+1+i*ldh]!=0.0) {
 #if !defined(PETSC_USE_COMPLEX)
-      SETERRQ(PetscObjectComm((PetscObject)pep),1,"Iterative Refinement requires the complex Schur form of the projected matrix");
+      SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"Iterative Refinement requires the complex Schur form of the projected matrix");
 #else
-      SETERRQ(PetscObjectComm((PetscObject)pep),1,"Iterative Refinement requires an upper triangular projected matrix");
+      SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"Iterative Refinement requires an upper triangular projected matrix");
 #endif
     }
   }
-  if (nsubc>k) SETERRQ(PetscObjectComm((PetscObject)pep),1,"Amount of subcommunicators should not be larger than the invariant pair dimension");
+  if (nsubc>k) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"Amount of subcommunicators should not be larger than the invariant pair dimension");
   ierr = BVSetActiveColumns(pep->V,0,k);CHKERRQ(ierr);
   ierr = BVDuplicateResize(pep->V,k,&dV);CHKERRQ(ierr);
   ierr = PetscLogObjectParent((PetscObject)pep,(PetscObject)dV);CHKERRQ(ierr);
   if (pep->scheme!=PEP_REFINE_SCHEME_SCHUR) {
     ierr = PetscMalloc1(1,&matctx);CHKERRQ(ierr);
-    if (nsubc>1) { /* spliting in subcommunicators */
+    if (nsubc>1) { /* splitting in subcommunicators */
       matctx->subc = pep->refinesubc;
       ierr = NRefSubcommSetup(pep,k,matctx,nsubc);CHKERRQ(ierr);
     } else matctx->subc=NULL;
