@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -14,6 +14,26 @@
 #include <slepc/private/pepimpl.h>      /*I "slepcpep.h" I*/
 #include <petscdraw.h>
 
+PetscErrorCode PEPMonitorLGCreate(MPI_Comm comm,const char host[],const char label[],const char metric[],PetscInt l,const char *names[],int x,int y,int m,int n,PetscDrawLG *lgctx)
+{
+  PetscDraw      draw;
+  PetscDrawAxis  axis;
+  PetscDrawLG    lg;
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  ierr = PetscDrawCreate(comm,host,label,x,y,m,n,&draw);CHKERRQ(ierr);
+  ierr = PetscDrawSetFromOptions(draw);CHKERRQ(ierr);
+  ierr = PetscDrawLGCreate(draw,l,&lg);CHKERRQ(ierr);
+  if (names) { ierr = PetscDrawLGSetLegend(lg,names);CHKERRQ(ierr); }
+  ierr = PetscDrawLGSetFromOptions(lg);CHKERRQ(ierr);
+  ierr = PetscDrawLGGetAxis(lg,&axis);CHKERRQ(ierr);
+  ierr = PetscDrawAxisSetLabels(axis,"Convergence","Iteration",metric);CHKERRQ(ierr);
+  ierr = PetscDrawDestroy(&draw);CHKERRQ(ierr);
+  *lgctx = lg;
+  PetscFunctionReturn(0);
+}
+
 /*
    Runs the user provided monitor routines, if any.
 */
@@ -59,10 +79,11 @@ $   monitor(PEP pep,int its,int nconv,PetscScalar *eigr,PetscScalar *eigi,PetscR
 .    -pep_monitor_all    - print error estimates at each iteration
 .    -pep_monitor_conv   - print the eigenvalue approximations only when
       convergence has been reached
-.    -pep_monitor_lg     - sets line graph monitor for the first unconverged
+.    -pep_monitor draw::draw_lg - sets line graph monitor for the first unconverged
       approximate eigenvalue
-.    -pep_monitor_lg_all - sets line graph monitor for all unconverged
+.    -pep_monitor_all draw::draw_lg - sets line graph monitor for all unconverged
       approximate eigenvalues
+.    -pep_monitor_conv draw::draw_lg - sets line graph monitor for convergence history
 -    -pep_monitor_cancel - cancels all monitors that have been hardwired into
       a code by calls to PEPMonitorSet(), but does not cancel those set via
       the options database.
@@ -136,11 +157,11 @@ PetscErrorCode PEPMonitorCancel(PEP pep)
 
 .seealso: PEPMonitorSet(), PEPDefaultMonitor()
 @*/
-PetscErrorCode PEPGetMonitorContext(PEP pep,void **ctx)
+PetscErrorCode PEPGetMonitorContext(PEP pep,void *ctx)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
-  *ctx = pep->monitorcontext[0];
+  *(void**)ctx = pep->monitorcontext[0];
   PetscFunctionReturn(0);
 }
 
@@ -166,63 +187,6 @@ static PetscErrorCode PEPMonitorGetTrueEig(PEP pep,PetscScalar *er,PetscScalar *
   PetscFunctionReturn(0);
 }
 
-/*@C
-   PEPMonitorAll - Print the current approximate values and
-   error estimates at each iteration of the polynomial eigensolver.
-
-   Collective on pep
-
-   Input Parameters:
-+  pep    - polynomial eigensolver context
-.  its    - iteration number
-.  nconv  - number of converged eigenpairs so far
-.  eigr   - real part of the eigenvalues
-.  eigi   - imaginary part of the eigenvalues
-.  errest - error estimates
-.  nest   - number of error estimates to display
--  vf     - viewer and format for monitoring
-
-   Level: intermediate
-
-.seealso: PEPMonitorSet(), PEPMonitorFirst(), PEPMonitorConverged()
-@*/
-PetscErrorCode PEPMonitorAll(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)
-{
-  PetscErrorCode ierr;
-  PetscInt       i;
-  PetscScalar    er,ei;
-  PetscViewer    viewer;
-
-  PetscFunctionBegin;
-  PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
-  PetscValidPointer(vf,8);
-  viewer = vf->viewer;
-  PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,8);
-  ierr = PetscViewerPushFormat(viewer,vf->format);CHKERRQ(ierr);
-  ierr = PetscViewerASCIIAddTab(viewer,((PetscObject)pep)->tablevel);CHKERRQ(ierr);
-  if (its==1 && ((PetscObject)pep)->prefix) {
-    ierr = PetscViewerASCIIPrintf(viewer,"  Eigenvalue approximations and residual norms for %s solve.\n",((PetscObject)pep)->prefix);CHKERRQ(ierr);
-  }
-  ierr = PetscViewerASCIIPrintf(viewer,"%3D PEP nconv=%D Values (Errors)",its,nconv);CHKERRQ(ierr);
-  ierr = PetscViewerASCIIUseTabs(viewer,PETSC_FALSE);CHKERRQ(ierr);
-  for (i=0;i<nest;i++) {
-    er = eigr[i]; ei = eigi[i];
-    ierr = PEPMonitorGetTrueEig(pep,&er,&ei);CHKERRQ(ierr);
-#if defined(PETSC_USE_COMPLEX)
-    ierr = PetscViewerASCIIPrintf(viewer," %g%+gi",(double)PetscRealPart(er),(double)PetscImaginaryPart(er));CHKERRQ(ierr);
-#else
-    ierr = PetscViewerASCIIPrintf(viewer," %g",(double)er);CHKERRQ(ierr);
-    if (eigi[i]!=0.0) { ierr = PetscViewerASCIIPrintf(viewer,"%+gi",(double)ei);CHKERRQ(ierr); }
-#endif
-    ierr = PetscViewerASCIIPrintf(viewer," (%10.8e)",(double)errest[i]);CHKERRQ(ierr);
-  }
-  ierr = PetscViewerASCIIPrintf(viewer,"\n");CHKERRQ(ierr);
-  ierr = PetscViewerASCIIUseTabs(viewer,PETSC_TRUE);CHKERRQ(ierr);
-  ierr = PetscViewerASCIISubtractTab(viewer,((PetscObject)pep)->tablevel);CHKERRQ(ierr);
-  ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
-  PetscFunctionReturn(0);
-}
-
 /*@C
    PEPMonitorFirst - Print the first unconverged approximate value and
    error estimate at each iteration of the polynomial eigensolver.
@@ -239,6 +203,9 @@ PetscErrorCode PEPMonitorAll(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *ei
 .  nest   - number of error estimates to display
 -  vf     - viewer and format for monitoring
 
+   Options Database Key:
+.  -pep_monitor - activates PEPMonitorFirst()
+
    Level: intermediate
 
 .seealso: PEPMonitorSet(), PEPMonitorAll(), PEPMonitorConverged()
@@ -247,12 +214,10 @@ PetscErrorCode PEPMonitorFirst(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *
 {
   PetscErrorCode ierr;
   PetscScalar    er,ei;
-  PetscViewer    viewer;
+  PetscViewer    viewer = vf->viewer;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
-  PetscValidPointer(vf,8);
-  viewer = vf->viewer;
   PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,8);
   if (its==1 && ((PetscObject)pep)->prefix) {
     ierr = PetscViewerASCIIPrintf(viewer,"  Eigenvalue approximations and residual norms for %s solve.\n",((PetscObject)pep)->prefix);CHKERRQ(ierr);
@@ -268,7 +233,7 @@ PetscErrorCode PEPMonitorFirst(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *
     ierr = PetscViewerASCIIPrintf(viewer," %g%+gi",(double)PetscRealPart(er),(double)PetscImaginaryPart(er));CHKERRQ(ierr);
 #else
     ierr = PetscViewerASCIIPrintf(viewer," %g",(double)er);CHKERRQ(ierr);
-    if (eigi[nconv]!=0.0) { ierr = PetscViewerASCIIPrintf(viewer,"%+gi",(double)ei);CHKERRQ(ierr); }
+    if (ei!=0.0) { ierr = PetscViewerASCIIPrintf(viewer,"%+gi",(double)ei);CHKERRQ(ierr); }
 #endif
     ierr = PetscViewerASCIIPrintf(viewer," (%10.8e)\n",(double)errest[nconv]);CHKERRQ(ierr);
     ierr = PetscViewerASCIIUseTabs(viewer,PETSC_TRUE);CHKERRQ(ierr);
@@ -278,6 +243,64 @@ PetscErrorCode PEPMonitorFirst(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *
   PetscFunctionReturn(0);
 }
 
+/*@C
+   PEPMonitorAll - Print the current approximate values and
+   error estimates at each iteration of the polynomial eigensolver.
+
+   Collective on pep
+
+   Input Parameters:
++  pep    - polynomial eigensolver context
+.  its    - iteration number
+.  nconv  - number of converged eigenpairs so far
+.  eigr   - real part of the eigenvalues
+.  eigi   - imaginary part of the eigenvalues
+.  errest - error estimates
+.  nest   - number of error estimates to display
+-  vf     - viewer and format for monitoring
+
+   Options Database Key:
+.  -pep_monitor_all - activates PEPMonitorAll()
+
+   Level: intermediate
+
+.seealso: PEPMonitorSet(), PEPMonitorFirst(), PEPMonitorConverged()
+@*/
+PetscErrorCode PEPMonitorAll(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)
+{
+  PetscErrorCode ierr;
+  PetscInt       i;
+  PetscScalar    er,ei;
+  PetscViewer    viewer = vf->viewer;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
+  PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,8);
+  ierr = PetscViewerPushFormat(viewer,vf->format);CHKERRQ(ierr);
+  ierr = PetscViewerASCIIAddTab(viewer,((PetscObject)pep)->tablevel);CHKERRQ(ierr);
+  if (its==1 && ((PetscObject)pep)->prefix) {
+    ierr = PetscViewerASCIIPrintf(viewer,"  Eigenvalue approximations and residual norms for %s solve.\n",((PetscObject)pep)->prefix);CHKERRQ(ierr);
+  }
+  ierr = PetscViewerASCIIPrintf(viewer,"%3D PEP nconv=%D Values (Errors)",its,nconv);CHKERRQ(ierr);
+  ierr = PetscViewerASCIIUseTabs(viewer,PETSC_FALSE);CHKERRQ(ierr);
+  for (i=0;i<nest;i++) {
+    er = eigr[i]; ei = eigi[i];
+    ierr = PEPMonitorGetTrueEig(pep,&er,&ei);CHKERRQ(ierr);
+#if defined(PETSC_USE_COMPLEX)
+    ierr = PetscViewerASCIIPrintf(viewer," %g%+gi",(double)PetscRealPart(er),(double)PetscImaginaryPart(er));CHKERRQ(ierr);
+#else
+    ierr = PetscViewerASCIIPrintf(viewer," %g",(double)er);CHKERRQ(ierr);
+    if (ei!=0.0) { ierr = PetscViewerASCIIPrintf(viewer,"%+gi",(double)ei);CHKERRQ(ierr); }
+#endif
+    ierr = PetscViewerASCIIPrintf(viewer," (%10.8e)",(double)errest[i]);CHKERRQ(ierr);
+  }
+  ierr = PetscViewerASCIIPrintf(viewer,"\n");CHKERRQ(ierr);
+  ierr = PetscViewerASCIIUseTabs(viewer,PETSC_TRUE);CHKERRQ(ierr);
+  ierr = PetscViewerASCIISubtractTab(viewer,((PetscObject)pep)->tablevel);CHKERRQ(ierr);
+  ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 /*@C
    PEPMonitorConverged - Print the approximate values and
    error estimates as they converge.
@@ -292,30 +315,33 @@ PetscErrorCode PEPMonitorFirst(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *
 .  eigi   - imaginary part of the eigenvalues
 .  errest - error estimates
 .  nest   - number of error estimates to display
--  ctx    - monitor context
+-  vf     - viewer and format for monitoring
+
+   Options Database Key:
+.  -pep_monitor_conv - activates PEPMonitorConverged()
 
    Level: intermediate
 
 .seealso: PEPMonitorSet(), PEPMonitorFirst(), PEPMonitorAll()
 @*/
-PetscErrorCode PEPMonitorConverged(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,SlepcConvMonitor ctx)
+PetscErrorCode PEPMonitorConverged(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)
 {
   PetscErrorCode ierr;
   PetscInt       i;
   PetscScalar    er,ei;
-  PetscViewer    viewer;
+  PetscViewer    viewer = vf->viewer;
+  SlepcConvMon   ctx;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
-  PetscValidPointer(ctx,8);
-  viewer = ctx->viewer;
   PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,8);
+  ctx = (SlepcConvMon)vf->data;
   if (its==1 && ((PetscObject)pep)->prefix) {
     ierr = PetscViewerASCIIPrintf(viewer,"  Convergence history for %s solve.\n",((PetscObject)pep)->prefix);CHKERRQ(ierr);
   }
   if (its==1) ctx->oldnconv = 0;
   if (ctx->oldnconv!=nconv) {
-    ierr = PetscViewerPushFormat(viewer,ctx->format);CHKERRQ(ierr);
+    ierr = PetscViewerPushFormat(viewer,vf->format);CHKERRQ(ierr);
     ierr = PetscViewerASCIIAddTab(viewer,((PetscObject)pep)->tablevel);CHKERRQ(ierr);
     for (i=ctx->oldnconv;i<nconv;i++) {
       ierr = PetscViewerASCIIPrintf(viewer,"%3D PEP converged value (error) #%D",its,i);CHKERRQ(ierr);
@@ -326,7 +352,7 @@ PetscErrorCode PEPMonitorConverged(PEP pep,PetscInt its,PetscInt nconv,PetscScal
       ierr = PetscViewerASCIIPrintf(viewer," %g%+gi",(double)PetscRealPart(er),(double)PetscImaginaryPart(er));CHKERRQ(ierr);
 #else
       ierr = PetscViewerASCIIPrintf(viewer," %g",(double)er);CHKERRQ(ierr);
-      if (eigi[i]!=0.0) { ierr = PetscViewerASCIIPrintf(viewer,"%+gi",(double)ei);CHKERRQ(ierr); }
+      if (ei!=0.0) { ierr = PetscViewerASCIIPrintf(viewer,"%+gi",(double)ei);CHKERRQ(ierr); }
 #endif
       ierr = PetscViewerASCIIPrintf(viewer," (%10.8e)\n",(double)errest[i]);CHKERRQ(ierr);
       ierr = PetscViewerASCIIUseTabs(viewer,PETSC_TRUE);CHKERRQ(ierr);
@@ -338,87 +364,156 @@ PetscErrorCode PEPMonitorConverged(PEP pep,PetscInt its,PetscInt nconv,PetscScal
   PetscFunctionReturn(0);
 }
 
-/*@C
-   PEPMonitorLGCreate - Creates a line graph context for use with
-   PEP to monitor convergence.
+PetscErrorCode PEPMonitorConvergedCreate(PetscViewer viewer,PetscViewerFormat format,void *ctx,PetscViewerAndFormat **vf)
+{
+  PetscErrorCode ierr;
+  SlepcConvMon   mctx;
 
-   Collective
+  PetscFunctionBegin;
+  ierr = PetscViewerAndFormatCreate(viewer,format,vf);CHKERRQ(ierr);
+  ierr = PetscNew(&mctx);CHKERRQ(ierr);
+  mctx->ctx = ctx;
+  (*vf)->data = (void*)mctx;
+  PetscFunctionReturn(0);
+}
+
+PetscErrorCode PEPMonitorConvergedDestroy(PetscViewerAndFormat **vf)
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  if (!*vf) PetscFunctionReturn(0);
+  ierr = PetscFree((*vf)->data);CHKERRQ(ierr);
+  ierr = PetscViewerDestroy(&(*vf)->viewer);CHKERRQ(ierr);
+  ierr = PetscDrawLGDestroy(&(*vf)->lg);CHKERRQ(ierr);
+  ierr = PetscFree(*vf);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
+/*@C
+   PEPMonitorFirstDrawLG - Plots the error estimate of the first unconverged
+   approximation at each iteration of the polynomial eigensolver.
+
+   Collective on pep
 
    Input Parameters:
-+  comm - communicator context
-.  host - the X display to open, or null for the local machine
-.  label - the title to put in the title bar
-.  x, y - the screen coordinates of the upper left coordinate of
-          the window
--  m, n - the screen width and height in pixels
++  pep    - polynomial eigensolver context
+.  its    - iteration number
+.  its    - iteration number
+.  nconv  - number of converged eigenpairs so far
+.  eigr   - real part of the eigenvalues
+.  eigi   - imaginary part of the eigenvalues
+.  errest - error estimates
+.  nest   - number of error estimates to display
+-  vf     - viewer and format for monitoring
 
-   Output Parameter:
-.  lgctx - the drawing context
-
-   Options Database Keys:
-+  -pep_monitor_lg - Sets line graph monitor for the first residual
--  -pep_monitor_lg_all - Sets line graph monitor for all residuals
-
-   Notes:
-   Use PetscDrawLGDestroy() to destroy this line graph.
+   Options Database Key:
+.  -pep_monitor draw::draw_lg - activates PEPMonitorFirstDrawLG()
 
    Level: intermediate
 
 .seealso: PEPMonitorSet()
 @*/
-PetscErrorCode PEPMonitorLGCreate(MPI_Comm comm,const char host[],const char label[],int x,int y,int m,int n,PetscDrawLG *lgctx)
+PetscErrorCode PEPMonitorFirstDrawLG(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)
 {
-  PetscDraw      draw;
-  PetscDrawLG    lg;
   PetscErrorCode ierr;
-
-  PetscFunctionBegin;
-  ierr = PetscDrawCreate(comm,host,label,x,y,m,n,&draw);CHKERRQ(ierr);
-  ierr = PetscDrawSetFromOptions(draw);CHKERRQ(ierr);
-  ierr = PetscDrawLGCreate(draw,1,&lg);CHKERRQ(ierr);
-  ierr = PetscDrawLGSetFromOptions(lg);CHKERRQ(ierr);
-  ierr = PetscDrawDestroy(&draw);CHKERRQ(ierr);
-  *lgctx = lg;
-  PetscFunctionReturn(0);
-}
-
-PetscErrorCode PEPMonitorLG(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,void *ctx)
-{
-  PetscDrawLG    lg = (PetscDrawLG)ctx;
+  PetscViewer    viewer = vf->viewer;
+  PetscDrawLG    lg = vf->lg;
   PetscReal      x,y;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
+  PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
+  PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,8);
   PetscValidHeaderSpecific(lg,PETSC_DRAWLG_CLASSID,8);
+  ierr = PetscViewerPushFormat(viewer,vf->format);CHKERRQ(ierr);
   if (its==1) {
     ierr = PetscDrawLGReset(lg);CHKERRQ(ierr);
     ierr = PetscDrawLGSetDimension(lg,1);CHKERRQ(ierr);
-    ierr = PetscDrawLGSetLimits(lg,1,1.0,PetscLog10Real(pep->tol)-2,0.0);CHKERRQ(ierr);
+    ierr = PetscDrawLGSetLimits(lg,1,1,PetscLog10Real(pep->tol)-2,0.0);CHKERRQ(ierr);
   }
-  x = (PetscReal)its;
-  if (errest[nconv] > 0.0) y = PetscLog10Real(errest[nconv]);
-  else y = 0.0;
-  ierr = PetscDrawLGAddPoint(lg,&x,&y);CHKERRQ(ierr);
-  if (its <= 20 || !(its % 5) || pep->reason) {
-    ierr = PetscDrawLGDraw(lg);CHKERRQ(ierr);
-    ierr = PetscDrawLGSave(lg);CHKERRQ(ierr);
+  if (nconv<nest) {
+    x = (PetscReal)its;
+    if (errest[nconv] > 0.0) y = PetscLog10Real(errest[nconv]);
+    else y = 0.0;
+    ierr = PetscDrawLGAddPoint(lg,&x,&y);CHKERRQ(ierr);
+    if (its <= 20 || !(its % 5) || pep->reason) {
+      ierr = PetscDrawLGDraw(lg);CHKERRQ(ierr);
+      ierr = PetscDrawLGSave(lg);CHKERRQ(ierr);
+    }
   }
+  ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
-PetscErrorCode PEPMonitorLGAll(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,void *ctx)
+/*@C
+   PEPMonitorFirstDrawLGCreate - Creates the plotter for the first error estimate.
+
+   Collective on viewer
+
+   Input Parameters:
++  viewer - the viewer
+.  format - the viewer format
+-  ctx    - an optional user context
+
+   Output Parameter:
+.  vf     - the viewer and format context
+
+   Level: intermediate
+
+.seealso: PEPMonitorSet()
+@*/
+PetscErrorCode PEPMonitorFirstDrawLGCreate(PetscViewer viewer,PetscViewerFormat format,void *ctx,PetscViewerAndFormat **vf)
 {
-  PetscDrawLG    lg = (PetscDrawLG)ctx;
-  PetscInt       i,n = PetscMin(pep->nev,255);
-  PetscReal      *x,*y;
   PetscErrorCode ierr;
 
   PetscFunctionBegin;
+  ierr = PetscViewerAndFormatCreate(viewer,format,vf);CHKERRQ(ierr);
+  (*vf)->data = ctx;
+  ierr = PEPMonitorLGCreate(PetscObjectComm((PetscObject)viewer),NULL,"First Error Estimate","Log Error Estimate",1,NULL,PETSC_DECIDE,PETSC_DECIDE,400,300,&(*vf)->lg);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
+/*@C
+   PEPMonitorAllDrawLG - Plots the error estimate of all unconverged
+   approximations at each iteration of the polynomial eigensolver.
+
+   Collective on pep
+
+   Input Parameters:
++  pep    - polynomial eigensolver context
+.  its    - iteration number
+.  its    - iteration number
+.  nconv  - number of converged eigenpairs so far
+.  eigr   - real part of the eigenvalues
+.  eigi   - imaginary part of the eigenvalues
+.  errest - error estimates
+.  nest   - number of error estimates to display
+-  vf     - viewer and format for monitoring
+
+   Options Database Key:
+.  -pep_monitor_all draw::draw_lg - activates PEPMonitorAllDrawLG()
+
+   Level: intermediate
+
+.seealso: PEPMonitorSet()
+@*/
+PetscErrorCode PEPMonitorAllDrawLG(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)
+{
+  PetscErrorCode ierr;
+  PetscViewer    viewer = vf->viewer;
+  PetscDrawLG    lg = vf->lg;
+  PetscInt       i,n = PetscMin(pep->nev,255);
+  PetscReal      *x,*y;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
+  PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,8);
   PetscValidHeaderSpecific(lg,PETSC_DRAWLG_CLASSID,8);
+  ierr = PetscViewerPushFormat(viewer,vf->format);CHKERRQ(ierr);
   if (its==1) {
     ierr = PetscDrawLGReset(lg);CHKERRQ(ierr);
     ierr = PetscDrawLGSetDimension(lg,n);CHKERRQ(ierr);
-    ierr = PetscDrawLGSetLimits(lg,1,1.0,PetscLog10Real(pep->tol)-2,0.0);CHKERRQ(ierr);
+    ierr = PetscDrawLGSetLimits(lg,1,1,PetscLog10Real(pep->tol)-2,0.0);CHKERRQ(ierr);
   }
   ierr = PetscMalloc2(n,&x,n,&y);CHKERRQ(ierr);
   for (i=0;i<n;i++) {
@@ -432,6 +527,118 @@ PetscErrorCode PEPMonitorLGAll(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *
     ierr = PetscDrawLGSave(lg);CHKERRQ(ierr);
   }
   ierr = PetscFree2(x,y);CHKERRQ(ierr);
+  ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
+/*@C
+   PEPMonitorAllDrawLGCreate - Creates the plotter for all the error estimates.
+
+   Collective on viewer
+
+   Input Parameters:
++  viewer - the viewer
+.  format - the viewer format
+-  ctx    - an optional user context
+
+   Output Parameter:
+.  vf     - the viewer and format context
+
+   Level: intermediate
+
+.seealso: PEPMonitorSet()
+@*/
+PetscErrorCode PEPMonitorAllDrawLGCreate(PetscViewer viewer,PetscViewerFormat format,void *ctx,PetscViewerAndFormat **vf)
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  ierr = PetscViewerAndFormatCreate(viewer,format,vf);CHKERRQ(ierr);
+  (*vf)->data = ctx;
+  ierr = PEPMonitorLGCreate(PetscObjectComm((PetscObject)viewer),NULL,"All Error Estimates","Log Error Estimate",1,NULL,PETSC_DECIDE,PETSC_DECIDE,400,300,&(*vf)->lg);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
+/*@C
+   PEPMonitorConvergedDrawLG - Plots the number of converged eigenvalues
+   at each iteration of the polynomial eigensolver.
+
+   Collective on pep
+
+   Input Parameters:
++  pep    - polynomial eigensolver context
+.  its    - iteration number
+.  its    - iteration number
+.  nconv  - number of converged eigenpairs so far
+.  eigr   - real part of the eigenvalues
+.  eigi   - imaginary part of the eigenvalues
+.  errest - error estimates
+.  nest   - number of error estimates to display
+-  vf     - viewer and format for monitoring
+
+   Options Database Key:
+.  -pep_monitor_conv draw::draw_lg - activates PEPMonitorConvergedDrawLG()
+
+   Level: intermediate
+
+.seealso: PEPMonitorSet()
+@*/
+PetscErrorCode PEPMonitorConvergedDrawLG(PEP pep,PetscInt its,PetscInt nconv,PetscScalar *eigr,PetscScalar *eigi,PetscReal *errest,PetscInt nest,PetscViewerAndFormat *vf)
+{
+  PetscErrorCode   ierr;
+  PetscViewer      viewer = vf->viewer;
+  PetscDrawLG      lg = vf->lg;
+  PetscReal        x,y;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
+  PetscValidHeaderSpecific(viewer,PETSC_VIEWER_CLASSID,8);
+  PetscValidHeaderSpecific(lg,PETSC_DRAWLG_CLASSID,8);
+  ierr = PetscViewerPushFormat(viewer,vf->format);CHKERRQ(ierr);
+  if (its==1) {
+    ierr = PetscDrawLGReset(lg);CHKERRQ(ierr);
+    ierr = PetscDrawLGSetDimension(lg,1);CHKERRQ(ierr);
+    ierr = PetscDrawLGSetLimits(lg,1,1,0,pep->nev);CHKERRQ(ierr);
+  }
+  x = (PetscReal)its;
+  y = (PetscReal)pep->nconv;
+  ierr = PetscDrawLGAddPoint(lg,&x,&y);CHKERRQ(ierr);
+  if (its <= 20 || !(its % 5) || pep->reason) {
+    ierr = PetscDrawLGDraw(lg);CHKERRQ(ierr);
+    ierr = PetscDrawLGSave(lg);CHKERRQ(ierr);
+  }
+  ierr = PetscViewerPopFormat(viewer);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
+/*@C
+   PEPMonitorConvergedDrawLGCreate - Creates the plotter for the convergence history.
+
+   Collective on viewer
+
+   Input Parameters:
++  viewer - the viewer
+.  format - the viewer format
+-  ctx    - an optional user context
+
+   Output Parameter:
+.  vf     - the viewer and format context
+
+   Level: intermediate
+
+.seealso: PEPMonitorSet()
+@*/
+PetscErrorCode PEPMonitorConvergedDrawLGCreate(PetscViewer viewer,PetscViewerFormat format,void *ctx,PetscViewerAndFormat **vf)
+{
+  PetscErrorCode ierr;
+  SlepcConvMon   mctx;
+
+  PetscFunctionBegin;
+  ierr = PetscViewerAndFormatCreate(viewer,format,vf);CHKERRQ(ierr);
+  ierr = PetscNew(&mctx);CHKERRQ(ierr);
+  mctx->ctx = ctx;
+  (*vf)->data = (void*)mctx;
+  ierr = PEPMonitorLGCreate(PetscObjectComm((PetscObject)viewer),NULL,"Convergence History","Number Converged",1,NULL,PETSC_DECIDE,PETSC_DECIDE,400,300,&(*vf)->lg);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
