@@ -52,6 +52,7 @@ PetscErrorCode PEPMonitorSetFromOptions(PEP pep,const char opt[],const char name
   ierr = PetscViewerGetType(viewer,&vtype);CHKERRQ(ierr);
   ierr = SlepcMonitorMakeKey_Internal(name,vtype,format,key);CHKERRQ(ierr);
   ierr = PetscFunctionListFind(PEPMonitorList,key,&mfunc);CHKERRQ(ierr);
+  if (!mfunc) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"Specified viewer and format not supported");
   ierr = PetscFunctionListFind(PEPMonitorCreateList,key,&cfunc);CHKERRQ(ierr);
   ierr = PetscFunctionListFind(PEPMonitorDestroyList,key,&dfunc);CHKERRQ(ierr);
   if (!cfunc) cfunc = PetscViewerAndFormatCreate_Internal;
@@ -141,7 +142,7 @@ PetscErrorCode PEPSetFromOptions(PEP pep)
     i = pep->max_it;
     ierr = PetscOptionsInt("-pep_max_it","Maximum number of iterations","PEPSetTolerances",pep->max_it,&i,&flg1);CHKERRQ(ierr);
     r = pep->tol;
-    ierr = PetscOptionsReal("-pep_tol","Tolerance","PEPSetTolerances",pep->tol==PETSC_DEFAULT?SLEPC_DEFAULT_TOL:pep->tol,&r,&flg2);CHKERRQ(ierr);
+    ierr = PetscOptionsReal("-pep_tol","Tolerance","PEPSetTolerances",SlepcDefaultTol(pep->tol),&r,&flg2);CHKERRQ(ierr);
     if (flg1 || flg2) { ierr = PEPSetTolerances(pep,r,i);CHKERRQ(ierr); }
 
     ierr = PetscOptionsBoolGroupBegin("-pep_conv_rel","Relative error convergence test","PEPSetConvergenceTest",&flg);CHKERRQ(ierr);
@@ -433,7 +434,7 @@ PetscErrorCode PEPSetDimensions(PEP pep,PetscInt nev,PetscInt ncv,PetscInt mpd)
 .     PEP_TARGET_MAGNITUDE - eigenvalues closest to the target (in magnitude)
 .     PEP_TARGET_REAL - eigenvalues with real part closest to target
 .     PEP_TARGET_IMAGINARY - eigenvalues with imaginary part closest to target
-.     PEP_ALL - all eigenvalues contained in a given interval
+.     PEP_ALL - all eigenvalues contained in a given interval or region
 -     PEP_WHICH_USER - user defined ordering set with PEPSetEigenvalueComparison()
 
    Options Database Keys:
@@ -446,7 +447,7 @@ PetscErrorCode PEPSetDimensions(PEP pep,PetscInt nev,PetscInt ncv,PetscInt mpd)
 .   -pep_target_magnitude - Sets eigenvalues closest to target
 .   -pep_target_real - Sets real parts closest to target
 .   -pep_target_imaginary - Sets imaginary parts closest to target
--   -pep_all - Sets all eigenvalues in an interval
+-   -pep_all - Sets all eigenvalues in an interval or region
 
    Notes:
    Not all eigensolvers implemented in PEP account for all the possible values
@@ -460,8 +461,9 @@ PetscErrorCode PEPSetDimensions(PEP pep,PetscInt nev,PetscInt ncv,PetscInt mpd)
    SLEPc have been built with complex scalars.
 
    PEP_ALL is intended for use in combination with an interval (see
-   PEPSetInterval()), when all eigenvalues within the interval are requested.
-   In that case, the number of eigenvalues is unknown, so the nev parameter
+   PEPSetInterval()), when all eigenvalues within the interval are requested,
+   and also for computing all eigenvalues in a region with the CISS solver.
+   In both cases, the number of eigenvalues is unknown, so the nev parameter
    has a different sense, see PEPSetDimensions().
 
    Level: intermediate
