@@ -163,4 +163,33 @@ int main(int argc,char **argv)
       args: -pep_type {{toar linear}} -pep_nev 4 -terse
       requires: double
 
+   testset:
+      args: -pep_type ciss -rg_type ellipse -rg_ellipse_center 1+.5i -rg_ellipse_radius .15 -terse
+      requires: complex
+      filter: sed -e "s/95386/95385/" | sed -e "s/91010/91009/"
+      output_file: output/butterfly_ciss.out
+      test:
+         suffix: ciss_hankel
+         args: -pep_ciss_extraction hankel -pep_ciss_integration_points 40
+         requires: !single
+      test:
+         suffix: ciss_ritz
+         args: -pep_ciss_extraction ritz
+      test:
+         suffix: ciss_caa
+         args: -pep_ciss_extraction caa -pep_ciss_moments 4
+      test:
+         suffix: ciss_part
+         nsize: 2
+         args: -pep_ciss_partitions 2
+      test:
+         suffix: ciss_refine
+         args: -pep_ciss_refine_inner 1 -pep_ciss_refine_blocksize 1
+
+   test:
+      suffix: 4
+      args: -pep_type ciss -rg_type ellipse -rg_ellipse_center .5+.5i -rg_ellipse_radius .25 -pep_ciss_moments 4 -pep_ciss_blocksize 5 -pep_ciss_refine_blocksize 2 -terse
+      requires: complex
+      filter: sed -e "s/46483/46484/" | sed -e "s/54946/54945/" | sed -e "s/48456/48457/" | sed -e "s/74117/74116/" | sed -e "s/37240/37241/"
+
 TEST*/
