@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -41,57 +41,72 @@ PetscErrorCode SVDSetUp_Lanczos(SVD svd)
   PetscInt       N;
 
   PetscFunctionBegin;
-  ierr = SVDMatGetSize(svd,NULL,&N);CHKERRQ(ierr);
+  SVDCheckStandard(svd);
+  ierr = MatGetSize(svd->A,NULL,&N);CHKERRQ(ierr);
   ierr = SVDSetDimensions_Default(svd);CHKERRQ(ierr);
-  if (svd->ncv>svd->nsv+svd->mpd) SETERRQ(PetscObjectComm((PetscObject)svd),1,"The value of ncv must not be larger than nev+mpd");
+  if (svd->ncv>svd->nsv+svd->mpd) SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_USER_INPUT,"The value of ncv must not be larger than nev+mpd");
   if (svd->max_it==PETSC_DEFAULT) svd->max_it = PetscMax(N/svd->ncv,100);
   svd->leftbasis = PetscNot(lanczos->oneside);
   ierr = SVDAllocateSolution(svd,1);CHKERRQ(ierr);
   ierr = DSSetType(svd->ds,DSSVD);CHKERRQ(ierr);
   ierr = DSSetCompact(svd->ds,PETSC_TRUE);CHKERRQ(ierr);
-  ierr = DSAllocate(svd->ds,svd->ncv);CHKERRQ(ierr);
+  ierr = DSSetExtraRow(svd->ds,PETSC_TRUE);CHKERRQ(ierr);
+  ierr = DSAllocate(svd->ds,svd->ncv+1);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
-PetscErrorCode SVDTwoSideLanczos(SVD svd,PetscReal *alpha,PetscReal *beta,BV V,BV U,PetscInt k,PetscInt n)
+PetscErrorCode SVDTwoSideLanczos(SVD svd,PetscReal *alpha,PetscReal *beta,BV V,BV U,PetscInt k,PetscInt *n,PetscBool *breakdown)
 {
   PetscErrorCode ierr;
   PetscInt       i;
   Vec            u,v;
+  PetscBool      lindep=PETSC_FALSE;
 
   PetscFunctionBegin;
   ierr = BVGetColumn(svd->V,k,&v);CHKERRQ(ierr);
   ierr = BVGetColumn(svd->U,k,&u);CHKERRQ(ierr);
-  ierr = SVDMatMult(svd,PETSC_FALSE,v,u);CHKERRQ(ierr);
+  ierr = MatMult(svd->A,v,u);CHKERRQ(ierr);
   ierr = BVRestoreColumn(svd->V,k,&v);CHKERRQ(ierr);
   ierr = BVRestoreColumn(svd->U,k,&u);CHKERRQ(ierr);
-  ierr = BVOrthogonalizeColumn(svd->U,k,NULL,alpha+k,NULL);CHKERRQ(ierr);
-  ierr = BVScaleColumn(U,k,1.0/alpha[k]);CHKERRQ(ierr);
-
-  for (i=k+1;i<n;i++) {
-    ierr = BVGetColumn(svd->V,i,&v);CHKERRQ(ierr);
-    ierr = BVGetColumn(svd->U,i-1,&u);CHKERRQ(ierr);
-    ierr = SVDMatMult(svd,PETSC_TRUE,u,v);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(svd->V,i,&v);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(svd->U,i-1,&u);CHKERRQ(ierr);
-    ierr = BVOrthogonalizeColumn(svd->V,i,NULL,beta+i-1,NULL);CHKERRQ(ierr);
-    ierr = BVScaleColumn(V,i,1.0/beta[i-1]);CHKERRQ(ierr);
-
-    ierr = BVGetColumn(svd->V,i,&v);CHKERRQ(ierr);
-    ierr = BVGetColumn(svd->U,i,&u);CHKERRQ(ierr);
-    ierr = SVDMatMult(svd,PETSC_FALSE,v,u);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(svd->V,i,&v);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(svd->U,i,&u);CHKERRQ(ierr);
-    ierr = BVOrthogonalizeColumn(svd->U,i,NULL,alpha+i,NULL);CHKERRQ(ierr);
-    ierr = BVScaleColumn(U,i,1.0/alpha[i]);CHKERRQ(ierr);
+  ierr = BVOrthonormalizeColumn(svd->U,k,PETSC_FALSE,alpha+k,&lindep);CHKERRQ(ierr);
+  if (lindep) {
+    *n = k;
+    if (breakdown) *breakdown = lindep;
+    PetscFunctionReturn(0);
   }
 
-  ierr = BVGetColumn(svd->V,n,&v);CHKERRQ(ierr);
-  ierr = BVGetColumn(svd->U,n-1,&u);CHKERRQ(ierr);
-  ierr = SVDMatMult(svd,PETSC_TRUE,u,v);CHKERRQ(ierr);
-  ierr = BVRestoreColumn(svd->V,n,&v);CHKERRQ(ierr);
-  ierr = BVRestoreColumn(svd->U,n-1,&u);CHKERRQ(ierr);
-  ierr = BVOrthogonalizeColumn(svd->V,n,NULL,beta+n-1,NULL);CHKERRQ(ierr);
+  for (i=k+1;i<*n;i++) {
+    ierr = BVGetColumn(svd->V,i,&v);CHKERRQ(ierr);
+    ierr = BVGetColumn(svd->U,i-1,&u);CHKERRQ(ierr);
+    ierr = MatMult(svd->AT,u,v);CHKERRQ(ierr);
+    ierr = BVRestoreColumn(svd->V,i,&v);CHKERRQ(ierr);
+    ierr = BVRestoreColumn(svd->U,i-1,&u);CHKERRQ(ierr);
+    ierr = BVOrthonormalizeColumn(svd->V,i,PETSC_FALSE,beta+i-1,&lindep);CHKERRQ(ierr);
+    if (lindep) {
+      *n = i;
+      break;
+    }
+    ierr = BVGetColumn(svd->V,i,&v);CHKERRQ(ierr);
+    ierr = BVGetColumn(svd->U,i,&u);CHKERRQ(ierr);
+    ierr = MatMult(svd->A,v,u);CHKERRQ(ierr);
+    ierr = BVRestoreColumn(svd->V,i,&v);CHKERRQ(ierr);
+    ierr = BVRestoreColumn(svd->U,i,&u);CHKERRQ(ierr);
+    ierr = BVOrthonormalizeColumn(svd->U,i,PETSC_FALSE,alpha+i,&lindep);CHKERRQ(ierr);
+    if (lindep) {
+      *n = i;
+      break;
+    }
+  }
+
+  if (!lindep) {
+    ierr = BVGetColumn(svd->V,*n,&v);CHKERRQ(ierr);
+    ierr = BVGetColumn(svd->U,*n-1,&u);CHKERRQ(ierr);
+    ierr = MatMult(svd->AT,u,v);CHKERRQ(ierr);
+    ierr = BVRestoreColumn(svd->V,*n,&v);CHKERRQ(ierr);
+    ierr = BVRestoreColumn(svd->U,*n-1,&u);CHKERRQ(ierr);
+    ierr = BVOrthogonalizeColumn(svd->V,*n,NULL,beta+*n-1,&lindep);CHKERRQ(ierr);
+  }
+  if (breakdown) *breakdown = lindep;
   PetscFunctionReturn(0);
 }
 
@@ -105,12 +120,12 @@ static PetscErrorCode SVDOneSideLanczos(SVD svd,PetscReal *alpha,PetscReal *beta
   PetscFunctionBegin;
   ierr = BVGetActiveColumns(V,&bvl,&bvk);CHKERRQ(ierr);
   ierr = BVGetColumn(V,k,&z);CHKERRQ(ierr);
-  ierr = SVDMatMult(svd,PETSC_FALSE,z,u);CHKERRQ(ierr);
+  ierr = MatMult(svd->A,z,u);CHKERRQ(ierr);
   ierr = BVRestoreColumn(V,k,&z);CHKERRQ(ierr);
 
   for (i=k+1;i<n;i++) {
     ierr = BVGetColumn(V,i,&z);CHKERRQ(ierr);
-    ierr = SVDMatMult(svd,PETSC_TRUE,u,z);CHKERRQ(ierr);
+    ierr = MatMult(svd->AT,u,z);CHKERRQ(ierr);
     ierr = BVRestoreColumn(V,i,&z);CHKERRQ(ierr);
     ierr = VecNormBegin(u,NORM_2,&a);CHKERRQ(ierr);
     ierr = BVSetActiveColumns(V,0,i);CHKERRQ(ierr);
@@ -124,11 +139,11 @@ static PetscErrorCode SVDOneSideLanczos(SVD svd,PetscReal *alpha,PetscReal *beta
     ierr = BVDotColumn(V,i,work);CHKERRQ(ierr);
     ierr = BVMultColumn(V,-1.0,1.0,i,work);CHKERRQ(ierr);
     ierr = BVNormColumn(V,i,NORM_2,&b);CHKERRQ(ierr);
-    if (PetscAbsReal(b)<10*PETSC_MACHINE_EPSILON) SETERRQ(PetscObjectComm((PetscObject)svd),1,"Recurrence generated a zero vector; use a two-sided variant");
+    if (PetscAbsReal(b)<10*PETSC_MACHINE_EPSILON) SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_PLIB,"Recurrence generated a zero vector; use a two-sided variant");
     ierr = BVScaleColumn(V,i,1.0/b);CHKERRQ(ierr);
 
     ierr = BVGetColumn(V,i,&z);CHKERRQ(ierr);
-    ierr = SVDMatMult(svd,PETSC_FALSE,z,u_1);CHKERRQ(ierr);
+    ierr = MatMult(svd->A,z,u_1);CHKERRQ(ierr);
     ierr = BVRestoreColumn(V,i,&z);CHKERRQ(ierr);
     ierr = VecAXPY(u_1,-b,u);CHKERRQ(ierr);
     alpha[i-1] = a;
@@ -139,7 +154,7 @@ static PetscErrorCode SVDOneSideLanczos(SVD svd,PetscReal *alpha,PetscReal *beta
   }
 
   ierr = BVGetColumn(V,n,&z);CHKERRQ(ierr);
-  ierr = SVDMatMult(svd,PETSC_TRUE,u,z);CHKERRQ(ierr);
+  ierr = MatMult(svd->AT,u,z);CHKERRQ(ierr);
   ierr = BVRestoreColumn(V,n,&z);CHKERRQ(ierr);
   ierr = VecNormBegin(u,NORM_2,&a);CHKERRQ(ierr);
   ierr = BVDotColumnBegin(V,n,work);CHKERRQ(ierr);
@@ -159,16 +174,60 @@ static PetscErrorCode SVDOneSideLanczos(SVD svd,PetscReal *alpha,PetscReal *beta
   PetscFunctionReturn(0);
 }
 
+/*
+   SVDKrylovConvergence - Implements the loop that checks for convergence
+   in Krylov methods.
+
+   Input Parameters:
+     svd     - the solver; some error estimates are updated in svd->errest
+     getall  - whether all residuals must be computed
+     kini    - initial value of k (the loop variable)
+     nits    - number of iterations of the loop
+
+   Output Parameter:
+     kout  - the first index where the convergence test failed
+*/
+PetscErrorCode SVDKrylovConvergence(SVD svd,PetscBool getall,PetscInt kini,PetscInt nits,PetscInt *kout)
+{
+  PetscErrorCode ierr;
+  PetscInt       k,marker,ld;
+  PetscReal      *alpha,*beta,*betah,resnorm;
+  PetscBool      extra;
+
+  PetscFunctionBegin;
+  if (svd->conv == SVD_CONV_MAXIT && svd->its >= svd->max_it) *kout = svd->nsv;
+  else {
+    ierr = DSGetLeadingDimension(svd->ds,&ld);CHKERRQ(ierr);
+    ierr = DSGetExtraRow(svd->ds,&extra);CHKERRQ(ierr);
+    if (!extra) SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_SUP,"Only implemented for DS with extra row");
+    marker = -1;
+    if (svd->trackall) getall = PETSC_TRUE;
+    ierr = DSGetArrayReal(svd->ds,DS_MAT_T,&alpha);CHKERRQ(ierr);
+    beta = alpha + ld;
+    betah = alpha + 2*ld;
+    for (k=kini;k<kini+nits;k++) {
+      if (svd->isgeneralized) resnorm = SlepcAbs(beta[k],betah[k]);
+      else resnorm = PetscAbsReal(beta[k]);
+      ierr = (*svd->converged)(svd,svd->sigma[k],resnorm,&svd->errest[k],svd->convergedctx);CHKERRQ(ierr);
+      if (marker==-1 && svd->errest[k] >= svd->tol) marker = k;
+      if (marker!=-1 && !getall) break;
+    }
+    ierr = DSRestoreArrayReal(svd->ds,DS_MAT_T,&alpha);CHKERRQ(ierr);
+    if (marker!=-1) k = marker;
+    *kout = k;
+  }
+  PetscFunctionReturn(0);
+}
+
 PetscErrorCode SVDSolve_Lanczos(SVD svd)
 {
   PetscErrorCode ierr;
   SVD_LANCZOS    *lanczos = (SVD_LANCZOS*)svd->data;
-  PetscReal      *alpha,*beta,lastbeta,norm,resnorm;
-  PetscScalar    *swork,*w,*Q,*PT;
+  PetscReal      *alpha,*beta;
+  PetscScalar    *swork,*w,*P;
   PetscInt       i,k,j,nv,ld;
   Vec            u=0,u_1=0;
-  Mat            U,VT;
-  PetscBool      conv;
+  Mat            U,V;
 
   PetscFunctionBegin;
   /* allocate working space */
@@ -176,15 +235,14 @@ PetscErrorCode SVDSolve_Lanczos(SVD svd)
   ierr = PetscMalloc2(ld,&w,svd->ncv,&swork);CHKERRQ(ierr);
 
   if (lanczos->oneside) {
-    ierr = SVDMatCreateVecs(svd,NULL,&u);CHKERRQ(ierr);
-    ierr = SVDMatCreateVecs(svd,NULL,&u_1);CHKERRQ(ierr);
+    ierr = MatCreateVecs(svd->A,NULL,&u);CHKERRQ(ierr);
+    ierr = MatCreateVecs(svd->A,NULL,&u_1);CHKERRQ(ierr);
   }
 
   /* normalize start vector */
   if (!svd->nini) {
     ierr = BVSetRandomColumn(svd->V,0);CHKERRQ(ierr);
-    ierr = BVNormColumn(svd->V,0,NORM_2,&norm);CHKERRQ(ierr);
-    ierr = BVScaleColumn(svd->V,0,1.0/norm);CHKERRQ(ierr);
+    ierr = BVOrthonormalizeColumn(svd->V,0,PETSC_TRUE,NULL,NULL);CHKERRQ(ierr);
   }
 
   while (svd->reason == SVD_CONVERGED_ITERATING) {
@@ -199,67 +257,54 @@ PetscErrorCode SVDSolve_Lanczos(SVD svd)
       ierr = SVDOneSideLanczos(svd,alpha,beta,svd->V,u,u_1,svd->nconv,nv,swork);CHKERRQ(ierr);
     } else {
       ierr = BVSetActiveColumns(svd->U,svd->nconv,nv);CHKERRQ(ierr);
-      ierr = SVDTwoSideLanczos(svd,alpha,beta,svd->V,svd->U,svd->nconv,nv);CHKERRQ(ierr);
+      ierr = SVDTwoSideLanczos(svd,alpha,beta,svd->V,svd->U,svd->nconv,&nv,NULL);CHKERRQ(ierr);
     }
-    lastbeta = beta[nv-1];
     ierr = DSRestoreArrayReal(svd->ds,DS_MAT_T,&alpha);CHKERRQ(ierr);
 
     /* compute SVD of bidiagonal matrix */
-    ierr = DSSetDimensions(svd->ds,nv,nv,svd->nconv,0);CHKERRQ(ierr);
+    ierr = DSSetDimensions(svd->ds,nv,svd->nconv,0);CHKERRQ(ierr);
+    ierr = DSSVDSetDimensions(svd->ds,nv);CHKERRQ(ierr);
     ierr = DSSetState(svd->ds,DS_STATE_INTERMEDIATE);CHKERRQ(ierr);
     ierr = DSSolve(svd->ds,w,NULL);CHKERRQ(ierr);
     ierr = DSSort(svd->ds,w,NULL,NULL,NULL,NULL);CHKERRQ(ierr);
+    ierr = DSUpdateExtraRow(svd->ds);CHKERRQ(ierr);
     ierr = DSSynchronize(svd->ds,w,NULL);CHKERRQ(ierr);
-
-    /* compute error estimates */
-    k = 0;
-    conv = PETSC_TRUE;
-    ierr = DSGetArray(svd->ds,DS_MAT_U,&Q);CHKERRQ(ierr);
-    for (i=svd->nconv;i<nv;i++) {
-      svd->sigma[i] = PetscRealPart(w[i]);
-      resnorm = PetscAbsScalar(Q[nv-1+i*ld])*lastbeta;
-      ierr = (*svd->converged)(svd,svd->sigma[i],resnorm,&svd->errest[i],svd->convergedctx);CHKERRQ(ierr);
-      if (conv) {
-        if (svd->errest[i] < svd->tol) k++;
-        else conv = PETSC_FALSE;
-      }
-    }
-    ierr = DSRestoreArray(svd->ds,DS_MAT_U,&Q);CHKERRQ(ierr);
+    for (i=svd->nconv;i<nv;i++) svd->sigma[i] = PetscRealPart(w[i]);
 
     /* check convergence */
-    ierr = (*svd->stopping)(svd,svd->its,svd->max_it,svd->nconv+k,svd->nsv,&svd->reason,svd->stoppingctx);CHKERRQ(ierr);
+    ierr = SVDKrylovConvergence(svd,PETSC_FALSE,svd->nconv,nv-svd->nconv,&k);CHKERRQ(ierr);
+    ierr = (*svd->stopping)(svd,svd->its,svd->max_it,k,svd->nsv,&svd->reason,svd->stoppingctx);CHKERRQ(ierr);
 
     /* compute restart vector */
-    ierr = DSGetArray(svd->ds,DS_MAT_VT,&PT);CHKERRQ(ierr);
     if (svd->reason == SVD_CONVERGED_ITERATING) {
-      if (k<nv-svd->nconv) {
-        for (j=svd->nconv;j<nv;j++) swork[j-svd->nconv] = PT[k+svd->nconv+j*ld];
+      if (k<nv) {
+        ierr = DSGetArray(svd->ds,DS_MAT_V,&P);CHKERRQ(ierr);
+        for (j=svd->nconv;j<nv;j++) swork[j-svd->nconv] = PetscConj(P[j+k*ld]);
+        ierr = DSRestoreArray(svd->ds,DS_MAT_V,&P);CHKERRQ(ierr);
         ierr = BVMultColumn(svd->V,1.0,0.0,nv,swork);CHKERRQ(ierr);
       } else {
         /* all approximations have converged, generate a new initial vector */
         ierr = BVSetRandomColumn(svd->V,nv);CHKERRQ(ierr);
-        ierr = BVOrthogonalizeColumn(svd->V,nv,NULL,&norm,NULL);CHKERRQ(ierr);
-        ierr = BVScaleColumn(svd->V,nv,1.0/norm);CHKERRQ(ierr);
+        ierr = BVOrthonormalizeColumn(svd->V,nv,PETSC_FALSE,NULL,NULL);CHKERRQ(ierr);
       }
     }
-    ierr = DSRestoreArray(svd->ds,DS_MAT_VT,&PT);CHKERRQ(ierr);
 
     /* compute converged singular vectors */
-    ierr = DSGetMat(svd->ds,DS_MAT_VT,&VT);CHKERRQ(ierr);
-    ierr = BVMultInPlaceTranspose(svd->V,VT,svd->nconv,svd->nconv+k);CHKERRQ(ierr);
-    ierr = MatDestroy(&VT);CHKERRQ(ierr);
+    ierr = DSGetMat(svd->ds,DS_MAT_V,&V);CHKERRQ(ierr);
+    ierr = BVMultInPlace(svd->V,V,svd->nconv,k);CHKERRQ(ierr);
+    ierr = MatDestroy(&V);CHKERRQ(ierr);
     if (!lanczos->oneside) {
       ierr = DSGetMat(svd->ds,DS_MAT_U,&U);CHKERRQ(ierr);
-      ierr = BVMultInPlace(svd->U,U,svd->nconv,svd->nconv+k);CHKERRQ(ierr);
+      ierr = BVMultInPlace(svd->U,U,svd->nconv,k);CHKERRQ(ierr);
       ierr = MatDestroy(&U);CHKERRQ(ierr);
     }
 
     /* copy restart vector from the last column */
     if (svd->reason == SVD_CONVERGED_ITERATING) {
-      ierr = BVCopyColumn(svd->V,nv,svd->nconv+k);CHKERRQ(ierr);
+      ierr = BVCopyColumn(svd->V,nv,k);CHKERRQ(ierr);
     }
 
-    svd->nconv += k;
+    svd->nconv = k;
     ierr = SVDMonitor(svd,svd->its,svd->nconv,svd->sigma,svd->errest,nv);CHKERRQ(ierr);
   }
 
@@ -407,6 +452,7 @@ SLEPC_EXTERN PetscErrorCode SVDCreate_Lanczos(SVD svd)
   svd->ops->destroy        = SVDDestroy_Lanczos;
   svd->ops->setfromoptions = SVDSetFromOptions_Lanczos;
   svd->ops->view           = SVDView_Lanczos;
+  svd->ops->computevectors = SVDComputeVectors_Left;
   ierr = PetscObjectComposeFunction((PetscObject)svd,"SVDLanczosSetOneSide_C",SVDLanczosSetOneSide_Lanczos);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)svd,"SVDLanczosGetOneSide_C",SVDLanczosGetOneSide_Lanczos);CHKERRQ(ierr);
   PetscFunctionReturn(0);
