@@ -358,6 +358,7 @@ PetscErrorCode SVDSetConvergenceTestFunction(SVD svd,PetscErrorCode (*func)(SVD,
   svd->convergedctx     = ctx;
   if (func == SVDConvergedAbsolute) svd->conv = SVD_CONV_ABS;
   else if (func == SVDConvergedRelative) svd->conv = SVD_CONV_REL;
+  else if (func == SVDConvergedNorm) svd->conv = SVD_CONV_NORM;
   else if (func == SVDConvergedMaxIt) svd->conv = SVD_CONV_MAXIT;
   else {
     svd->conv      = SVD_CONV_USER;
@@ -379,6 +380,7 @@ PetscErrorCode SVDSetConvergenceTestFunction(SVD svd,PetscErrorCode (*func)(SVD,
    Options Database Keys:
 +  -svd_conv_abs   - Sets the absolute convergence test
 .  -svd_conv_rel   - Sets the convergence test relative to the singular value
+.  -svd_conv_norm  - Sets the convergence test relative to the matrix norms
 .  -svd_conv_maxit - Forces the maximum number of iterations as set by -svd_max_it
 -  -svd_conv_user  - Selects the user-defined convergence test
 
@@ -386,6 +388,7 @@ PetscErrorCode SVDSetConvergenceTestFunction(SVD svd,PetscErrorCode (*func)(SVD,
    The parameter 'conv' can have one of these values
 +     SVD_CONV_ABS   - absolute error ||r||
 .     SVD_CONV_REL   - error relative to the singular value l, ||r||/sigma
+.     SVD_CONV_NORM  - error relative to the matrix norms, ||r||/||A||
 .     SVD_CONV_MAXIT - no convergence until maximum number of iterations has been reached
 -     SVD_CONV_USER  - function set by SVDSetConvergenceTestFunction()
 
@@ -401,6 +404,7 @@ PetscErrorCode SVDSetConvergenceTest(SVD svd,SVDConv conv)
   switch (conv) {
     case SVD_CONV_ABS:   svd->converged = SVDConvergedAbsolute; break;
     case SVD_CONV_REL:   svd->converged = SVDConvergedRelative; break;
+    case SVD_CONV_NORM:  svd->converged = SVDConvergedNorm; break;
     case SVD_CONV_MAXIT: svd->converged = SVDConvergedMaxIt; break;
     case SVD_CONV_USER:
       if (!svd->convergeduser) SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_ORDER,"Must call SVDSetConvergenceTestFunction() first");
@@ -594,6 +598,7 @@ PetscErrorCode SVDMonitorSetFromOptions(SVD svd,const char opt[],const char name
   ierr = PetscViewerGetType(viewer,&vtype);CHKERRQ(ierr);
   ierr = SlepcMonitorMakeKey_Internal(name,vtype,format,key);CHKERRQ(ierr);
   ierr = PetscFunctionListFind(SVDMonitorList,key,&mfunc);CHKERRQ(ierr);
+  if (!mfunc) SETERRQ(PetscObjectComm((PetscObject)svd),PETSC_ERR_SUP,"Specified viewer and format not supported");
   ierr = PetscFunctionListFind(SVDMonitorCreateList,key,&cfunc);CHKERRQ(ierr);
   ierr = PetscFunctionListFind(SVDMonitorDestroyList,key,&dfunc);CHKERRQ(ierr);
   if (!cfunc) cfunc = PetscViewerAndFormatCreate_Internal;
@@ -655,13 +660,15 @@ PetscErrorCode SVDSetFromOptions(SVD svd)
     i = svd->max_it;
     ierr = PetscOptionsInt("-svd_max_it","Maximum number of iterations","SVDSetTolerances",svd->max_it,&i,&flg1);CHKERRQ(ierr);
     r = svd->tol;
-    ierr = PetscOptionsReal("-svd_tol","Tolerance","SVDSetTolerances",svd->tol==PETSC_DEFAULT?SLEPC_DEFAULT_TOL:svd->tol,&r,&flg2);CHKERRQ(ierr);
+    ierr = PetscOptionsReal("-svd_tol","Tolerance","SVDSetTolerances",SlepcDefaultTol(svd->tol),&r,&flg2);CHKERRQ(ierr);
     if (flg1 || flg2) { ierr = SVDSetTolerances(svd,r,i);CHKERRQ(ierr); }
 
     ierr = PetscOptionsBoolGroupBegin("-svd_conv_abs","Absolute error convergence test","SVDSetConvergenceTest",&flg);CHKERRQ(ierr);
     if (flg) { ierr = SVDSetConvergenceTest(svd,SVD_CONV_ABS);CHKERRQ(ierr); }
     ierr = PetscOptionsBoolGroup("-svd_conv_rel","Relative error convergence test","SVDSetConvergenceTest",&flg);CHKERRQ(ierr);
     if (flg) { ierr = SVDSetConvergenceTest(svd,SVD_CONV_REL);CHKERRQ(ierr); }
+    ierr = PetscOptionsBoolGroup("-svd_conv_norm","Convergence test relative to the matrix norms","SVDSetConvergenceTest",&flg);CHKERRQ(ierr);
+    if (flg) { ierr = SVDSetConvergenceTest(svd,SVD_CONV_NORM);CHKERRQ(ierr); }
     ierr = PetscOptionsBoolGroup("-svd_conv_maxit","Maximum iterations convergence test","SVDSetConvergenceTest",&flg);CHKERRQ(ierr);
     if (flg) { ierr = SVDSetConvergenceTest(svd,SVD_CONV_MAXIT);CHKERRQ(ierr); }
     ierr = PetscOptionsBoolGroupEnd("-svd_conv_user","User-defined convergence test","SVDSetConvergenceTest",&flg);CHKERRQ(ierr);
@@ -864,7 +871,6 @@ PetscErrorCode SVDGetTrackAll(SVD svd,PetscBool *trackall)
   PetscFunctionReturn(0);
 }
 
-
 /*@C
    SVDSetOptionsPrefix - Sets the prefix used for searching for all
    SVD options in the database.
