@@ -68,12 +68,12 @@ int main(int argc,char **argv)
   ierr = MatSetUp(B);CHKERRQ(ierr);
   ierr = MatGetOwnershipRange(B,&Istart,&Iend);CHKERRQ(ierr);
   for (i=Istart;i<Iend;i++) {
-    col[0]=i; col[1]=i+1;
+    col[0]=i-1; col[1]=i;
     if (i==0) {
-      ierr = MatSetValue(B,i,col[0],valsb[1],INSERT_VALUES);CHKERRQ(ierr);
-    } else if (i<n-1) {
+      ierr = MatSetValue(B,i,col[1],valsb[1],INSERT_VALUES);CHKERRQ(ierr);
+    } else if (i<n) {
       ierr = MatSetValues(B,1,&i,2,col,valsb,INSERT_VALUES);CHKERRQ(ierr);
-    } else if (i==n-1) {
+    } else if (i==n) {
       ierr = MatSetValue(B,i,col[0],valsb[0],INSERT_VALUES);CHKERRQ(ierr);
     }
   }
