@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -34,6 +34,7 @@ int main(int argc,char **argv)
   SVDConv              conv;
   SVDStop              stop;
   SVDWhich             which;
+  SVDProblemType       ptype;
   SVDConvergedReason   reason;
   PetscInt             m=20,n,Istart,Iend,i,col[2],its;
   PetscScalar          value[] = { 1, 2 };
@@ -77,10 +78,10 @@ int main(int argc,char **argv)
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
   ierr = SVDCreate(PETSC_COMM_WORLD,&svd);CHKERRQ(ierr);
-  ierr = SVDSetOperator(svd,A);CHKERRQ(ierr);
+  ierr = SVDSetOperators(svd,A,NULL);CHKERRQ(ierr);
 
   /* test some interface functions */
-  ierr = SVDGetOperator(svd,&B);CHKERRQ(ierr);
+  ierr = SVDGetOperators(svd,&B,NULL);CHKERRQ(ierr);
   ierr = MatView(B,PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
   ierr = SVDSetConvergenceTest(svd,SVD_CONV_ABS);CHKERRQ(ierr);
   ierr = SVDSetStoppingTest(svd,SVD_STOP_BASIC);CHKERRQ(ierr);
@@ -91,14 +92,18 @@ int main(int argc,char **argv)
   ierr = SVDSetFromOptions(svd);CHKERRQ(ierr);
 
   /* query properties and print them */
+  ierr = SVDGetProblemType(svd,&ptype);CHKERRQ(ierr);
+  ierr = PetscPrintf(PETSC_COMM_WORLD," Problem type = %d",(int)ptype);CHKERRQ(ierr);
+  ierr = SVDIsGeneralized(svd,&flg);CHKERRQ(ierr);
+  if (flg) { ierr = PetscPrintf(PETSC_COMM_WORLD," generalized");CHKERRQ(ierr); }
   ierr = SVDGetImplicitTranspose(svd,&tmode);CHKERRQ(ierr);
-  ierr = PetscPrintf(PETSC_COMM_WORLD," Transpose mode is %s\n",tmode?"implicit":"explicit");CHKERRQ(ierr);
+  ierr = PetscPrintf(PETSC_COMM_WORLD,"\n Transpose mode is %s\n",tmode?"implicit":"explicit");CHKERRQ(ierr);
   ierr = SVDGetConvergenceTest(svd,&conv);CHKERRQ(ierr);
   ierr = PetscPrintf(PETSC_COMM_WORLD," Convergence test is %s\n",ctest[conv]);CHKERRQ(ierr);
   ierr = SVDGetStoppingTest(svd,&stop);CHKERRQ(ierr);
   ierr = PetscPrintf(PETSC_COMM_WORLD," Stopping test is %s\n",stest[stop]);CHKERRQ(ierr);
   ierr = SVDGetWhichSingularTriplets(svd,&which);CHKERRQ(ierr);
-  ierr = PetscPrintf(PETSC_COMM_WORLD," Which = %s\n",which?"largest":"smallest");CHKERRQ(ierr);
+  ierr = PetscPrintf(PETSC_COMM_WORLD," Which = %s\n",which?"smallest":"largest");CHKERRQ(ierr);
 
   /* call the solver */
   ierr = SVDSolve(svd);CHKERRQ(ierr);
@@ -126,9 +131,12 @@ int main(int argc,char **argv)
       test:
          suffix: 1_lanczos
          args: -svd_type lanczos
+      test:
+         suffix: 1_randomized
+         args: -svd_type randomized
       test:
          suffix: 1_trlanczos
-         args: -svd_type trlanczos -svd_ncv 12
+         args: -svd_type trlanczos -svd_ncv 12 -svd_trlanczos_restart 0.6
       test:
          suffix: 1_cross
          args: -svd_type cross
