@@ -67,7 +67,7 @@ int main(int argc,char **argv)
     ierr = PetscViewerDestroy(&viewer);CHKERRQ(ierr);
     for (i=0;i<nconv;i++) {
       ierr = SVDGetSingularTriplet(svd,i,&sval,NULL,NULL);CHKERRQ(ierr);
-      if (sval!=sigma[i]) SETERRQ(PETSC_COMM_WORLD,1,"Singular values in the file do not match");
+      if (sval!=sigma[i]) SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_FILE_UNEXPECTED,"Singular values in the file do not match");
     }
     ierr = PetscFree(sigma);CHKERRQ(ierr);
   }
