@@ -43,7 +43,7 @@ PetscErrorCode BVMultInPlace_Tensor(BV V,Mat Q,PetscInt s,PetscInt e)
   PetscFunctionReturn(0);
 }
 
-PetscErrorCode BVMultInPlaceTranspose_Tensor(BV V,Mat Q,PetscInt s,PetscInt e)
+PetscErrorCode BVMultInPlaceHermitianTranspose_Tensor(BV V,Mat Q,PetscInt s,PetscInt e)
 {
   PetscErrorCode    ierr;
   BV_TENSOR         *ctx = (BV_TENSOR*)V->data;
@@ -454,7 +454,7 @@ static PetscErrorCode BVTensorCompress_Tensor(BV V,PetscInt newc)
     }
     /*
       update columns associated with non-converged vectors, orthogonalize
-      against pQ so that next M has rank nnc+d-1 insted of nrow+d-1
+      against pQ so that next M has rank nnc+d-1 instead of nrow+d-1
     */
     for (i=0;i<deg;i++) {
       PetscStackCallBLAS("BLASgemm",BLASgemm_("C","N",&newc_,&nnc_,&nrow_,&sone,pQ+offu,&rs1_,S+(lock+newc)*lds+i*ctx->ld+lock,&lds_,&zero,SS+i*newc*nnc,&newc_));
@@ -767,7 +767,7 @@ SLEPC_EXTERN PetscErrorCode BVCreate_Tensor(BV bv)
   ctx->puk = -1;
 
   bv->ops->multinplace      = BVMultInPlace_Tensor;
-  bv->ops->multinplacetrans = BVMultInPlaceTranspose_Tensor;
+  bv->ops->multinplacetrans = BVMultInPlaceHermitianTranspose_Tensor;
   bv->ops->dot              = BVDot_Tensor;
   bv->ops->scale            = BVScale_Tensor;
   bv->ops->norm             = BVNorm_Tensor;
