@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -21,7 +21,7 @@ PetscFunctionList BVList = 0;
 
    Logically Collective on bv
 
-   Input Parameter:
+   Input Parameters:
 +  bv   - the basis vectors context
 -  type - a known type
 
@@ -44,7 +44,7 @@ PetscErrorCode BVSetType(BV bv,BVType type)
   ierr = PetscObjectTypeCompare((PetscObject)bv,type,&match);CHKERRQ(ierr);
   if (match) PetscFunctionReturn(0);
   ierr = PetscStrcmp(type,BVTENSOR,&match);CHKERRQ(ierr);
-  if (match) SETERRQ(PetscObjectComm((PetscObject)bv),1,"Use BVCreateTensor() to create a BV of type tensor");
+  if (match) SETERRQ(PetscObjectComm((PetscObject)bv),PETSC_ERR_ORDER,"Use BVCreateTensor() to create a BV of type tensor");
 
   ierr =  PetscFunctionListFind(BVList,type,&r);CHKERRQ(ierr);
   if (!r) SETERRQ1(PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_UNKNOWN_TYPE,"Unable to find requested BV type %s",type);
@@ -357,7 +357,7 @@ PetscErrorCode BVResize(BV bv,PetscInt m,PetscBool copy)
 #if defined(PETSC_HAVE_CUDA)
       ierr = VecCreateSeqCUDA(PETSC_COMM_SELF,m,&v);CHKERRQ(ierr);
 #else
-      SETERRQ(PetscObjectComm((PetscObject)bv),1,"Something wrong happened");
+      SETERRQ(PetscObjectComm((PetscObject)bv),PETSC_ERR_PLIB,"Something wrong happened");
 #endif
     } else {
       ierr = VecCreateSeq(PETSC_COMM_SELF,m,&v);CHKERRQ(ierr);
@@ -420,13 +420,13 @@ PetscErrorCode BVSetActiveColumns(BV bv,PetscInt l,PetscInt k)
   if (k==PETSC_DECIDE || k==PETSC_DEFAULT) {
     bv->k = bv->m;
   } else {
-    if (k<0 || k>bv->m) SETERRQ(PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of k. Must be between 0 and m");
+    if (k<0 || k>bv->m) SETERRQ2(PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of k (%D). Must be between 0 and m (%D)",k,bv->m);
     bv->k = k;
   }
   if (l==PETSC_DECIDE || l==PETSC_DEFAULT) {
     bv->l = 0;
   } else {
-    if (l<0 || l>bv->k) SETERRQ(PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of l. Must be between 0 and k");
+    if (l<0 || l>bv->k) SETERRQ2(PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of l (%D). Must be between 0 and k (%D)",l,bv->k);
     bv->l = l;
   }
   PetscFunctionReturn(0);
@@ -440,7 +440,7 @@ PetscErrorCode BVSetActiveColumns(BV bv,PetscInt l,PetscInt k)
    Input Parameter:
 .  bv - the basis vectors context
 
-   Output Parameter:
+   Output Parameters:
 +  l  - number of leading columns
 -  k  - number of active columns
 
@@ -484,7 +484,7 @@ PetscErrorCode BVGetActiveColumns(BV bv,PetscInt *l,PetscInt *k)
 
    Level: advanced
 
-.seealso: BVGetMatrix(), BVDot(), BVNorm(), BVOrthogonalize()
+.seealso: BVGetMatrix(), BVDot(), BVNorm(), BVOrthogonalize(), BVSetDefiniteTolerance()
 @*/
 PetscErrorCode BVSetMatrix(BV bv,Mat B,PetscBool indef)
 {
@@ -520,7 +520,7 @@ PetscErrorCode BVSetMatrix(BV bv,Mat B,PetscBool indef)
    Input Parameter:
 .  bv    - the basis vectors context
 
-   Output Parameter:
+   Output Parameters:
 +  B     - the matrix of the inner product (may be NULL)
 -  indef - the flag indicating if the matrix is indefinite
 
@@ -543,7 +543,7 @@ PetscErrorCode BVGetMatrix(BV bv,Mat *B,PetscBool *indef)
 
    Neighbor-wise Collective on bv
 
-   Input Parameter:
+   Input Parameters:
 +  bv - the basis vectors context
 -  x  - the vector
 
@@ -621,7 +621,7 @@ PetscErrorCode BVApplyMatrixBV(BV X,BV Y)
 
    Logically Collective on bv
 
-   Input Parameter:
+   Input Parameters:
 +  bv    - the basis vectors context
 -  omega - a vector representing the diagonal of the signature matrix
 
@@ -740,7 +740,7 @@ PetscErrorCode BVSetBufferVec(BV bv,Vec buffer)
   ierr = VecGetSize(buffer,&n);CHKERRQ(ierr);
   ld = bv->m+bv->nc;
   if (n != ld*bv->m) SETERRQ1(PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_SIZ,"Buffer size must be %d",ld*bv->m);
-  ierr = MPI_Comm_size(PetscObjectComm((PetscObject)buffer),&size);CHKERRQ(ierr);
+  ierr = MPI_Comm_size(PetscObjectComm((PetscObject)buffer),&size);CHKERRMPI(ierr);
   if (size>1) SETERRQ(PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_WRONG,"Buffer must be a sequential vector");
 
   ierr = PetscObjectReference((PetscObject)buffer);CHKERRQ(ierr);
@@ -816,7 +816,7 @@ PetscErrorCode BVGetBufferVec(BV bv,Vec *buffer)
 
    Level: advanced
 
-.seealso: BVGetRandomContext(), BVSetRandom(), BVSetRandomColumn()
+.seealso: BVGetRandomContext(), BVSetRandom(), BVSetRandomNormal(), BVSetRandomColumn(), BVSetRandomCond()
 @*/
 PetscErrorCode BVSetRandomContext(BV bv,PetscRandom rand)
 {
@@ -846,7 +846,7 @@ PetscErrorCode BVSetRandomContext(BV bv,PetscRandom rand)
 
    Level: advanced
 
-.seealso: BVSetRandomContext(), BVSetRandom(), BVSetRandomColumn()
+.seealso: BVSetRandomContext(), BVSetRandom(), BVSetRandomNormal(), BVSetRandomColumn(), BVSetRandomCond()
 @*/
 PetscErrorCode BVGetRandomContext(BV bv,PetscRandom* rand)
 {
@@ -858,6 +858,8 @@ PetscErrorCode BVGetRandomContext(BV bv,PetscRandom* rand)
   if (!bv->rand) {
     ierr = PetscRandomCreate(PetscObjectComm((PetscObject)bv),&bv->rand);CHKERRQ(ierr);
     ierr = PetscLogObjectParent((PetscObject)bv,(PetscObject)bv->rand);CHKERRQ(ierr);
+    if (bv->cuda) { ierr = PetscRandomSetType(bv->rand,PETSCCURAND);CHKERRQ(ierr); }
+    if (bv->sfocalled) { ierr = PetscRandomSetFromOptions(bv->rand);CHKERRQ(ierr); }
     if (bv->rrandom) {
       ierr = PetscRandomSetSeed(bv->rand,0x12345678);CHKERRQ(ierr);
       ierr = PetscRandomSeed(bv->rand);CHKERRQ(ierr);
@@ -910,6 +912,9 @@ PetscErrorCode BVSetFromOptions(BV bv)
 
     ierr = PetscOptionsEnum("-bv_matmult","Method for BVMatMult","BVSetMatMultMethod",BVMatMultTypes,(PetscEnum)bv->vmm,(PetscEnum*)&bv->vmm,NULL);CHKERRQ(ierr);
 
+    ierr = PetscOptionsReal("-bv_definite_tol","Tolerance for checking a definite inner product","BVSetDefiniteTolerance",r,&r,&flg1);CHKERRQ(ierr);
+    if (flg1) { ierr = BVSetDefiniteTolerance(bv,r);CHKERRQ(ierr); }
+
     /* undocumented option to generate random vectors that are independent of the number of processes */
     ierr = PetscOptionsGetBool(NULL,NULL,"-bv_reproducible_random",&bv->rrandom,NULL);CHKERRQ(ierr);
 
@@ -919,9 +924,7 @@ PetscErrorCode BVSetFromOptions(BV bv)
     }
     ierr = PetscObjectProcessOptionsHandlers(PetscOptionsObject,(PetscObject)bv);CHKERRQ(ierr);
   ierr = PetscOptionsEnd();CHKERRQ(ierr);
-
-  if (!bv->rand) { ierr = BVGetRandomContext(bv,&bv->rand);CHKERRQ(ierr); }
-  ierr = PetscRandomSetFromOptions(bv->rand);CHKERRQ(ierr);
+  bv->sfocalled = PETSC_TRUE;
   PetscFunctionReturn(0);
 }
 
@@ -1015,7 +1018,7 @@ PetscErrorCode BVSetOrthogonalization(BV bv,BVOrthogType type,BVOrthogRefineType
    Input Parameter:
 .  bv - basis vectors context
 
-   Output Parameter:
+   Output Parameters:
 +  type   - the method of vector orthogonalization
 .  refine - type of refinement
 .  eta    - parameter for selective refinement
@@ -1101,7 +1104,7 @@ PetscErrorCode BVGetMatMultMethod(BV bv,BVMatMultType *method)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
-  PetscValidPointer(bv,method);
+  PetscValidPointer(method,2);
   *method = bv->vmm;
   PetscFunctionReturn(0);
 }
@@ -1410,11 +1413,11 @@ PetscErrorCode BVCreateMat(BV bv,Mat *A)
   PetscValidPointer(A,2);
 
   ierr = MatCreateDense(PetscObjectComm((PetscObject)bv->t),bv->n,PETSC_DECIDE,bv->N,bv->m,NULL,A);CHKERRQ(ierr);
-  ierr = MatDenseGetArray(*A,&aa);CHKERRQ(ierr);
+  ierr = MatDenseGetArrayWrite(*A,&aa);CHKERRQ(ierr);
   ierr = BVGetArrayRead(bv,&vv);CHKERRQ(ierr);
   ierr = PetscArraycpy(aa,vv,bv->m*bv->n);CHKERRQ(ierr);
   ierr = BVRestoreArrayRead(bv,&vv);CHKERRQ(ierr);
-  ierr = MatDenseRestoreArray(*A,&aa);CHKERRQ(ierr);
+  ierr = MatDenseRestoreArrayWrite(*A,&aa);CHKERRQ(ierr);
   ierr = MatAssemblyBegin(*A,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
   ierr = MatAssemblyEnd(*A,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -1540,8 +1543,10 @@ PETSC_STATIC_INLINE PetscErrorCode BVDuplicate_Private(BV V,BV W)
   W->indef        = V->indef;
   W->vmm          = V->vmm;
   W->rrandom      = V->rrandom;
+  W->deftol       = V->deftol;
   if (V->rand) { ierr = PetscObjectReference((PetscObject)V->rand);CHKERRQ(ierr); }
   W->rand         = V->rand;
+  W->sfocalled    = V->sfocalled;
   if (V->ops->duplicate) { ierr = (*V->ops->duplicate)(V,W);CHKERRQ(ierr); }
   ierr = PetscObjectStateIncrease((PetscObject)W);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -1592,7 +1597,7 @@ PetscErrorCode BVDuplicate(BV V,BV *W)
 
    Collective on V
 
-   Input Parameter:
+   Input Parameters:
 +  V - basis vectors context
 -  m - the new number of columns
 
@@ -1721,7 +1726,7 @@ PetscErrorCode BVCopy(BV V,BV W)
 
    Logically Collective on V
 
-   Input Parameter:
+   Input Parameters:
 +  V - basis vectors context
 -  j - the column number to be copied
 
@@ -1766,7 +1771,7 @@ PetscErrorCode BVCopyVec(BV V,PetscInt j,Vec w)
 
    Logically Collective on V
 
-   Input Parameter:
+   Input Parameters:
 +  V - basis vectors context
 .  j - the number of the source column
 -  i - the number of the destination column
@@ -1848,7 +1853,7 @@ static PetscErrorCode BVGetSplit_Private(BV bv,PetscBool left,BV *split)
 
    Logically Collective on bv
 
-   Input Parameters:
+   Input Parameter:
 .  bv - the basis vectors context
 
    Output Parameters:
@@ -1931,3 +1936,70 @@ PetscErrorCode BVRestoreSplit(BV bv,BV *L,BV *R)
   PetscFunctionReturn(0);
 }
 
+/*@
+   BVSetDefiniteTolerance - Set the tolerance to be used when checking a
+   definite inner product.
+
+   Logically Collective on bv
+
+   Input Parameters:
++  bv     - basis vectors
+-  deftol - the tolerance
+
+   Options Database Key:
+.  -bv_definite_tol <deftol> - the tolerance
+
+   Notes:
+   When using a non-standard inner product, see BVSetMatrix(), the solver needs
+   to compute sqrt(z'*B*z) for various vectors z. If the inner product has not
+   been declared indefinite, the value z'*B*z must be positive, but due to
+   rounding error a tiny value may become negative. A tolerance is used to
+   detect this situation. Likewise, in complex arithmetic z'*B*z should be
+   real, and we use the same tolerance to check whether a nonzero imaginary part
+   can be considered negligible.
+
+   This function sets this tolerance, which defaults to 10*eps, where eps is
+   the machine epsilon. The default value should be good for most applications.
+
+   Level: advanced
+
+.seealso: BVSetMatrix()
+@*/
+PetscErrorCode BVSetDefiniteTolerance(BV bv,PetscReal deftol)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(bv,BV_CLASSID,1);
+  PetscValidLogicalCollectiveReal(bv,deftol,2);
+  if (deftol == PETSC_DEFAULT) bv->deftol = 10*PETSC_MACHINE_EPSILON;
+  else {
+    if (deftol<=0.0) SETERRQ(PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of deftol. Must be > 0");
+    bv->deftol = deftol;
+  }
+  PetscFunctionReturn(0);
+}
+
+/*@
+   BVGetDefiniteTolerance - Returns the tolerance for checking a definite
+   inner product.
+
+   Not Collective
+
+   Input Parameter:
+.  bv - the basis vectors
+
+   Output Parameters:
+.  deftol - the tolerance
+
+   Level: advanced
+
+.seealso: BVGetDefiniteTolerance()
+@*/
+PetscErrorCode BVGetDefiniteTolerance(BV bv,PetscReal *deftol)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(bv,BV_CLASSID,1);
+  PetscValidRealPointer(deftol,2);
+  *deftol = bv->deftol;
+  PetscFunctionReturn(0);
+}
+
