@@ -67,7 +67,7 @@ PetscErrorCode BVMult(BV Y,PetscScalar alpha,PetscScalar beta,BV X,Mat Q)
   PetscCheckSameTypeAndComm(Y,1,X,4);
   if (X==Y) SETERRQ(PetscObjectComm((PetscObject)Y),PETSC_ERR_ARG_WRONG,"X and Y arguments must be different");
   if (Q) {
-    PetscCheckTypeName(Q,MATSEQDENSE);
+    PetscCheckTypeNames(Q,MATSEQDENSE,MATSEQDENSECUDA);
     ierr = MatGetSize(Q,&m,&n);CHKERRQ(ierr);
     if (m<X->k) SETERRQ2(PetscObjectComm((PetscObject)Y),PETSC_ERR_ARG_SIZ,"Mat argument has %D rows, should have at least %D",m,X->k);
     if (n<Y->k) SETERRQ2(PetscObjectComm((PetscObject)Y),PETSC_ERR_ARG_SIZ,"Mat argument has %D columns, should have at least %D",n,Y->k);
@@ -220,7 +220,7 @@ PetscErrorCode BVMultColumn(BV X,PetscScalar alpha,PetscScalar beta,PetscInt j,P
 
    Level: intermediate
 
-.seealso: BVMult(), BVMultVec(), BVMultInPlaceTranspose(), BVSetActiveColumns()
+.seealso: BVMult(), BVMultVec(), BVMultInPlaceHermitianTranspose(), BVSetActiveColumns()
 @*/
 PetscErrorCode BVMultInPlace(BV V,Mat Q,PetscInt s,PetscInt e)
 {
@@ -235,7 +235,7 @@ PetscErrorCode BVMultInPlace(BV V,Mat Q,PetscInt s,PetscInt e)
   PetscValidType(V,1);
   BVCheckSizes(V,1);
   PetscValidType(Q,2);
-  PetscCheckTypeName(Q,MATSEQDENSE);
+  PetscCheckTypeNames(Q,MATSEQDENSE,MATSEQDENSECUDA);
 
   if (s<V->l || s>V->m) SETERRQ3(PetscObjectComm((PetscObject)V),PETSC_ERR_ARG_OUTOFRANGE,"Argument s has wrong value %D, should be between %D and %D",s,V->l,V->m);
   if (e<V->l || e>V->m) SETERRQ3(PetscObjectComm((PetscObject)V),PETSC_ERR_ARG_OUTOFRANGE,"Argument e has wrong value %D, should be between %D and %D",e,V->l,V->m);
@@ -252,7 +252,7 @@ PetscErrorCode BVMultInPlace(BV V,Mat Q,PetscInt s,PetscInt e)
 }
 
 /*@
-   BVMultInPlaceTranspose - Update a set of vectors as V(:,s:e-1) = V*Q'(:,s:e-1).
+   BVMultInPlaceHermitianTranspose - Update a set of vectors as V(:,s:e-1) = V*Q'(:,s:e-1).
 
    Logically Collective on V
 
@@ -272,7 +272,7 @@ PetscErrorCode BVMultInPlace(BV V,Mat Q,PetscInt s,PetscInt e)
 
 .seealso: BVMultInPlace()
 @*/
-PetscErrorCode BVMultInPlaceTranspose(BV V,Mat Q,PetscInt s,PetscInt e)
+PetscErrorCode BVMultInPlaceHermitianTranspose(BV V,Mat Q,PetscInt s,PetscInt e)
 {
   PetscErrorCode ierr;
   PetscInt       m,n;
@@ -285,7 +285,7 @@ PetscErrorCode BVMultInPlaceTranspose(BV V,Mat Q,PetscInt s,PetscInt e)
   PetscValidType(V,1);
   BVCheckSizes(V,1);
   PetscValidType(Q,2);
-  PetscCheckTypeName(Q,MATSEQDENSE);
+  PetscCheckTypeNames(Q,MATSEQDENSE,MATSEQDENSECUDA);
 
   if (s<V->l || s>V->m) SETERRQ3(PetscObjectComm((PetscObject)V),PETSC_ERR_ARG_OUTOFRANGE,"Argument s has wrong value %D, should be between %D and %D",s,V->l,V->m);
   if (e<V->l || e>V->m) SETERRQ3(PetscObjectComm((PetscObject)V),PETSC_ERR_ARG_OUTOFRANGE,"Argument e has wrong value %D, should be between %D and %D",e,V->l,V->m);
@@ -429,6 +429,35 @@ PETSC_STATIC_INLINE PetscErrorCode BVSetRandomNormalColumn_Private(BV bv,PetscIn
   PetscFunctionReturn(0);
 }
 
+PETSC_STATIC_INLINE PetscErrorCode BVSetRandomSignColumn_Private(BV bv,PetscInt k)
+{
+  PetscErrorCode ierr;
+  PetscInt       i,low,high;
+  PetscScalar    *px,t;
+  Vec            x;
+
+  PetscFunctionBegin;
+  ierr = BVGetColumn(bv,k,&x);CHKERRQ(ierr);
+  ierr = VecGetOwnershipRange(x,&low,&high);CHKERRQ(ierr);
+  if (bv->rrandom) {  /* generate the same vector irrespective of number of processes */
+    ierr = VecGetArray(x,&px);CHKERRQ(ierr);
+    for (i=0;i<bv->N;i++) {
+      ierr = PetscRandomGetValue(bv->rand,&t);CHKERRQ(ierr);
+      if (i>=low && i<high) px[i-low] = (PetscRealPart(t)<0.5)? -1.0: 1.0;
+    }
+    ierr = VecRestoreArray(x,&px);CHKERRQ(ierr);
+  } else {
+    ierr = VecSetRandom(x,bv->rand);CHKERRQ(ierr);
+    ierr = VecGetArray(x,&px);CHKERRQ(ierr);
+    for (i=low;i<high;i++) {
+      px[i-low] = (PetscRealPart(px[i-low])<0.5)? -1.0: 1.0;
+    }
+    ierr = VecRestoreArray(x,&px);CHKERRQ(ierr);
+  }
+  ierr = BVRestoreColumn(bv,k,&x);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 /*@
    BVSetRandom - Set the columns of a BV to random numbers.
 
@@ -442,7 +471,7 @@ PETSC_STATIC_INLINE PetscErrorCode BVSetRandomNormalColumn_Private(BV bv,PetscIn
 
    Level: advanced
 
-.seealso: BVSetRandomContext(), BVSetRandomColumn(), BVSetRandomNormal(), BVSetRandomCond(), BVSetActiveColumns()
+.seealso: BVSetRandomContext(), BVSetRandomColumn(), BVSetRandomNormal(), BVSetRandomSign(), BVSetRandomCond(), BVSetActiveColumns()
 @*/
 PetscErrorCode BVSetRandom(BV bv)
 {
@@ -502,7 +531,7 @@ PetscErrorCode BVSetRandomColumn(BV bv,PetscInt j)
 
    Logically Collective on bv
 
-   Input Parameters:
+   Input Parameter:
 .  bv - basis vectors
 
    Notes:
@@ -549,6 +578,53 @@ PetscErrorCode BVSetRandomNormal(BV bv)
   PetscFunctionReturn(0);
 }
 
+/*@
+   BVSetRandomSign - Set the entries of a BV to values 1 or -1 with equal
+   probability.
+
+   Logically Collective on bv
+
+   Input Parameter:
+.  bv - basis vectors
+
+   Notes:
+   All active columns (except the leading ones) are modified.
+
+   This function is used, e.g., in contour integral methods when estimating
+   the number of eigenvalues enclosed by the contour via an unbiased
+   estimator of tr(f(A)) [Bai et al., JCAM 1996].
+
+   Developer Notes:
+   The current implementation obtains random numbers and then replaces them
+   with -1 or 1 depending on the value being less than 0.5 or not.
+
+   Level: advanced
+
+.seealso: BVSetRandomContext(), BVSetRandom(), BVSetRandomColumn(), BVSetActiveColumns()
+@*/
+PetscErrorCode BVSetRandomSign(BV bv)
+{
+  PetscErrorCode ierr;
+  PetscScalar    low,high;
+  PetscInt       k;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(bv,BV_CLASSID,1);
+  PetscValidType(bv,1);
+  BVCheckSizes(bv,1);
+
+  ierr = BVGetRandomContext(bv,&bv->rand);CHKERRQ(ierr);
+  ierr = PetscRandomGetInterval(bv->rand,&low,&high);CHKERRQ(ierr);
+  if (PetscRealPart(low)!=0.0 || PetscRealPart(high)!=1.0) SETERRQ(PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_WRONGSTATE,"The PetscRandom object in the BV must have interval [0,1]");
+  ierr = PetscLogEventBegin(BV_SetRandom,bv,0,0,0);CHKERRQ(ierr);
+  for (k=bv->l;k<bv->k;k++) {
+    ierr = BVSetRandomSignColumn_Private(bv,k);CHKERRQ(ierr);
+  }
+  ierr = PetscLogEventEnd(BV_SetRandom,bv,0,0,0);CHKERRQ(ierr);
+  ierr = PetscObjectStateIncrease((PetscObject)bv);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 /*@
    BVSetRandomCond - Set the columns of a BV to random numbers, in a way that
    the generated matrix has a given condition number.
@@ -588,7 +664,7 @@ PetscErrorCode BVSetRandomCond(BV bv,PetscReal condn)
   ierr = DSCreate(PetscObjectComm((PetscObject)bv),&ds);CHKERRQ(ierr);
   ierr = DSSetType(ds,DSHEP);CHKERRQ(ierr);
   ierr = DSAllocate(ds,bv->m);CHKERRQ(ierr);
-  ierr = DSSetDimensions(ds,bv->k,0,bv->l,bv->k);CHKERRQ(ierr);
+  ierr = DSSetDimensions(ds,bv->k,bv->l,bv->k);CHKERRQ(ierr);
   /* [V,S] = eig(B'*B) */
   ierr = DSGetMat(ds,DS_MAT_A,&A);CHKERRQ(ierr);
   ierr = BVDot(bv,bv,A);CHKERRQ(ierr);
@@ -884,8 +960,8 @@ PetscErrorCode BVMatMultTransposeColumn(BV V,Mat A,PetscInt j)
 }
 
 /*@
-   BVMatMultHermitianTransposeColumn - Computes the matrix-vector product for a specified
-   column, storing the result in the next column: v_{j+1}=A*v_j.
+   BVMatMultHermitianTransposeColumn - Computes the conjugate-transpose matrix-vector
+   product for a specified column, storing the result in the next column: v_{j+1}=A^H*v_j.
 
    Neighbor-wise Collective on A
 
