@@ -204,7 +204,7 @@ static PetscErrorCode DSVectors_GHIEP_Eigen_Some(DS ds,PetscInt *idx,PetscReal *
     ep = LAPACKlamch_("S");
     /* Compute eigenvalues of the block */
     PetscStackCallBLAS("LAPACKlag2",LAPACKlag2_(M,&two,b,&two,&ep,&scal1,&scal2,&wr1,&wr2,&wi));
-    if (wi==0.0) SETERRQ(PETSC_COMM_SELF,1,"Real block in DSVectors_GHIEP");
+    if (wi==0.0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"Real block in DSVectors_GHIEP");
     else { /* Complex eigenvalues */
       if (scal1<ep) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_FP,"Nearly infinite eigenvalue");
       wr1 /= scal1;
@@ -285,7 +285,7 @@ PetscErrorCode DSVectors_GHIEP(DS ds,DSMatType mat,PetscInt *k,PetscReal *rnorm)
       }
       break;
     case DS_MAT_U:
-    case DS_MAT_VT:
+    case DS_MAT_V:
       SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"Not implemented yet");
     default:
       SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Invalid mat parameter");
@@ -404,7 +404,7 @@ PetscErrorCode DSSort_GHIEP(DS ds,PetscScalar *wr,PetscScalar *wi,PetscScalar *r
     if (perm[i]<n-1) e[i] = *(ds->rwork+perm[i]);
   }
   if (!ds->compact) { ierr = DSSwitchFormat_GHIEP(ds,PETSC_FALSE);CHKERRQ(ierr); }
-  ierr = DSPermuteColumns_Private(ds,ds->l,n,DS_MAT_Q,perm);CHKERRQ(ierr);
+  ierr = DSPermuteColumns_Private(ds,ds->l,n,n,DS_MAT_Q,perm);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -668,7 +668,7 @@ PetscErrorCode DSSolve_GHIEP_QR_II(DS ds,PetscScalar *wr,PetscScalar *wi)
   /* Check signature */
   for (i=0;i<ds->n;i++) {
     PetscReal de = (ds->compact)?s[i]:PetscRealPart(B[i*ld+i]);
-    if (de != 1.0 && de != -1.0) SETERRQ(PETSC_COMM_SELF,1,"Diagonal elements of the signature matrix must be 1 or -1");
+    if (de != 1.0 && de != -1.0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"Diagonal elements of the signature matrix must be 1 or -1");
   }
 #endif
   ierr = DSAllocateWork_Private(ds,ld*ld,2*ld,ld*2);CHKERRQ(ierr);
@@ -689,7 +689,7 @@ PetscErrorCode DSSolve_GHIEP_QR_II(DS ds,PetscScalar *wr,PetscScalar *wi)
   /* Reduce to pseudotriadiagonal form */
   ierr = DSIntermediate_GHIEP(ds);CHKERRQ(ierr);
 
-  /* Compute Eigenvalues (QR)*/
+  /* Compute Eigenvalues (QR) */
   ierr = DSAllocateMat_Private(ds,DS_MAT_W);CHKERRQ(ierr);
   H = ds->mat[DS_MAT_W];
   if (ds->compact) {
@@ -779,7 +779,7 @@ PetscErrorCode DSSolve_GHIEP_QR(DS ds,PetscScalar *wr,PetscScalar *wi)
   /* Check signature */
   for (i=0;i<ds->n;i++) {
     PetscReal de = (ds->compact)?s[i]:PetscRealPart(B[i*ld+i]);
-    if (de != 1.0 && de != -1.0) SETERRQ(PETSC_COMM_SELF,1,"Diagonal elements of the signature matrix must be 1 or -1");
+    if (de != 1.0 && de != -1.0) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"Diagonal elements of the signature matrix must be 1 or -1");
   }
 #endif
   lw = 14*ld+ld*ld;
@@ -968,9 +968,11 @@ PetscErrorCode DSSynchronize_GHIEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
     if (eigr) {
       ierr = MPI_Pack(eigr+l,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#if !defined(PETSC_USE_COMPLEX)
     if (eigi) {
       ierr = MPI_Pack(eigi+l,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#endif
   }
   ierr = MPI_Bcast(ds->work,size,MPI_BYTE,0,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
   if (rank) {
@@ -987,9 +989,11 @@ PetscErrorCode DSSynchronize_GHIEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
     if (eigr) {
       ierr = MPI_Unpack(ds->work,size,&off,eigr+l,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#if !defined(PETSC_USE_COMPLEX)
     if (eigi) {
       ierr = MPI_Unpack(ds->work,size,&off,eigi+l,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#endif
   }
   PetscFunctionReturn(0);
 }
@@ -1002,6 +1006,43 @@ PetscErrorCode DSHermitian_GHIEP(DS ds,DSMatType m,PetscBool *flg)
   PetscFunctionReturn(0);
 }
 
+/*MC
+   DSGHIEP - Dense Generalized Hermitian Indefinite Eigenvalue Problem.
+
+   Level: beginner
+
+   Notes:
+   The problem is expressed as A*X = B*X*Lambda, where both A and B are
+   real symmetric (or complex Hermitian) and possibly indefinite. Lambda
+   is a diagonal matrix whose diagonal elements are the arguments of DSSolve().
+   After solve, A is overwritten with Lambda. Note that in the case of real
+   scalars, A is overwritten with a real representation of Lambda, i.e.,
+   complex conjugate eigenvalue pairs are stored as a 2x2 block in the
+   quasi-diagonal matrix.
+
+   In the intermediate state A is reduced to tridiagonal form and B is
+   transformed into a signature matrix. In compact storage format, these
+   matrices are stored in T and D, respectively.
+
+   Used DS matrices:
++  DS_MAT_A - first problem matrix
+.  DS_MAT_B - second problem matrix
+.  DS_MAT_T - symmetric tridiagonal matrix of the reduced pencil
+.  DS_MAT_D - diagonal matrix (signature) of the reduced pencil
+-  DS_MAT_Q - pseudo-orthogonal transformation that reduces (A,B) to
+   tridiagonal-diagonal form (intermediate step) or a real basis of eigenvectors
+
+   Implemented methods:
++  0 - QR iteration plus inverse iteration for the eigenvectors
+.  1 - HZ iteration
+-  2 - QR iteration plus pseudo-orthogonalization for the eigenvectors
+
+   References:
+.  1. - C. Campos and J. E. Roman, "Restarted Q-Arnoldi-type methods exploiting
+   symmetry in quadratic eigenvalue problems", BIT Numer. Math. 56(4):1213-1236, 2016.
+
+.seealso: DSCreate(), DSSetType(), DSType
+M*/
 SLEPC_EXTERN PetscErrorCode DSCreate_GHIEP(DS ds)
 {
   PetscFunctionBegin;
