@@ -27,7 +27,6 @@
   2) Moreover, P and Q are assumed to be the identity in DS_STATE_INTERMEDIATE.
 */
 
-
 static PetscErrorCode CleanDenseSchur(PetscInt n,PetscInt k,PetscScalar *S,PetscInt ldS,PetscScalar *T,PetscInt ldT,PetscScalar *X,PetscInt ldX,PetscScalar *Y,PetscInt ldY);
 
 PetscErrorCode DSAllocate_GNHEP(DS ds,PetscInt ld)
@@ -550,9 +549,11 @@ PetscErrorCode DSSynchronize_GNHEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
     if (eigr) {
       ierr = MPI_Pack(eigr+l,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#if !defined(PETSC_USE_COMPLEX)
     if (eigi) {
       ierr = MPI_Pack(eigi+l,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#endif
   }
   ierr = MPI_Bcast(ds->work,size,MPI_BYTE,0,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
   if (rank) {
@@ -565,9 +566,11 @@ PetscErrorCode DSSynchronize_GNHEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
     if (eigr) {
       ierr = MPI_Unpack(ds->work,size,&off,eigr+l,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#if !defined(PETSC_USE_COMPLEX)
     if (eigi) {
       ierr = MPI_Unpack(ds->work,size,&off,eigi+l,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#endif
   }
   PetscFunctionReturn(0);
 }
@@ -606,6 +609,31 @@ PetscErrorCode DSTruncate_GNHEP(DS ds,PetscInt n,PetscBool trim)
   PetscFunctionReturn(0);
 }
 
+/*MC
+   DSGNHEP - Dense Generalized Non-Hermitian Eigenvalue Problem.
+
+   Level: beginner
+
+   Notes:
+   The problem is expressed as A*X = B*X*Lambda, where (A,B) is the input
+   matrix pencil. Lambda is a diagonal matrix whose diagonal elements are the
+   arguments of DSSolve(). After solve, (A,B) is overwritten with the
+   generalized (real) Schur form (S,T) = (Z'*A*Q,Z'*B*Q), with the first
+   matrix being upper quasi-triangular and the second one triangular.
+
+   Used DS matrices:
++  DS_MAT_A - first problem matrix
+.  DS_MAT_B - second problem matrix
+.  DS_MAT_Q - first orthogonal/unitary transformation that reduces to
+   generalized (real) Schur form
+-  DS_MAT_Z - second orthogonal/unitary transformation that reduces to
+   generalized (real) Schur form
+
+   Implemented methods:
+.  0 - QZ iteration (_gges)
+
+.seealso: DSCreate(), DSSetType(), DSType
+M*/
 SLEPC_EXTERN PetscErrorCode DSCreate_GNHEP(DS ds)
 {
   PetscFunctionBegin;
