@@ -168,7 +168,7 @@ PetscErrorCode DSVectors_HEP(DS ds,DSMatType mat,PetscInt *j,PetscReal *rnorm)
       if (rnorm && j) *rnorm = PetscAbsScalar(Q[ds->n-1+(*j)*ld]);
       break;
     case DS_MAT_U:
-    case DS_MAT_VT:
+    case DS_MAT_V:
       SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"Not implemented yet");
     default:
       SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Invalid mat parameter");
@@ -339,7 +339,7 @@ PetscErrorCode DSSort_HEP(DS ds,PetscScalar *wr,PetscScalar *wi,PetscScalar *rr,
     ierr = DSSortEigenvalues_Private(ds,rr,ri,perm,PETSC_FALSE);CHKERRQ(ierr);
   }
   for (i=l;i<n;i++) wr[i] = d[perm[i]];
-  ierr = DSPermuteColumns_Private(ds,l,n,DS_MAT_Q,perm);CHKERRQ(ierr);
+  ierr = DSPermuteColumns_Private(ds,l,n,n,DS_MAT_Q,perm);CHKERRQ(ierr);
   for (i=l;i<n;i++) d[i] = PetscRealPart(wr[i]);
   if (!ds->compact) {
     for (i=l;i<n;i++) A[i+i*ld] = wr[i];
@@ -803,6 +803,34 @@ PetscErrorCode DSHermitian_HEP(DS ds,DSMatType m,PetscBool *flg)
   PetscFunctionReturn(0);
 }
 
+/*MC
+   DSHEP - Dense Hermitian Eigenvalue Problem.
+
+   Level: beginner
+
+   Notes:
+   The problem is expressed as A*X = X*Lambda, where A is real symmetric
+   (or complex Hermitian). Lambda is a diagonal matrix whose diagonal
+   elements are the arguments of DSSolve(). After solve, A is overwritten
+   with Lambda.
+
+   In the intermediate state A is reduced to tridiagonal form. In compact
+   storage format, the symmetric tridiagonal matrix is stored in T.
+
+   Used DS matrices:
++  DS_MAT_A - problem matrix
+.  DS_MAT_T - symmetric tridiagonal matrix
+-  DS_MAT_Q - orthogonal/unitary transformation that reduces to tridiagonal form
+   (intermediate step) or matrix of orthogonal eigenvectors, which is equal to X
+
+   Implemented methods:
++  0 - Implicit QR (_steqr)
+.  1 - Multiple Relatively Robust Representations (_stevr)
+.  2 - Divide and Conquer (_stedc)
+-  3 - Block Divide and Conquer (real scalars only)
+
+.seealso: DSCreate(), DSSetType(), DSType
+M*/
 SLEPC_EXTERN PetscErrorCode DSCreate_HEP(DS ds)
 {
   PetscFunctionBegin;
