@@ -251,7 +251,7 @@ PetscErrorCode DSVectors_NHEP(DS ds,DSMatType mat,PetscInt *j,PetscReal *rnorm)
       }
       break;
     case DS_MAT_U:
-    case DS_MAT_VT:
+    case DS_MAT_V:
       SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"Not implemented yet");
     default:
       SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Invalid mat parameter");
@@ -383,9 +383,11 @@ PetscErrorCode DSSynchronize_NHEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
     if (eigr) {
       ierr = MPI_Pack(eigr+l,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#if !defined(PETSC_USE_COMPLEX)
     if (eigi) {
       ierr = MPI_Pack(eigi+l,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#endif
   }
   ierr = MPI_Bcast(ds->work,size,MPI_BYTE,0,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
   if (rank) {
@@ -396,9 +398,11 @@ PetscErrorCode DSSynchronize_NHEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
     if (eigr) {
       ierr = MPI_Unpack(ds->work,size,&off,eigr+l,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#if !defined(PETSC_USE_COMPLEX)
     if (eigi) {
       ierr = MPI_Unpack(ds->work,size,&off,eigi+l,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#endif
   }
   PetscFunctionReturn(0);
 }
@@ -500,7 +504,7 @@ PetscErrorCode DSTranslateHarmonic_NHEP(DS ds,PetscScalar tau,PetscReal beta,Pet
     B = ds->mat[DS_MAT_W];
     ierr = PetscArraycpy(B,A,ld*ld);CHKERRQ(ierr);
 
-    /* Vector g initialy stores b = beta*e_n^T */
+    /* Vector g initially stores b = beta*e_n^T */
     ierr = PetscArrayzero(g,n);CHKERRQ(ierr);
     g[n-1] = beta;
 
@@ -544,6 +548,32 @@ PetscErrorCode DSTranslateHarmonic_NHEP(DS ds,PetscScalar tau,PetscReal beta,Pet
   PetscFunctionReturn(0);
 }
 
+/*MC
+   DSNHEP - Dense Non-Hermitian Eigenvalue Problem.
+
+   Level: beginner
+
+   Notes:
+   The problem is expressed as A*X = X*Lambda, where A is the input matrix.
+   Lambda is a diagonal matrix whose diagonal elements are the arguments of
+   DSSolve(). After solve, A is overwritten with the upper quasi-triangular
+   matrix T of the (real) Schur form, A*Q = Q*T.
+
+   In the intermediate state A is reduced to upper Hessenberg form.
+
+   Computation of left eigenvectors is supported, but two-sided Krylov solvers
+   usually rely on the related DSNHEPTS.
+
+   Used DS matrices:
++  DS_MAT_A - problem matrix
+-  DS_MAT_Q - orthogonal/unitary transformation that reduces to Hessenberg form
+   (intermediate step) or matrix of orthogonal Schur vectors
+
+   Implemented methods:
+.  0 - Implicit QR (_hseqr)
+
+.seealso: DSCreate(), DSSetType(), DSType
+M*/
 SLEPC_EXTERN PetscErrorCode DSCreate_NHEP(DS ds)
 {
   PetscFunctionBegin;
