@@ -7,16 +7,6 @@
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
-/*
-   DSNHEPTS: a special variant of NHEP to be used in two-sided Krylov solvers
-
-   DS_MAT_A - upper Hessenberg matrix obtained from Arnoldi
-   DS_MAT_B - upper Hessenberg matrix obtained from Arnoldi on the transpose
-   DS_MAT_Q - orthogonal matrix of (right) Schur vectors
-   DS_MAT_Z - orthogonal matrix of left Schur vectors (computed as Schur vectors of B)
-   DS_MAT_X - right eigenvectors
-   DS_MAT_Y - left eigenvectors (computed as right eigenvectors of B)
-*/
 
 #include <slepc/private/dsimpl.h>
 #include <slepcblaslapack.h>
@@ -215,7 +205,7 @@ PetscErrorCode DSVectors_NHEPTS(DS ds,DSMatType mat,PetscInt *j,PetscReal *rnorm
       }
       break;
     case DS_MAT_U:
-    case DS_MAT_VT:
+    case DS_MAT_V:
       SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"Not implemented yet");
     default:
       SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Invalid mat parameter");
@@ -345,9 +335,11 @@ PetscErrorCode DSSynchronize_NHEPTS(DS ds,PetscScalar eigr[],PetscScalar eigi[])
     if (eigr) {
       ierr = MPI_Pack(eigr+l,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#if !defined(PETSC_USE_COMPLEX)
     if (eigi) {
       ierr = MPI_Pack(eigi+l,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#endif
     if (ctx->wr) {
       ierr = MPI_Pack(ctx->wr+l,n,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
@@ -366,9 +358,11 @@ PetscErrorCode DSSynchronize_NHEPTS(DS ds,PetscScalar eigr[],PetscScalar eigi[])
     if (eigr) {
       ierr = MPI_Unpack(ds->work,size,&off,eigr+l,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#if !defined(PETSC_USE_COMPLEX)
     if (eigi) {
       ierr = MPI_Unpack(ds->work,size,&off,eigi+l,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#endif
     if (ctx->wr) {
       ierr = MPI_Unpack(ds->work,size,&off,ctx->wr+l,n,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
@@ -438,6 +432,47 @@ PetscErrorCode DSDestroy_NHEPTS(DS ds)
   PetscFunctionReturn(0);
 }
 
+PetscErrorCode DSMatGetSize_NHEPTS(DS ds,DSMatType t,PetscInt *rows,PetscInt *cols)
+{
+  PetscFunctionBegin;
+  *rows = ((t==DS_MAT_A || t==DS_MAT_B) && ds->extrarow)? ds->n+1: ds->n;
+  *cols = ds->n;
+  PetscFunctionReturn(0);
+}
+
+/*MC
+   DSNHEPTS - Dense Non-Hermitian Eigenvalue Problem (special variant intended
+   for two-sided Krylov solvers).
+
+   Level: beginner
+
+   Notes:
+   Two related problems are solved, A*X = X*Lambda and B*Y = Y*Lambda', where A and
+   B are supposed to come from the Arnoldi factorizations of a certain matrix and its
+   (conjugate) transpose, respectively. Hence, in exact arithmetic the columns of Y
+   are equal to the left eigenvectors of A. Lambda is a diagonal matrix whose diagonal
+   elements are the arguments of DSSolve(). After solve, A is overwritten with the
+   upper quasi-triangular matrix T of the (real) Schur form, A*Q = Q*T, and similarly
+   another (real) Schur relation is computed, B*Z = Z*S, overwriting B.
+
+   In the intermediate state A and B are reduced to upper Hessenberg form.
+
+   When left eigenvectors DS_MAT_Y are requested, right eigenvectors of B are returned,
+   while DS_MAT_X contains right eigenvectors of A.
+
+   Used DS matrices:
++  DS_MAT_A - first problem matrix obtained from Arnoldi
+.  DS_MAT_B - second problem matrix obtained from Arnoldi on the transpose
+.  DS_MAT_Q - orthogonal/unitary transformation that reduces A to Hessenberg form
+   (intermediate step) or matrix of orthogonal Schur vectors of A
+-  DS_MAT_Z - orthogonal/unitary transformation that reduces B to Hessenberg form
+   (intermediate step) or matrix of orthogonal Schur vectors of B
+
+   Implemented methods:
+.  0 - Implicit QR (_hseqr)
+
+.seealso: DSCreate(), DSSetType(), DSType
+M*/
 SLEPC_EXTERN PetscErrorCode DSCreate_NHEPTS(DS ds)
 {
   DS_NHEPTS      *ctx;
@@ -457,6 +492,7 @@ SLEPC_EXTERN PetscErrorCode DSCreate_NHEPTS(DS ds)
   ds->ops->truncate        = DSTruncate_NHEPTS;
   ds->ops->update          = DSUpdateExtraRow_NHEPTS;
   ds->ops->destroy         = DSDestroy_NHEPTS;
+  ds->ops->matgetsize      = DSMatGetSize_NHEPTS;
   PetscFunctionReturn(0);
 }
 
