@@ -44,8 +44,11 @@ PetscErrorCode DSView_PEP(DS ds,PetscViewer viewer)
 
   PetscFunctionBegin;
   ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
-  ierr = PetscViewerASCIIPrintf(viewer,"polynomial degree: %D\n",ctx->d);CHKERRQ(ierr);
-  if (format == PETSC_VIEWER_ASCII_INFO || format == PETSC_VIEWER_ASCII_INFO_DETAIL) PetscFunctionReturn(0);
+  if (format == PETSC_VIEWER_ASCII_INFO) PetscFunctionReturn(0);
+  if (format == PETSC_VIEWER_ASCII_INFO_DETAIL) {
+    ierr = PetscViewerASCIIPrintf(viewer,"polynomial degree: %D\n",ctx->d);CHKERRQ(ierr);
+    PetscFunctionReturn(0);
+  }
   for (i=0;i<=ctx->d;i++) {
     ierr = DSViewMat(ds,viewer,DSMatExtra[i]);CHKERRQ(ierr);
   }
@@ -72,13 +75,13 @@ PetscErrorCode DSSort_PEP(DS ds,PetscScalar *wr,PetscScalar *wi,PetscScalar *rr,
 {
   PetscErrorCode ierr;
   DS_PEP         *ctx = (DS_PEP*)ds->data;
-  PetscInt       n,i,j,k,p,*perm,told,ld;
-  PetscScalar    *A,*X,*Y,rtmp,rtmp2;
+  PetscInt       n,i,*perm,told;
+  PetscScalar    *A;
 
   PetscFunctionBegin;
   if (!ds->sc) PetscFunctionReturn(0);
   n = ds->n*ctx->d;
-  A  = ds->mat[DS_MAT_A];
+  A = ds->mat[DS_MAT_A];
   perm = ds->perm;
   for (i=0;i<n;i++) perm[i] = i;
   told = ds->t;
@@ -93,23 +96,7 @@ PetscErrorCode DSSort_PEP(DS ds,PetscScalar *wr,PetscScalar *wi,PetscScalar *rr,
   for (i=0;i<n;i++) wr[i] = A[i];
   for (i=0;i<n;i++) A[i]  = wi[perm[i]];
   for (i=0;i<n;i++) wi[i] = A[i];
-  /* cannot use DSPermuteColumns_Private() since matrix is not square */
-  ld = ds->ld;
-  X  = ds->mat[DS_MAT_X];
-  Y  = ds->mat[DS_MAT_Y];
-  for (i=0;i<n;i++) {
-    p = perm[i];
-    if (p != i) {
-      j = i + 1;
-      while (perm[j] != i) j++;
-      perm[j] = p; perm[i] = i;
-      /* swap columns i and j */
-      for (k=0;k<ds->n;k++) {
-        rtmp  = X[k+p*ld]; X[k+p*ld] = X[k+i*ld]; X[k+i*ld] = rtmp;
-        rtmp2 = Y[k+p*ld]; Y[k+p*ld] = Y[k+i*ld]; Y[k+i*ld] = rtmp2;
-      }
-    }
-  }
+  ierr = DSPermuteColumnsTwo_Private(ds,0,n,ds->n,DS_MAT_X,DS_MAT_Y,perm);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -280,9 +267,11 @@ PetscErrorCode DSSynchronize_PEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
     if (eigr) {
       ierr = MPI_Pack(eigr,dn,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#if !defined(PETSC_USE_COMPLEX)
     if (eigi) {
       ierr = MPI_Pack(eigi,dn,MPIU_SCALAR,ds->work,size,&off,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#endif
   }
   ierr = MPI_Bcast(ds->work,size,MPI_BYTE,0,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
   if (rank) {
@@ -293,9 +282,11 @@ PetscErrorCode DSSynchronize_PEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
     if (eigr) {
       ierr = MPI_Unpack(ds->work,size,&off,eigr,dn,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#if !defined(PETSC_USE_COMPLEX)
     if (eigi) {
       ierr = MPI_Unpack(ds->work,size,&off,eigi,dn,MPIU_SCALAR,PetscObjectComm((PetscObject)ds));CHKERRMPI(ierr);
     }
+#endif
   }
   PetscFunctionReturn(0);
 }
@@ -499,6 +490,37 @@ PetscErrorCode DSMatGetSize_PEP(DS ds,DSMatType t,PetscInt *rows,PetscInt *cols)
   PetscFunctionReturn(0);
 }
 
+/*MC
+   DSPEP - Dense Polynomial Eigenvalue Problem.
+
+   Level: beginner
+
+   Notes:
+   The problem is expressed as P(lambda)*x = 0, where P(.) is a matrix
+   polynomial of degree d. The eigenvalues lambda are the arguments
+   returned by DSSolve().
+
+   The degree of the polynomial, d, can be set with DSPEPSetDegree(), with
+   the first d+1 extra matrices of the DS defining the matrix polynomial. By
+   default, the polynomial is expressed in the monomial basis, but a
+   different basis can be used by setting the corresponding coefficients
+   via DSPEPSetCoefficients().
+
+   The problem is solved via linearization, by building a pencil (A,B) of
+   size p*n and solving the corresponding GNHEP.
+
+   Used DS matrices:
++  DS_MAT_Ex - coefficients of the matrix polynomial
+.  DS_MAT_A  - (workspace) first matrix of the linearization
+.  DS_MAT_B  - (workspace) second matrix of the linearization
+.  DS_MAT_W  - (workspace) right eigenvectors of the linearization
+-  DS_MAT_U  - (workspace) left eigenvectors of the linearization
+
+   Implemented methods:
+.  0 - QZ iteration on the linearization (_ggev)
+
+.seealso: DSCreate(), DSSetType(), DSType, DSPEPSetDegree(), DSPEPSetCoefficients()
+M*/
 SLEPC_EXTERN PetscErrorCode DSCreate_PEP(DS ds)
 {
   DS_PEP         *ctx;
