@@ -113,48 +113,41 @@ PetscErrorCode DSGetState(DS ds,DSStateType *state)
    Input Parameters:
 +  ds - the direct solver context
 .  n  - the new size
-.  m  - the new column size (only for DSSVD)
 .  l  - number of locked (inactive) leading columns
 -  k  - intermediate dimension (e.g., position of arrow)
 
    Notes:
    The internal arrays are not reallocated.
 
-   The value m is not used except in the case of DSSVD, pass 0 otherwise.
+   Some DS types have additional dimensions, e.g. the number of columns
+   in DSSVD. For these, you should call a specific interface function.
 
    Level: intermediate
 
-.seealso: DSGetDimensions(), DSAllocate()
+.seealso: DSGetDimensions(), DSAllocate(), DSSVDSetDimensions()
 @*/
-PetscErrorCode DSSetDimensions(DS ds,PetscInt n,PetscInt m,PetscInt l,PetscInt k)
+PetscErrorCode DSSetDimensions(DS ds,PetscInt n,PetscInt l,PetscInt k)
 {
   PetscErrorCode ierr;
-  PetscInt       on,om,ol,ok;
+  PetscInt       on,ol,ok;
+  PetscBool      issvd;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   DSCheckAlloc(ds,1);
   PetscValidLogicalCollectiveInt(ds,n,2);
-  PetscValidLogicalCollectiveInt(ds,m,3);
-  PetscValidLogicalCollectiveInt(ds,l,4);
-  PetscValidLogicalCollectiveInt(ds,k,5);
-  on = ds->n; om = ds->m; ol = ds->l; ok = ds->k;
+  PetscValidLogicalCollectiveInt(ds,l,3);
+  PetscValidLogicalCollectiveInt(ds,k,4);
+  on = ds->n; ol = ds->l; ok = ds->k;
   if (n==PETSC_DECIDE || n==PETSC_DEFAULT) {
     ds->n = ds->ld;
   } else {
     if (n<0 || n>ds->ld) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of n. Must be between 0 and ld");
-    if (ds->extrarow && n+1>ds->ld) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"A value of n equal to ld leaves no room for extra row");
+    ierr = PetscObjectTypeCompareAny((PetscObject)ds,&issvd,DSSVD,DSGSVD,"");CHKERRQ(ierr);  /* SVD and GSVD have extra column instead of extra row */
+    if (ds->extrarow && n+1>ds->ld && !issvd) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"A value of n equal to ld leaves no room for extra row");
     ds->n = n;
   }
   ds->t = ds->n;   /* truncated length equal to the new dimension */
-  if (m) {
-    if (m==PETSC_DECIDE || m==PETSC_DEFAULT) {
-      ds->m = ds->ld;
-    } else {
-      if (m<0 || m>ds->ld) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of m. Must be between 0 and ld");
-      ds->m = m;
-    }
-  }
   if (l==PETSC_DECIDE || l==PETSC_DEFAULT) {
     ds->l = 0;
   } else {
@@ -167,8 +160,8 @@ PetscErrorCode DSSetDimensions(DS ds,PetscInt n,PetscInt m,PetscInt l,PetscInt k
     if (k<0 || k>ds->n) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of k. Must be between 0 and n");
     ds->k = k;
   }
-  if (on!=ds->n || om!=ds->m || ol!=ds->l || ok!=ds->k) {
-    ierr = PetscInfo4(ds,"New dimensions are: n=%D, m=%D, l=%D, k=%D\n",ds->n,ds->m,ds->l,ds->k);CHKERRQ(ierr);
+  if (on!=ds->n || ol!=ds->l || ok!=ds->k) {
+    ierr = PetscInfo3(ds,"New dimensions are: n=%D, l=%D, k=%D\n",ds->n,ds->l,ds->k);CHKERRQ(ierr);
   }
   PetscFunctionReturn(0);
 }
@@ -181,9 +174,8 @@ PetscErrorCode DSSetDimensions(DS ds,PetscInt n,PetscInt m,PetscInt l,PetscInt k
    Input Parameter:
 .  ds - the direct solver context
 
-   Output Parameter:
+   Output Parameters:
 +  n  - the current size
-.  m  - the current column size (only for DSSVD)
 .  l  - number of locked (inactive) leading columns
 .  k  - intermediate dimension (e.g., position of arrow)
 -  t  - truncated length
@@ -192,17 +184,19 @@ PetscErrorCode DSSetDimensions(DS ds,PetscInt n,PetscInt m,PetscInt l,PetscInt k
    The t parameter makes sense only if DSTruncate() has been called.
    Otherwise its value equals n.
 
+   Some DS types have additional dimensions, e.g. the number of columns
+   in DSSVD. For these, you should call a specific interface function.
+
    Level: intermediate
 
-.seealso: DSSetDimensions(), DSTruncate()
+.seealso: DSSetDimensions(), DSTruncate(), DSSVDGetDimensions()
 @*/
-PetscErrorCode DSGetDimensions(DS ds,PetscInt *n,PetscInt *m,PetscInt *l,PetscInt *k,PetscInt *t)
+PetscErrorCode DSGetDimensions(DS ds,PetscInt *n,PetscInt *l,PetscInt *k,PetscInt *t)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   DSCheckAlloc(ds,1);
   if (n) *n = ds->n;
-  if (m) *m = ds->m;
   if (l) *l = ds->l;
   if (k) *k = ds->k;
   if (t) *t = ds->t;
@@ -542,7 +536,7 @@ PetscErrorCode DSGetArray(DS ds,DSMatType m,PetscScalar *a[])
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   DSCheckAlloc(ds,1);
   DSCheckValidMat(ds,m,2);
-  PetscValidPointer(a,2);
+  PetscValidPointer(a,3);
   *a = ds->mat[m];
   CHKMEMQ;
   PetscFunctionReturn(0);
@@ -570,7 +564,7 @@ PetscErrorCode DSRestoreArray(DS ds,DSMatType m,PetscScalar *a[])
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   DSCheckAlloc(ds,1);
   DSCheckValidMat(ds,m,2);
-  PetscValidPointer(a,2);
+  PetscValidPointer(a,3);
   CHKMEMQ;
   *a = 0;
   ierr = PetscObjectStateIncrease((PetscObject)ds);CHKERRQ(ierr);
@@ -601,7 +595,7 @@ PetscErrorCode DSGetArrayReal(DS ds,DSMatType m,PetscReal *a[])
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   DSCheckAlloc(ds,1);
   DSCheckValidMatReal(ds,m,2);
-  PetscValidPointer(a,2);
+  PetscValidPointer(a,3);
   *a = ds->rmat[m];
   CHKMEMQ;
   PetscFunctionReturn(0);
@@ -629,7 +623,7 @@ PetscErrorCode DSRestoreArrayReal(DS ds,DSMatType m,PetscReal *a[])
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   DSCheckAlloc(ds,1);
   DSCheckValidMatReal(ds,m,2);
-  PetscValidPointer(a,2);
+  PetscValidPointer(a,3);
   CHKMEMQ;
   *a = 0;
   ierr = PetscObjectStateIncrease((PetscObject)ds);CHKERRQ(ierr);
@@ -852,7 +846,7 @@ PetscErrorCode DSSynchronize(DS ds,PetscScalar eigr[],PetscScalar eigi[])
 .  rnorm - (optional) computed residual norm
 
    Notes:
-   Allowed values for mat are DS_MAT_X, DS_MAT_Y, DS_MAT_U and DS_MAT_VT, to
+   Allowed values for mat are DS_MAT_X, DS_MAT_Y, DS_MAT_U and DS_MAT_V, to
    compute right or left eigenvectors, or left or right singular vectors,
    respectively.
 
