@@ -18,16 +18,21 @@ PetscErrorCode DSAllocateMatrix_Private(DS ds,DSMatType m,PetscBool isreal)
 {
   size_t         sz;
   PetscInt       n,d,nelem;
-  PetscBool      ispep;
+  PetscBool      ispep,isnep;
   PetscErrorCode ierr;
 
   PetscFunctionBegin;
   ierr = PetscObjectTypeCompare((PetscObject)ds,DSPEP,&ispep);CHKERRQ(ierr);
+  ierr = PetscObjectTypeCompare((PetscObject)ds,DSNEP,&isnep);CHKERRQ(ierr);
   if (ispep) {
     ierr = DSPEPGetDegree(ds,&d);CHKERRQ(ierr);
   }
-  if (ispep && (m==DS_MAT_A || m==DS_MAT_B || m==DS_MAT_W || m==DS_MAT_U || m==DS_MAT_X || m==DS_MAT_Y)) n = d*ds->ld;
+  if (isnep) {
+    ierr = DSNEPGetMinimality(ds,&d);CHKERRQ(ierr);
+  }
+  if ((ispep || isnep) && (m==DS_MAT_A || m==DS_MAT_B || m==DS_MAT_W || m==DS_MAT_U || m==DS_MAT_X || m==DS_MAT_Y)) n = d*ds->ld;
   else n = ds->ld;
+
   switch (m) {
     case DS_MAT_T:
       nelem = 3*ds->ld;
@@ -269,7 +274,10 @@ PetscErrorCode DSCopyMatrix_Private(DS ds,DSMatType dst,DSMatType src)
   PetscFunctionReturn(0);
 }
 
-PetscErrorCode DSPermuteColumns_Private(DS ds,PetscInt l,PetscInt n,DSMatType mat,PetscInt *perm)
+/*
+  Permute comumns [istart..iend-1] of [mat] according to perm. Columns have length n
+ */
+PetscErrorCode DSPermuteColumns_Private(DS ds,PetscInt istart,PetscInt iend,PetscInt n,DSMatType mat,PetscInt *perm)
 {
   PetscInt    i,j,k,p,ld;
   PetscScalar *Q,rtmp;
@@ -277,7 +285,7 @@ PetscErrorCode DSPermuteColumns_Private(DS ds,PetscInt l,PetscInt n,DSMatType ma
   PetscFunctionBegin;
   ld = ds->ld;
   Q  = ds->mat[mat];
-  for (i=l;i<n;i++) {
+  for (i=istart;i<iend;i++) {
     p = perm[i];
     if (p != i) {
       j = i + 1;
@@ -292,16 +300,46 @@ PetscErrorCode DSPermuteColumns_Private(DS ds,PetscInt l,PetscInt n,DSMatType ma
   PetscFunctionReturn(0);
 }
 
-PetscErrorCode DSPermuteRows_Private(DS ds,PetscInt l,PetscInt n,DSMatType mat,PetscInt *perm)
+/*
+  The same as DSPermuteColumns_Private but for two matrices [mat1] and [mat2]
+ */
+PetscErrorCode DSPermuteColumnsTwo_Private(DS ds,PetscInt istart,PetscInt iend,PetscInt n,DSMatType mat1,DSMatType mat2,PetscInt *perm)
 {
-  PetscInt    i,j,m=ds->m,k,p,ld;
+  PetscInt    i,j,k,p,ld;
+  PetscScalar *Q,*Z,rtmp,rtmp2;
+
+  PetscFunctionBegin;
+  ld = ds->ld;
+  Q  = ds->mat[mat1];
+  Z  = ds->mat[mat2];
+  for (i=istart;i<iend;i++) {
+    p = perm[i];
+    if (p != i) {
+      j = i + 1;
+      while (perm[j] != i) j++;
+      perm[j] = p; perm[i] = i;
+      /* swap columns i and j */
+      for (k=0;k<n;k++) {
+        rtmp  = Q[k+p*ld]; Q[k+p*ld] = Q[k+i*ld]; Q[k+i*ld] = rtmp;
+        rtmp2 = Z[k+p*ld]; Z[k+p*ld] = Z[k+i*ld]; Z[k+i*ld] = rtmp2;
+      }
+    }
+  }
+  PetscFunctionReturn(0);
+}
+
+/*
+  Permute rows [istart..iend-1] of [mat] according to perm. Rows have length m
+ */
+PetscErrorCode DSPermuteRows_Private(DS ds,PetscInt istart,PetscInt iend,PetscInt m,DSMatType mat,PetscInt *perm)
+{
+  PetscInt    i,j,k,p,ld;
   PetscScalar *Q,rtmp;
 
   PetscFunctionBegin;
-  if (!m) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_WRONG,"m was not set");
   ld = ds->ld;
   Q  = ds->mat[mat];
-  for (i=l;i<n;i++) {
+  for (i=istart;i<iend;i++) {
     p = perm[i];
     if (p != i) {
       j = i + 1;
@@ -316,17 +354,20 @@ PetscErrorCode DSPermuteRows_Private(DS ds,PetscInt l,PetscInt n,DSMatType mat,P
   PetscFunctionReturn(0);
 }
 
-PetscErrorCode DSPermuteBoth_Private(DS ds,PetscInt l,PetscInt n,DSMatType mat1,DSMatType mat2,PetscInt *perm)
+/*
+  Permute columns [istart..iend-1] of [mat1] and [mat2] according to perm.
+  Columns of [mat1] have length n, columns of [mat2] have length m
+ */
+PetscErrorCode DSPermuteBoth_Private(DS ds,PetscInt istart,PetscInt iend,PetscInt n,PetscInt m,DSMatType mat1,DSMatType mat2,PetscInt *perm)
 {
-  PetscInt    i,j,m=ds->m,k,p,ld;
-  PetscScalar *U,*VT,rtmp;
+  PetscInt    i,j,k,p,ld;
+  PetscScalar *U,*V,rtmp;
 
   PetscFunctionBegin;
-  if (!m) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_WRONG,"m was not set");
   ld = ds->ld;
   U  = ds->mat[mat1];
-  VT = ds->mat[mat2];
-  for (i=l;i<n;i++) {
+  V  = ds->mat[mat2];
+  for (i=istart;i<iend;i++) {
     p = perm[i];
     if (p != i) {
       j = i + 1;
@@ -336,9 +377,9 @@ PetscErrorCode DSPermuteBoth_Private(DS ds,PetscInt l,PetscInt n,DSMatType mat1,
       for (k=0;k<n;k++) {
         rtmp = U[k+p*ld]; U[k+p*ld] = U[k+i*ld]; U[k+i*ld] = rtmp;
       }
-      /* swap rows i and j of VT */
+      /* swap columns i and j of V */
       for (k=0;k<m;k++) {
-        rtmp = VT[p+k*ld]; VT[p+k*ld] = VT[i+k*ld]; VT[i+k*ld] = rtmp;
+        rtmp = V[k+p*ld]; V[k+p*ld] = V[k+i*ld]; V[k+i*ld] = rtmp;
       }
     }
   }
@@ -368,7 +409,7 @@ PetscErrorCode DSSetIdentity(DS ds,DSMatType mat)
   PetscValidLogicalCollectiveEnum(ds,mat,2);
   DSCheckValidMat(ds,mat,2);
 
-  ierr = DSGetDimensions(ds,&n,NULL,&l,NULL,NULL);CHKERRQ(ierr);
+  ierr = DSGetDimensions(ds,&n,&l,NULL,NULL);CHKERRQ(ierr);
   ierr = DSGetLeadingDimension(ds,&ld);CHKERRQ(ierr);
   ierr = PetscLogEventBegin(DS_Other,ds,0,0,0);CHKERRQ(ierr);
   ierr = DSGetArray(ds,mat,&x);CHKERRQ(ierr);
@@ -410,7 +451,7 @@ PetscErrorCode DSOrthogonalize(DS ds,DSMatType mat,PetscInt cols,PetscInt *lindc
   DSCheckValidMat(ds,mat,2);
   PetscValidLogicalCollectiveInt(ds,cols,3);
 
-  ierr = DSGetDimensions(ds,&n,NULL,&l,NULL,NULL);CHKERRQ(ierr);
+  ierr = DSGetDimensions(ds,&n,&l,NULL,NULL);CHKERRQ(ierr);
   ierr = DSGetLeadingDimension(ds,&ld);CHKERRQ(ierr);
   n = n - l;
   if (cols > n) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_WRONG,"Invalid number of columns");
@@ -471,7 +512,7 @@ static PetscErrorCode SlepcMatDenseMult(PetscScalar *C,PetscInt _ldC,PetscScalar
   if (Bt) tmp = rB, rB = cB, cB = tmp, qB = T;
 
   /* Check size */
-  if (cA != rB) SETERRQ(PETSC_COMM_SELF,1,"Matrix dimensions do not match");
+  if (cA != rB) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_PLIB,"Matrix dimensions do not match");
 
   /* Do stub */
   if ((rA == 1) && (cA == 1) && (cB == 1)) {
@@ -527,7 +568,7 @@ PetscErrorCode DSPseudoOrthogonalize(DS ds,DSMatType mat,PetscInt cols,PetscReal
   DSCheckValidMat(ds,mat,2);
   PetscValidLogicalCollectiveInt(ds,cols,3);
   PetscValidRealPointer(s,4);
-  ierr = DSGetDimensions(ds,&n,NULL,&l,NULL,NULL);CHKERRQ(ierr);
+  ierr = DSGetDimensions(ds,&n,&l,NULL,NULL);CHKERRQ(ierr);
   ierr = DSGetLeadingDimension(ds,&ld);CHKERRQ(ierr);
   n = n - l;
   if (cols > n) SETERRQ(PetscObjectComm((PetscObject)ds),PETSC_ERR_ARG_WRONG,"Invalid number of columns");
@@ -559,7 +600,7 @@ PetscErrorCode DSPseudoOrthogonalize(DS ds,DSMatType mat,PetscInt cols,PetscReal
       /* nr_o <- mynorm(A[i]'*m) */
       ierr = SlepcMatDenseMult(&nr0,1,0.0,1.0,&A[ld*i],ld,n,1,PETSC_TRUE,m,n,n,1,PETSC_FALSE);CHKERRQ(ierr);
       nr = PetscSign(PetscRealPart(nr0))*PetscSqrtReal(PetscAbsScalar(nr0));
-      if (PetscAbs(nr) < PETSC_MACHINE_EPSILON) SETERRQ(PETSC_COMM_SELF,1,"Linear dependency detected");
+      if (PetscAbs(nr) < PETSC_MACHINE_EPSILON) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_CONV_FAILED,"Linear dependency detected");
       if (PetscAbs(nr) > 0.7*PetscAbs(nr_o)) break;
       nr_o = nr;
     }
