@@ -18,21 +18,29 @@ int main(int argc,char **argv)
   DS             ds;
   FN             f1,f2,f3,funs[3],qfun;
   SlepcSC        sc;
-  PetscScalar    *Id,*A,*B,*wr,*wi,*X,coeffs[2];
-  PetscReal      tau=0.001,h,a=20,xi,re,im,nrm,aux;
-  PetscInt       i,j,n=10,ld,nev,nfun;
+  PetscScalar    *Id,*A,*B,*wr,*wi,*X,*W,coeffs[2],auxr,alpha;
+  PetscReal      tol,tau=0.001,radius=10,h,a=20,xi,re,im,nrm,aux;
+  PetscInt       i,j,ii,jj,k,n=10,ld,nev,nfun;
   PetscViewer    viewer;
   PetscBool      verbose;
+  RG             rg;
+  DSMatType      mat[3]={DS_MAT_E0,DS_MAT_E1,DS_MAT_E2};
+#if !defined(PETSC_USE_COMPLEX)
+  PetscScalar    auxi;
+#endif
 
   ierr = SlepcInitialize(&argc,&argv,(char*)0,help);if (ierr) return ierr;
   ierr = PetscOptionsGetInt(NULL,NULL,"-n",&n,NULL);CHKERRQ(ierr);
   ierr = PetscOptionsGetReal(NULL,NULL,"-tau",&tau,NULL);CHKERRQ(ierr);
   ierr = PetscPrintf(PETSC_COMM_WORLD,"Solve a Dense System of type NEP - dimension %D, tau=%g.\n",n,(double)tau);CHKERRQ(ierr);
   ierr = PetscOptionsHasName(NULL,NULL,"-verbose",&verbose);CHKERRQ(ierr);
+  ierr = PetscOptionsGetReal(NULL,NULL,"-radius",&radius,NULL);CHKERRQ(ierr);
 
   /* Create DS object */
   ierr = DSCreate(PETSC_COMM_WORLD,&ds);CHKERRQ(ierr);
   ierr = DSSetType(ds,DSNEP);CHKERRQ(ierr);
+  tol  = 1000*n*PETSC_MACHINE_EPSILON;
+  ierr = DSNEPSetRefine(ds,tol,PETSC_DECIDE);CHKERRQ(ierr);
   ierr = DSSetFromOptions(ds);CHKERRQ(ierr);
 
   /* Set functions (prior to DSAllocate) */
@@ -58,7 +66,14 @@ int main(int argc,char **argv)
   /* Set dimensions */
   ld = n+2;  /* test leading dimension larger than n */
   ierr = DSAllocate(ds,ld);CHKERRQ(ierr);
-  ierr = DSSetDimensions(ds,n,0,0,0);CHKERRQ(ierr);
+  ierr = DSSetDimensions(ds,n,0,0);CHKERRQ(ierr);
+
+  /* Set region (used only in method=1) */
+  ierr = RGCreate(PETSC_COMM_WORLD,&rg);CHKERRQ(ierr);
+  ierr = RGSetType(rg,RGELLIPSE);CHKERRQ(ierr);
+  ierr = RGEllipseSetParameters(rg,0.0,radius,1.0);CHKERRQ(ierr);
+  ierr = DSNEPSetRG(ds,rg);CHKERRQ(ierr);
+  ierr = RGDestroy(&rg);CHKERRQ(ierr);
 
   /* Set up viewer */
   ierr = PetscViewerASCIIGetStdout(PETSC_COMM_WORLD,&viewer);CHKERRQ(ierr);
@@ -102,7 +117,7 @@ int main(int argc,char **argv)
   }
 
   /* Solve */
-  ierr = PetscMalloc2(n,&wr,n,&wi);CHKERRQ(ierr);
+  ierr = PetscCalloc2(n,&wr,n,&wi);CHKERRQ(ierr);
   ierr = DSGetSlepcSC(ds,&sc);CHKERRQ(ierr);
   sc->comparison    = SlepcCompareLargestMagnitude;
   sc->comparisonctx = NULL;
@@ -115,10 +130,13 @@ int main(int argc,char **argv)
     ierr = PetscPrintf(PETSC_COMM_WORLD,"After solve - - - - - - - - -\n");CHKERRQ(ierr);
     ierr = DSView(ds,viewer);CHKERRQ(ierr);
   }
+  ierr = DSGetDimensions(ds,NULL,NULL,NULL,&nev);CHKERRQ(ierr);
 
-  /* Print first eigenvalue */
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Computed eigenvalue =\n");CHKERRQ(ierr);
-  nev = 1;
+  /* Print computed eigenvalues */
+  ierr = PetscMalloc1(ld*ld,&W);CHKERRQ(ierr);
+  ierr = DSVectors(ds,DS_MAT_X,NULL,NULL);CHKERRQ(ierr);
+  ierr = DSGetArray(ds,DS_MAT_X,&X);CHKERRQ(ierr);
+  ierr = PetscPrintf(PETSC_COMM_WORLD,"Computed eigenvalues =\n");CHKERRQ(ierr);
   for (i=0;i<nev;i++) {
 #if defined(PETSC_USE_COMPLEX)
     re = PetscRealPart(wr[i]);
@@ -127,35 +145,42 @@ int main(int argc,char **argv)
     re = wr[i];
     im = wi[i];
 #endif
+    /* Residual */
+    ierr = PetscArrayzero(W,ld*ld);CHKERRQ(ierr);
+    for (k=0;k<nfun;k++) {
+      ierr = FNEvaluateFunction(funs[k],wr[i],&alpha);CHKERRQ(ierr);
+      ierr = DSGetArray(ds,mat[k],&A);CHKERRQ(ierr);
+      for (jj=0;jj<n;jj++) for (ii=0;ii<n;ii++) W[jj*ld+ii] += alpha*A[jj*ld+ii];
+      ierr = DSRestoreArray(ds,mat[k],&A);CHKERRQ(ierr);
+    }
+    nrm = 0.0;
+    for (k=0;k<n;k++) {
+      auxr = 0.0;
+#if !defined(PETSC_USE_COMPLEX)
+      auxi = 0.0;
+#endif
+      for (j=0;j<n;j++) {
+        auxr += W[k+j*ld]*X[i*ld+j];
+#if !defined(PETSC_USE_COMPLEX)
+        if (PetscAbs(wi[j])!=0.0) auxi += W[k+j*ld]*X[(i+1)*ld+j];
+#endif
+      }
+      aux = SlepcAbsEigenvalue(auxr,auxi);
+      nrm += aux*aux;
+    }
+    nrm = PetscSqrtReal(nrm);
+    if (nrm/SlepcAbsEigenvalue(wr[i],wi[i])>tol) {
+      ierr = PetscPrintf(PETSC_COMM_WORLD,"Warning: the residual norm of the %D-th computed eigenpair %g\n",i,(double)nrm);CHKERRQ(ierr);
+    }
     if (PetscAbs(im)<1e-10) {
       ierr = PetscViewerASCIIPrintf(viewer,"  %.5f\n",(double)re);CHKERRQ(ierr);
     } else {
       ierr = PetscViewerASCIIPrintf(viewer,"  %.5f%+.5fi\n",(double)re,(double)im);CHKERRQ(ierr);
     }
   }
-
-  /* Eigenvectors */
-  ierr = DSVectors(ds,DS_MAT_X,NULL,NULL);CHKERRQ(ierr);
-  j = 0;
-  nrm = 0.0;
-  ierr = DSGetArray(ds,DS_MAT_X,&X);CHKERRQ(ierr);
-  for (i=0;i<n;i++) {
-#if defined(PETSC_USE_COMPLEX)
-    aux = PetscAbsScalar(X[i+j*ld]);
-#else
-    if (PetscAbs(wi[j])==0.0) aux = PetscAbsScalar(X[i+j*ld]);
-    else aux = SlepcAbsEigenvalue(X[i+j*ld],X[i+(j+1)*ld]);
-#endif
-    nrm += aux*aux;
-  }
+  ierr = PetscFree(W);CHKERRQ(ierr);
   ierr = DSRestoreArray(ds,DS_MAT_X,&X);CHKERRQ(ierr);
-  nrm = PetscSqrtReal(nrm);
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Norm of eigenvector = %.3f\n",(double)nrm);CHKERRQ(ierr);
-  if (verbose) {
-    ierr = PetscPrintf(PETSC_COMM_WORLD,"After vectors - - - - - - - - -\n");CHKERRQ(ierr);
-    ierr = DSView(ds,viewer);CHKERRQ(ierr);
-  }
-
+  ierr = DSRestoreArray(ds,DS_MAT_W,&W);CHKERRQ(ierr);
   ierr = PetscFree2(wr,wi);CHKERRQ(ierr);
   ierr = FNDestroy(&f1);CHKERRQ(ierr);
   ierr = FNDestroy(&f2);CHKERRQ(ierr);
@@ -167,7 +192,14 @@ int main(int argc,char **argv)
 
 /*TEST
 
-   test:
-      suffix: 1
+   testset:
+      test:
+         filter: grep -v "solving the problem"
+         suffix: 1
+      test:
+         suffix: 2
+         args: -ds_method 1 -radius 10 -ds_nep_refine_its 1
+         filter: grep -v "solving the problem" | sed -e "s/[+-]0\.0*i//g" | sed -e "s/37411/37410/" | sed -e "s/tolerance [0-9]\.[0-9]*e[+-]\([0-9]*\)/tolerance removed/" | sed -e "s/tolerance [0-9]\.\([0-9]*\)/tolerance removed/"
+         requires: complex
 
 TEST*/
