@@ -18,10 +18,10 @@ int main(int argc,char **argv)
   DS             ds;
   SlepcSC        sc;
   PetscReal      sigma,rnorm,aux;
-  PetscScalar    *A,*U,*w;
-  PetscInt       i,j,k,n=15,m=10,ld;
+  PetscScalar    *A,*U,*w,d;
+  PetscInt       i,j,k,n=15,m=10,m1,ld;
   PetscViewer    viewer;
-  PetscBool      verbose;
+  PetscBool      verbose,extrarow;
 
   ierr = SlepcInitialize(&argc,&argv,(char*)0,help);if (ierr) return ierr;
   ierr = PetscOptionsGetInt(NULL,NULL,"-n",&n,NULL);CHKERRQ(ierr);
@@ -29,6 +29,7 @@ int main(int argc,char **argv)
   k = PetscMin(n,m);
   ierr = PetscPrintf(PETSC_COMM_WORLD,"Solve a Dense System of type SVD - dimension %Dx%D.\n",n,m);CHKERRQ(ierr);
   ierr = PetscOptionsHasName(NULL,NULL,"-verbose",&verbose);CHKERRQ(ierr);
+  ierr = PetscOptionsHasName(NULL,NULL,"-extrarow",&extrarow);CHKERRQ(ierr);
 
   /* Create DS object */
   ierr = DSCreate(PETSC_COMM_WORLD,&ds);CHKERRQ(ierr);
@@ -36,7 +37,11 @@ int main(int argc,char **argv)
   ierr = DSSetFromOptions(ds);CHKERRQ(ierr);
   ld = n+2;  /* test leading dimension larger than n */
   ierr = DSAllocate(ds,ld);CHKERRQ(ierr);
-  ierr = DSSetDimensions(ds,n,m,0,0);CHKERRQ(ierr);
+  ierr = DSSetDimensions(ds,n,0,0);CHKERRQ(ierr);
+  ierr = DSSVDSetDimensions(ds,m);CHKERRQ(ierr);
+  ierr = DSSVDGetDimensions(ds,&m1);CHKERRQ(ierr);
+  if (m1!=m) SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_PLIB,"Inconsistent dimension value");
+  ierr = DSSetExtraRow(ds,extrarow);CHKERRQ(ierr);
 
   /* Set up viewer */
   ierr = PetscViewerASCIIGetStdout(PETSC_COMM_WORLD,&viewer);CHKERRQ(ierr);
@@ -53,6 +58,7 @@ int main(int argc,char **argv)
   for (j=1;j<n/2;j++) {
     for (i=0;i<n-j;i++) { if ((i+j)<n && i<m) A[(i+j)+i*ld]=-1.0; }
   }
+  if (extrarow) { A[n-2+m*ld]=1.0; A[n-1+m*ld]=1.0; }  /* really an extra column */
   ierr = DSRestoreArray(ds,DS_MAT_A,&A);CHKERRQ(ierr);
   ierr = DSSetState(ds,DS_STATE_RAW);CHKERRQ(ierr);
   if (verbose) {
@@ -70,6 +76,7 @@ int main(int argc,char **argv)
   sc->mapobj        = NULL;
   ierr = DSSolve(ds,w,NULL);CHKERRQ(ierr);
   ierr = DSSort(ds,w,NULL,NULL,NULL,NULL);CHKERRQ(ierr);
+  if (extrarow) { ierr = DSUpdateExtraRow(ds);CHKERRQ(ierr); }
   if (verbose) {
     ierr = PetscPrintf(PETSC_COMM_WORLD,"After solve - - - - - - - - -\n");CHKERRQ(ierr);
     ierr = DSView(ds,viewer);CHKERRQ(ierr);
@@ -82,6 +89,19 @@ int main(int argc,char **argv)
     ierr = PetscViewerASCIIPrintf(viewer,"  %.5f\n",(double)sigma);CHKERRQ(ierr);
   }
 
+  if (extrarow) {
+    /* Check that extra column is correct */
+    ierr = DSGetArray(ds,DS_MAT_A,&A);CHKERRQ(ierr);
+    ierr = DSGetArray(ds,DS_MAT_U,&U);CHKERRQ(ierr);
+    d = 0.0;
+    for (i=0;i<n;i++) d += A[i+m*ld]-U[n-2+i*ld]-U[n-1+i*ld];
+    if (PetscAbsScalar(d)>10*PETSC_MACHINE_EPSILON) {
+      ierr = PetscPrintf(PETSC_COMM_WORLD,"Warning: there is a mismatch in the extra row of %g\n",(double)PetscAbsScalar(d));CHKERRQ(ierr);
+    }
+    ierr = DSRestoreArray(ds,DS_MAT_A,&A);CHKERRQ(ierr);
+    ierr = DSRestoreArray(ds,DS_MAT_U,&U);CHKERRQ(ierr);
+  }
+
   /* Singular vectors */
   ierr = DSVectors(ds,DS_MAT_U,NULL,NULL);CHKERRQ(ierr);  /* all singular vectors */
   j = 0;
@@ -107,4 +127,9 @@ int main(int argc,char **argv)
       suffix: 1
       requires: !single
 
+   test:
+      suffix: 2
+      args: -extrarow
+      requires: !single
+
 TEST*/
