@@ -413,12 +413,12 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa(FN fn,Mat A,Mat B)
 {
 #if !defined(PETSC_HAVE_COMPLEX)
   PetscFunctionBegin;
-  SETERRQ(PETSC_COMM_SELF,1,"This function requires C99 or C++ complex support");
+  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"This function requires C99 or C++ complex support");
 #else
   PetscInt          i,j,n_,s,k,m,mod;
   PetscBLASInt      n=0,n2=0,irsize=0,rsizediv2,ipsize=0,iremainsize=0,info,*piv,minlen,lwork=0,one=1;
   PetscReal         nrm,shift=0.0;
-#if defined(PETSC_USE_COMPLEX) || defined(PETSC_HAVE_ESSL)
+#if defined(PETSC_USE_COMPLEX)
   PetscReal         *rwork=NULL;
 #endif
   PetscComplex      *As,*RR,*RR2,*expmA,*expmA2,*Maux,*Maux2,rsize,*r,psize,*p,remainsize,*remainterm,*rootp,*rootq,mult=0.0,scale,cone=1.0,czero=0.0,*aux;
@@ -426,13 +426,8 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa(FN fn,Mat A,Mat B)
   const PetscScalar *Aa;
   PetscErrorCode    ierr;
   PetscBool         isreal,flg;
-#if defined(PETSC_HAVE_ESSL)
-  PetscScalar       sdummy,*wri;
-  PetscBLASInt      idummy,io=0;
-#else
   PetscBLASInt      query=-1;
   PetscScalar       work1,*work;
-#endif
 
   PetscFunctionBegin;
   ierr = MatGetSize(A,&n_,NULL);CHKERRQ(ierr);
@@ -449,7 +444,6 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa(FN fn,Mat A,Mat B)
     ierr = PetscMalloc2(n,&wr,n,&wi);CHKERRQ(ierr);
     ierr = PetscArraycpy(sMaux,Aa,n2);CHKERRQ(ierr);
     /* estimate rightmost eigenvalue and shift A with it */
-#if !defined(PETSC_HAVE_ESSL)
 #if !defined(PETSC_USE_COMPLEX)
     PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_("N","N",&n,sMaux,&n,wr,wi,NULL,&n,NULL,&n,&work1,&query,&info));
     SlepcCheckLapackInfo("geev",info);
@@ -467,21 +461,6 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa(FN fn,Mat A,Mat B)
     ierr = PetscFree2(rwork,work);CHKERRQ(ierr);
 #endif
     SlepcCheckLapackInfo("geev",info);
-#else /* defined(PETSC_HAVE_ESSL) */
-    ierr = PetscBLASIntCast(4*n,&lwork);CHKERRQ(ierr);
-    ierr = PetscMalloc2(lwork,&rwork,2*n,&wri);CHKERRQ(ierr);
-#if !defined(PETSC_USE_COMPLEX)
-    PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_(&io,sMaux,&n,wri,&sdummy,&idummy,&idummy,&n,rwork,&lwork));
-    for (i=0;i<n;i++) {
-      wr[i] = wri[2*i];
-      wi[i] = wri[2*i+1];
-    }
-#else
-    PetscStackCallBLAS("LAPACKgeev",LAPACKgeev_(&io,Maux,&n,wri,&sdummy,&idummy,&idummy,&n,rwork,&lwork));
-    for (i=0;i<n;i++) wr[i] = wri[i];
-#endif
-    ierr = PetscFree2(rwork,wri);CHKERRQ(ierr);
-#endif
     ierr = PetscLogFlops(25.0*n*n*n+(n*n*n)/3.0+1.0*n*n*n);CHKERRQ(ierr);
 
     shift = PetscRealPart(wr[0]);
@@ -981,6 +960,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Pade_CUDA(FN fn,Mat A,Mat B)
   cudaError_t    cerr;
 
   PetscFunctionBegin;
+  ierr = PetscCUDAInitializeCheck();CHKERRQ(ierr); /* For CUDA event timers */
   ierr = PetscCUBLASGetHandle(&cublasv2handle);CHKERRQ(ierr);
   ierr = MatDenseGetArray(A,&Aa);CHKERRQ(ierr);
   ierr = MatDenseGetArray(B,&Ba);CHKERRQ(ierr);
@@ -999,12 +979,12 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Pade_CUDA(FN fn,Mat A,Mat B)
   cerr = cudaMalloc((void **)&d_ppP,sizeof(PetscScalar*));CHKERRCUDA(cerr);
   cerr = cudaMalloc((void **)&d_ppQ,sizeof(PetscScalar*));CHKERRCUDA(cerr);
 
-  ierr = PetscMalloc(sizeof(PetscScalar*),&ppP);CHKERRQ(ierr);
-  ierr = PetscMalloc(sizeof(PetscScalar*),&ppQ);CHKERRQ(ierr);
+  ierr = PetscMalloc1(1,&ppP);CHKERRQ(ierr);
+  ierr = PetscMalloc1(1,&ppQ);CHKERRQ(ierr);
 
   cerr = cudaMemcpy(d_As,Aa,sizeof(PetscScalar)*ld2,cudaMemcpyHostToDevice);CHKERRCUDA(cerr);
-  cerr = cudaMemcpy(d_Ba,Ba,sizeof(PetscScalar)*ld2,cudaMemcpyHostToDevice);CHKERRCUDA(cerr);
   d_P = d_Ba;
+  ierr = PetscLogGpuTimeBegin();CHKERRQ(ierr);
 
   /* Pade' coefficients */
   c[0] = 1.0;
@@ -1016,12 +996,12 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Pade_CUDA(FN fn,Mat A,Mat B)
     sexp = PetscMax(0,(int)(PetscLogReal(s)/PetscLogReal(2.0))+2);
     scale = PetscPowRealInt(2.0,-sexp);
     cberr = cublasXscal(cublasv2handle,ld2,&scale,d_As,one);CHKERRCUBLAS(cberr);
-    ierr = PetscLogFlops(1.0*n*n);CHKERRQ(ierr);
+    ierr = PetscLogGpuFlops(1.0*n*n);CHKERRQ(ierr);
   } else sexp = 0;
 
   /* Horner evaluation */
   cberr = cublasXgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n,n,n,&sone,d_As,ld,d_As,ld,&szero,d_A2,ld);CHKERRCUBLAS(cberr);
-  ierr = PetscLogFlops(2.0*n*n*n);CHKERRQ(ierr);
+  ierr = PetscLogGpuFlops(2.0*n*n*n);CHKERRQ(ierr);
   cerr = cudaMemset(d_Q,zero,sizeof(PetscScalar)*ld2);CHKERRCUDA(cerr);
   cerr = cudaMemset(d_P,zero,sizeof(PetscScalar)*ld2);CHKERRCUDA(cerr);
   ierr = set_diagonal(n,d_Q,ld,c[p]);CHKERRQ(cerr);
@@ -1040,7 +1020,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Pade_CUDA(FN fn,Mat A,Mat B)
       ierr = shift_diagonal(n,d_P,ld,c[k-1]);CHKERRQ(cerr);
       odd = PETSC_TRUE;
     }
-    ierr = PetscLogFlops(2.0*n*n*n);CHKERRQ(ierr);
+    ierr = PetscLogGpuFlops(2.0*n*n*n);CHKERRQ(ierr);
   }
   if (odd) {
     cberr = cublasXgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n,n,n,&sone,d_Q,ld,d_As,ld,&szero,d_W,ld);CHKERRCUBLAS(cberr);
@@ -1078,19 +1058,19 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Pade_CUDA(FN fn,Mat A,Mat B)
 
     cberr = cublasXgetrfBatched(cublasv2handle,n,d_ppQ,ld,d_ipiv,d_info,one);CHKERRCUBLAS(cberr);
     cerr = cudaMemcpy(&info,d_info,sizeof(PetscBLASInt),cudaMemcpyDeviceToHost);CHKERRCUDA(cerr);
-    if (info < 0) SETERRQ1(PETSC_COMM_SELF, PETSC_ERR_LIB, "LAPACKgetrf: Illegal value on argument %d",PetscAbsInt(info));
-    if (info > 0) SETERRQ2(PETSC_COMM_SELF, PETSC_ERR_MAT_LU_ZRPVT, "LAPACKgetrf: Matrix is singular. U(%d,%d) is zero",info,info);
+    if (info < 0) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_LIB,"LAPACKgetrf: Illegal value on argument %d",PetscAbsInt(info));
+    if (info > 0) SETERRQ2(PETSC_COMM_SELF,PETSC_ERR_MAT_LU_ZRPVT,"LAPACKgetrf: Matrix is singular. U(%d,%d) is zero",info,info);
 #if defined (CUDA_VERSION) && CUDA_VERSION >= 5050
     cberr = cublasXgetrsBatched(cublasv2handle,CUBLAS_OP_N,n,n,(const PetscScalar **)d_ppQ,ld,d_ipiv,d_ppP,ld,&info,one);CHKERRCUBLAS(cberr);
-    if (info < 0) SETERRQ1(PETSC_COMM_SELF, PETSC_ERR_LIB, "LAPACKgetri: Illegal value on argument %d",PetscAbsInt(info));
-    if (info > 0) SETERRQ2(PETSC_COMM_SELF, PETSC_ERR_MAT_LU_ZRPVT, "LAPACKgetri: Matrix is singular. U(%d,%d) is zero",info,info);
+    if (info < 0) SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_LIB,"LAPACKgetri: Illegal value on argument %d",PetscAbsInt(info));
+    if (info > 0) SETERRQ2(PETSC_COMM_SELF,PETSC_ERR_MAT_LU_ZRPVT,"LAPACKgetri: Matrix is singular. U(%d,%d) is zero",info,info);
 #else
     SETERRQ(communicator,PETSC_ERR_LIB,"cublasXgetrsBatched needs CUDA >= 7");
 #endif
     cberr = cublasXscal(cublasv2handle,ld2,&stwo,d_P,one);CHKERRCUBLAS(cberr);
     ierr = shift_diagonal(n,d_P,ld,sone);CHKERRQ(cerr);
   }
-  ierr = PetscLogFlops(2.0*n*n*n+2.0*n*n*n/3.0+4.0*n*n);CHKERRQ(ierr);
+  ierr = PetscLogGpuFlops(2.0*n*n*n+2.0*n*n*n/3.0+4.0*n*n);CHKERRQ(ierr);
 
   for (k=1;k<=sexp;k++) {
     cberr = cublasXgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n,n,n,&sone,d_P,ld,d_P,ld,&szero,d_W,ld);CHKERRCUBLAS(cberr);
@@ -1101,8 +1081,9 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Pade_CUDA(FN fn,Mat A,Mat B)
   } else {
     cerr = cudaMemcpy(Ba,d_Ba,sizeof(PetscScalar)*ld2,cudaMemcpyDeviceToHost);CHKERRCUDA(cerr);
   }
-  ierr = PetscLogFlops(2.0*n*n*n*sexp);CHKERRQ(ierr);
+  ierr = PetscLogGpuFlops(2.0*n*n*n*sexp);CHKERRQ(ierr);
 
+  ierr = PetscLogGpuTimeEnd();CHKERRQ(ierr);
   cerr = cudaFree(d_Ba);CHKERRCUDA(cerr);
   cerr = cudaFree(d_Q);CHKERRCUDA(cerr);
   cerr = cudaFree(d_W);CHKERRCUDA(cerr);
@@ -1141,6 +1122,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Pade_CUDAm(FN fn,Mat A,Mat B)
   magma_int_t    mierr;
 
   PetscFunctionBegin;
+  ierr = PetscCUDAInitializeCheck();CHKERRQ(ierr); /* For CUDA event timers */
   ierr = PetscCUBLASGetHandle(&cublasv2handle);CHKERRQ(ierr);
   magma_init();
   ierr = MatDenseGetArray(A,&Aa);CHKERRQ(ierr);
@@ -1156,11 +1138,11 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Pade_CUDAm(FN fn,Mat A,Mat B)
   cerr = cudaMalloc((void **)&d_As,sizeof(PetscScalar)*m*m);CHKERRCUDA(cerr);
   cerr = cudaMalloc((void **)&d_A2,sizeof(PetscScalar)*m*m);CHKERRCUDA(cerr);
 
-  ierr = PetscMalloc(sizeof(PetscInt)*n,&piv);CHKERRQ(ierr);
+  ierr = PetscMalloc1(n,&piv);CHKERRQ(ierr);
 
   cerr = cudaMemcpy(d_As,Aa,sizeof(PetscScalar)*ld2,cudaMemcpyHostToDevice);CHKERRCUDA(cerr);
-  cerr = cudaMemcpy(d_Ba,Ba,sizeof(PetscScalar)*ld2,cudaMemcpyHostToDevice);CHKERRCUDA(cerr);
   d_P = d_Ba;
+  ierr = PetscLogGpuTimeBegin();CHKERRQ(ierr);
 
   /* Pade' coefficients */
   c[0] = 1.0;
@@ -1168,18 +1150,18 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Pade_CUDAm(FN fn,Mat A,Mat B)
 
   /* Scaling */
   cberr = cublasXnrm2(cublasv2handle,ld2,d_As,one,&s);CHKERRCUBLAS(cberr);
-  ierr = PetscLogFlops(1.0*n*n);CHKERRQ(ierr);
+  ierr = PetscLogGpuFlops(1.0*n*n);CHKERRQ(ierr);
 
   if (s>0.5) {
     sexp = PetscMax(0,(int)(PetscLogReal(s)/PetscLogReal(2.0))+2);
     scale = PetscPowRealInt(2.0,-sexp);
     cberr = cublasXscal(cublasv2handle,ld2,&scale,d_As,one);CHKERRCUBLAS(cberr);
-    ierr = PetscLogFlops(1.0*n*n);CHKERRQ(ierr);
+    ierr = PetscLogGpuFlops(1.0*n*n);CHKERRQ(ierr);
   } else sexp = 0;
 
   /* Horner evaluation */
   cberr = cublasXgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n,n,n,&sone,d_As,ld,d_As,ld,&szero,d_A2,ld);CHKERRCUBLAS(cberr);
-  ierr = PetscLogFlops(2.0*n*n*n);CHKERRQ(ierr);
+  ierr = PetscLogGpuFlops(2.0*n*n*n);CHKERRQ(ierr);
   cerr = cudaMemset(d_Q,zero,sizeof(PetscScalar)*ld2);CHKERRCUDA(cerr);
   cerr = cudaMemset(d_P,zero,sizeof(PetscScalar)*ld2);CHKERRCUDA(cerr);
   ierr = set_diagonal(n,d_Q,ld,c[p]);CHKERRQ(cerr);
@@ -1198,7 +1180,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Pade_CUDAm(FN fn,Mat A,Mat B)
       ierr = shift_diagonal(n,d_P,ld,c[k-1]);CHKERRQ(cerr);
       odd = PETSC_TRUE;
     }
-    ierr = PetscLogFlops(2.0*n*n*n);CHKERRQ(ierr);
+    ierr = PetscLogGpuFlops(2.0*n*n*n);CHKERRQ(ierr);
   }
   if (odd) {
     cberr = cublasXgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n,n,n,&sone,d_Q,ld,d_As,ld,&szero,d_W,ld);CHKERRCUBLAS(cberr);
@@ -1218,7 +1200,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Pade_CUDAm(FN fn,Mat A,Mat B)
     cberr = cublasXscal(cublasv2handle,ld2,&stwo,d_P,one);CHKERRCUBLAS(cberr);
     ierr = shift_diagonal(n,d_P,ld,sone);CHKERRQ(cerr);
   }
-  ierr = PetscLogFlops(2.0*n*n*n+2.0*n*n*n/3.0+4.0*n*n);CHKERRQ(ierr);
+  ierr = PetscLogGpuFlops(2.0*n*n*n+2.0*n*n*n/3.0+4.0*n*n);CHKERRQ(ierr);
 
   for (k=1;k<=sexp;k++) {
     cberr = cublasXgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n,n,n,&sone,d_P,ld,d_P,ld,&szero,d_W,ld);CHKERRCUBLAS(cberr);
@@ -1229,8 +1211,9 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Pade_CUDAm(FN fn,Mat A,Mat B)
   } else {
     cerr = cudaMemcpy(Ba,d_Ba,sizeof(PetscScalar)*ld2,cudaMemcpyDeviceToHost);CHKERRCUDA(cerr);
   }
-  ierr = PetscLogFlops(2.0*n*n*n*sexp);CHKERRQ(ierr);
+  ierr = PetscLogGpuFlops(2.0*n*n*n*sexp);CHKERRQ(ierr);
 
+  ierr = PetscLogGpuTimeEnd();CHKERRQ(ierr);
   cerr = cudaFree(d_Ba);CHKERRCUDA(cerr);
   cerr = cudaFree(d_Q);CHKERRCUDA(cerr);
   cerr = cudaFree(d_W);CHKERRCUDA(cerr);
@@ -1273,6 +1256,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Higham_CUDAm(FN fn,Mat A,Mat B)
   magma_int_t       mierr;
 
   PetscFunctionBegin;
+  ierr = PetscCUDAInitializeCheck();CHKERRQ(ierr); /* For CUDA event timers */
   ierr = PetscCUBLASGetHandle(&cublasv2handle);CHKERRQ(ierr);
   magma_init();
   ierr = MatDenseGetArray(A,&Aa);CHKERRQ(ierr);
@@ -1281,9 +1265,10 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Higham_CUDAm(FN fn,Mat A,Mat B)
   ierr = PetscBLASIntCast(n,&n_);CHKERRQ(ierr);
   n2 = n_*n_;
   ierr = PetscMalloc2(8*n*n,&work,n,&ipiv);CHKERRQ(ierr);
-  ierr = cudaMalloc((void**)&d_work,8*n*n*sizeof(PetscScalar));CHKERRQ(ierr);
+  cerr = cudaMalloc((void**)&d_work,8*n*n*sizeof(PetscScalar));CHKERRCUDA(ierr);
   cerr = cudaMalloc((void **)&d_Ba,sizeof(PetscScalar)*n*n);CHKERRCUDA(cerr);
-  ierr = cudaMemcpy(d_Ba,Ba,n2*sizeof(PetscScalar),cudaMemcpyHostToDevice);CHKERRQ(ierr);
+
+  ierr = PetscLogGpuTimeBegin();CHKERRQ(ierr);
 
   /* Matrix powers */
   Apowers[0] = work;                  /* Apowers[0] = A   */
@@ -1298,13 +1283,13 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Higham_CUDAm(FN fn,Mat A,Mat B)
   d_Apowers[3] = d_Apowers[2] + n*n;    /* d_Apowers[3] = A^6 */
   d_Apowers[4] = d_Apowers[3] + n*n;    /* d_Apowers[4] = A^8 */
 
-  ierr = cudaMemcpy(d_Apowers[0],Aa,n2*sizeof(PetscScalar),cudaMemcpyHostToDevice);CHKERRQ(ierr);
+  cerr = cudaMemcpy(d_Apowers[0],Aa,n2*sizeof(PetscScalar),cudaMemcpyHostToDevice);CHKERRCUDA(ierr);
   cberr = cublasXgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n_,n_,n_,&sone,d_Apowers[0],n_,d_Apowers[0],n_,&szero,d_Apowers[1],n_);CHKERRCUBLAS(cberr);
   cberr = cublasXgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n_,n_,n_,&sone,d_Apowers[1],n_,d_Apowers[1],n_,&szero,d_Apowers[2],n_);CHKERRCUBLAS(cberr);
   cberr = cublasXgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n_,n_,n_,&sone,d_Apowers[1],n_,d_Apowers[2],n_,&szero,d_Apowers[3],n_);CHKERRCUBLAS(cberr);
-  ierr = PetscLogFlops(6.0*n*n*n);CHKERRQ(ierr);
+  ierr = PetscLogGpuFlops(6.0*n*n*n);CHKERRQ(ierr);
 
-  ierr = cudaMemcpy(Apowers[0],d_Apowers[0],4*n2*sizeof(PetscScalar),cudaMemcpyDeviceToHost);CHKERRQ(ierr);
+  cerr = cudaMemcpy(Apowers[0],d_Apowers[0],4*n2*sizeof(PetscScalar),cudaMemcpyDeviceToHost);CHKERRCUDA(ierr);
   /* Compute scaling parameter and order of Pade approximant */
   ierr = expm_params(n,Apowers,&s,&m,Apowers[4]);CHKERRQ(ierr);
 
@@ -1313,7 +1298,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Higham_CUDAm(FN fn,Mat A,Mat B)
       scale = PetscPowRealInt(2.0,-PetscMax(2*j,1)*s);
       cberr = cublasXscal(cublasv2handle,n2,&scale,d_Apowers[j],one);CHKERRCUBLAS(cberr);
     }
-    ierr = PetscLogFlops(4.0*n*n);CHKERRQ(ierr);
+    ierr = PetscLogGpuFlops(4.0*n*n);CHKERRQ(ierr);
   }
 
   /* Evaluate the Pade approximant */
@@ -1341,10 +1326,10 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Higham_CUDAm(FN fn,Mat A,Mat B)
       for (j=m;j>=3;j-=2) {
         cberr = cublasXaxpy(cublasv2handle,n2,&c[j],d_Apowers[(j+1)/2-1],one,d_P,one);CHKERRCUBLAS(cberr);
         cberr = cublasXaxpy(cublasv2handle,n2,&c[j-1],d_Apowers[(j+1)/2-1],one,d_Q,one);CHKERRCUBLAS(cberr);
-        ierr = PetscLogFlops(4.0*n*n);CHKERRQ(ierr);
+        ierr = PetscLogGpuFlops(4.0*n*n);CHKERRQ(ierr);
       }
       cberr = cublasXgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n_,n_,n_,&sone,d_Apowers[0],n_,d_P,n_,&szero,d_W,n_);CHKERRCUBLAS(cberr);
-      ierr = PetscLogFlops(2.0*n*n*n);CHKERRQ(ierr);
+      ierr = PetscLogGpuFlops(2.0*n*n*n);CHKERRQ(ierr);
       SWAP(d_P,d_W,aux);
       break;
     case 13:
@@ -1355,7 +1340,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Higham_CUDAm(FN fn,Mat A,Mat B)
       cberr = cublasXaxpy(cublasv2handle,n2,&c[11],d_Apowers[2],one,d_P,one);CHKERRCUBLAS(cberr);
       cberr = cublasXaxpy(cublasv2handle,n2,&c[9],d_Apowers[1],one,d_P,one);CHKERRCUBLAS(cberr);
       cberr = cublasXgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n_,n_,n_,&sone,d_Apowers[3],n_,d_P,n_,&szero,d_W,n_);CHKERRCUBLAS(cberr);
-      ierr = PetscLogFlops(5.0*n*n+2.0*n*n*n);CHKERRQ(ierr);
+      ierr = PetscLogGpuFlops(5.0*n*n+2.0*n*n*n);CHKERRQ(ierr);
 
       cerr = cudaMemset(d_P,zero,sizeof(PetscScalar)*n2);CHKERRCUDA(cerr);
       ierr = set_diagonal(n,d_P,n,c[1]);CHKERRQ(cerr);
@@ -1364,7 +1349,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Higham_CUDAm(FN fn,Mat A,Mat B)
       cberr = cublasXaxpy(cublasv2handle,n2,&c[3],d_Apowers[1],one,d_P,one);CHKERRCUBLAS(cberr);
       cberr = cublasXaxpy(cublasv2handle,n2,&sone,d_P,one,d_W,one);CHKERRCUBLAS(cberr);
       cberr = cublasXgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n_,n_,n_,&sone,d_Apowers[0],n_,d_W,n_,&szero,d_P,n_);CHKERRCUBLAS(cberr);
-      ierr = PetscLogFlops(7.0*n*n+2.0*n*n*n);CHKERRQ(ierr);
+      ierr = PetscLogGpuFlops(7.0*n*n+2.0*n*n*n);CHKERRQ(ierr);
       /*  Q = Apowers[3]*(c[12]*Apowers[3] + c[10]*Apowers[2] + c[8]*Apowers[1])
           + c[6]*Apowers[3] + c[4]*Apowers[2] + c[2]*Apowers[1] + c[0]*I        */
       cerr = cudaMemcpy(d_Q,d_Apowers[3],n2*sizeof(PetscScalar),cudaMemcpyDeviceToDevice);CHKERRCUDA(cerr);
@@ -1372,14 +1357,14 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Higham_CUDAm(FN fn,Mat A,Mat B)
       cberr = cublasXaxpy(cublasv2handle,n2,&c[10],d_Apowers[2],one,d_Q,one);CHKERRCUBLAS(cberr);
       cberr = cublasXaxpy(cublasv2handle,n2,&c[8],d_Apowers[1],one,d_Q,one);CHKERRCUBLAS(cberr);
       cberr = cublasXgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n_,n_,n_,&sone,d_Apowers[3],n_,d_Q,n_,&szero,d_W,n_);CHKERRCUBLAS(cberr);
-      ierr = PetscLogFlops(5.0*n*n+2.0*n*n*n);CHKERRQ(ierr);
+      ierr = PetscLogGpuFlops(5.0*n*n+2.0*n*n*n);CHKERRQ(ierr);
       cerr = cudaMemset(d_Q,zero,sizeof(PetscScalar)*n2);CHKERRCUDA(cerr);
       ierr = set_diagonal(n,d_Q,n,c[0]);CHKERRQ(cerr);
       cberr = cublasXaxpy(cublasv2handle,n2,&c[6],d_Apowers[3],one,d_Q,one);CHKERRCUBLAS(cberr);
       cberr = cublasXaxpy(cublasv2handle,n2,&c[4],d_Apowers[2],one,d_Q,one);CHKERRCUBLAS(cberr);
       cberr = cublasXaxpy(cublasv2handle,n2,&c[2],d_Apowers[1],one,d_Q,one);CHKERRCUBLAS(cberr);
       cberr = cublasXaxpy(cublasv2handle,n2,&sone,d_W,one,d_Q,one);CHKERRCUBLAS(cberr);
-      ierr = PetscLogFlops(7.0*n*n);CHKERRQ(ierr);
+      ierr = PetscLogGpuFlops(7.0*n*n);CHKERRQ(ierr);
       break;
     default: SETERRQ1(PETSC_COMM_SELF,PETSC_ERR_ARG_WRONG,"Wrong value of m %d",m);
   }
@@ -1390,7 +1375,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Higham_CUDAm(FN fn,Mat A,Mat B)
 
   cberr = cublasXscal(cublasv2handle,n2,&stwo,d_P,one);CHKERRCUBLAS(cberr);
   ierr = shift_diagonal(n,d_P,n,sone);CHKERRQ(ierr);
-  ierr = PetscLogFlops(2.0*n*n*n/3.0+4.0*n*n);CHKERRQ(ierr);
+  ierr = PetscLogGpuFlops(2.0*n*n*n/3.0+4.0*n*n);CHKERRQ(ierr);
 
   /* Squaring */
   for (j=1;j<=s;j++) {
@@ -1402,11 +1387,14 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_Higham_CUDAm(FN fn,Mat A,Mat B)
   } else {
     cerr = cudaMemcpy(Ba,d_Ba,n2*sizeof(PetscScalar),cudaMemcpyDeviceToHost);CHKERRCUDA(cerr);
   }
-  ierr = PetscLogFlops(2.0*n*n*n*s);CHKERRQ(ierr);
+  ierr = PetscLogGpuFlops(2.0*n*n*n*s);CHKERRQ(ierr);
+  ierr = PetscLogGpuTimeEnd();CHKERRQ(ierr);
 
   ierr = PetscFree2(work,ipiv);CHKERRQ(ierr);
   ierr = MatDenseRestoreArray(A,&Aa);CHKERRQ(ierr);
   ierr = MatDenseRestoreArray(B,&Ba);CHKERRQ(ierr);
+  cerr = cudaFree(d_Ba);CHKERRCUDA(cerr);
+  cerr = cudaFree(d_work);CHKERRCUDA(cerr);
   magma_finalize();
   PetscFunctionReturn(0);
 }
@@ -1438,6 +1426,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa_CUDAm(FN fn,Mat A,Ma
   magma_int_t    mierr;
 
   PetscFunctionBegin;
+  ierr = PetscCUDAInitializeCheck();CHKERRQ(ierr); /* For CUDA event timers */
   ierr = PetscCUBLASGetHandle(&cublasv2handle);CHKERRQ(ierr);
   magma_init();
   ierr = MatGetSize(A,&n_,NULL);CHKERRQ(ierr);
@@ -1447,7 +1436,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa_CUDAm(FN fn,Mat A,Ma
   ierr = PetscBLASIntCast(n*n,&n2);CHKERRQ(ierr);
 
   cerr = cudaMalloc((void **)&d_Ba,sizeof(PetscScalar)*n2);CHKERRCUDA(cerr);
-  cerr = cudaMemcpy(d_Ba,Ba,sizeof(PetscScalar)*n2,cudaMemcpyHostToDevice);CHKERRCUDA(cerr);
+  ierr = PetscLogGpuTimeBegin();CHKERRQ(ierr);
   d_Ba2 = d_Ba;
 
   ierr = PetscMalloc2(n2,&sMaux,n2,&Maux);CHKERRQ(ierr);
@@ -1479,7 +1468,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa_CUDAm(FN fn,Mat A,Ma
     ierr = PetscFree2(rwork,work);CHKERRQ(ierr);
 #endif
     SlepcCheckLapackInfo("geev",info);
-    ierr = PetscLogFlops(25.0*n*n*n+(n*n*n)/3.0+1.0*n*n*n);CHKERRQ(ierr);
+    ierr = PetscLogGpuFlops(25.0*n*n*n+(n*n*n)/3.0+1.0*n*n*n);CHKERRQ(ierr);
 
     shift = PetscRealPart(wr[0]);
     for (i=1;i<n;i++) {
@@ -1491,32 +1480,34 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa_CUDAm(FN fn,Mat A,Ma
   cerr = cudaMemcpy(d_sMaux,Aa,sizeof(PetscScalar)*n2,cudaMemcpyHostToDevice);CHKERRCUDA(cerr);
   if (shift) {
     ierr = shift_diagonal(n,d_sMaux,n,-shift);CHKERRQ(ierr);
-    ierr = PetscLogFlops(1.0*n);CHKERRQ(ierr);
+    ierr = PetscLogGpuFlops(1.0*n);CHKERRQ(ierr);
   }
 #if defined(PETSC_USE_COMPLEX)
   cerr = cudaMemcpy(d_Maux,Aa,sizeof(PetscScalar)*n2,cudaMemcpyHostToDevice);CHKERRCUDA(cerr);
   if (shift) {
     ierr = shift_diagonal(n,d_Maux,n,-shift);CHKERRQ(ierr);
-    ierr = PetscLogFlops(1.0*n);CHKERRQ(ierr);
+    ierr = PetscLogGpuFlops(1.0*n);CHKERRQ(ierr);
   }
 #endif
 
   /* estimate norm(A) and select the scaling factor */
   cberr = cublasXnrm2(cublasv2handle,n2,d_sMaux,one,&nrm);CHKERRCUBLAS(cberr);
-  ierr = PetscLogFlops(2.0*n*n);CHKERRQ(ierr);
+  ierr = PetscLogGpuFlops(2.0*n*n);CHKERRQ(ierr);
   ierr = sexpm_params(nrm,&s,&k,&m);CHKERRQ(ierr);
   if (s==0 && k==1 && m==0) { /* exp(A) = I+A to eps! */
     if (shift) expshift = PetscExpReal(shift);
     ierr = shift_Cdiagonal(n,d_Maux,n,rone,rzero);CHKERRQ(ierr);
     if (shift) {
       cberr = cublasXscal(cublasv2handle,n2,&expshift,d_sMaux,one);CHKERRCUBLAS(cberr);
-      ierr = PetscLogFlops(1.0*(n+n2));CHKERRQ(ierr);
+      ierr = PetscLogGpuFlops(1.0*(n+n2));CHKERRQ(ierr);
     } else {
-      ierr = PetscLogFlops(1.0*n);CHKERRQ(ierr);
+      ierr = PetscLogGpuFlops(1.0*n);CHKERRQ(ierr);
     }
     cerr = cudaMemcpy(Ba,d_sMaux,sizeof(PetscScalar)*n2,cudaMemcpyDeviceToHost);CHKERRCUDA(cerr);
-    cerr = cudaFree(d_sMaux);CHKERRCUDA(cerr);
     cerr = cudaFree(d_Ba);CHKERRCUDA(cerr);
+    cerr = cudaFree(d_isreal);CHKERRCUDA(cerr);
+    cerr = cudaFree(d_sMaux);CHKERRCUDA(cerr);
+    cerr = cudaFree(d_Maux);CHKERRCUDA(cerr);
     ierr = MatDenseRestoreArray(A,&Aa);CHKERRQ(ierr);
     ierr = MatDenseRestoreArray(B,&Ba);CHKERRQ(ierr);
     PetscFunctionReturn(0); /* quick return */
@@ -1535,7 +1526,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa_CUDAm(FN fn,Mat A,Ma
 #endif
   scale = 1.0/PetscPowRealInt(2.0,s);
   cberr = cublasXCscal(cublasv2handle,n2,(const cuComplex *)&scale,(cuComplex *)d_As,one);CHKERRCUBLAS(cberr);
-  ierr = SlepcLogFlopsComplex(1.0*n2);CHKERRQ(ierr);
+  ierr = SlepcLogGpuFlopsComplex(1.0*n2);CHKERRQ(ierr);
 
   /* evaluate Pade approximant (partial fraction or product form) */
   if (fn->method==8 || !m) { /* partial fraction */
@@ -1565,7 +1556,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa_CUDAm(FN fn,Mat A,Ma
         ierr = add_array2D_Conj(n,n,d_RR,n);CHKERRQ(ierr);
         cberr = cublasXCaxpy(cublasv2handle,n2,&cone,d_RR,one,d_expmA,one);CHKERRCUBLAS(cberr);
         /* shift(n) + gesv + axpy(n2) */
-        ierr = SlepcLogFlopsComplex(1.0*n+(2.0*n*n*n/3.0+2.0*n*n*n)+2.0*n2);CHKERRQ(ierr);
+        ierr = SlepcLogGpuFlopsComplex(1.0*n+(2.0*n*n*n/3.0+2.0*n*n*n)+2.0*n2);CHKERRQ(ierr);
       }
 
       mod = ipsize % 2;
@@ -1577,7 +1568,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa_CUDAm(FN fn,Mat A,Ma
         mierr = magma_Cgesv_gpu(n,n,d_Maux,n,piv,d_RR,n,&info);CHKERRMAGMA(mierr);
         SlepcCheckLapackInfo("gesv",info);
         cberr = cublasXCaxpy(cublasv2handle,n2,&cone,d_RR,one,d_expmA,one);CHKERRCUBLAS(cberr);
-        ierr = SlepcLogFlopsComplex(1.0*n+(2.0*n*n*n/3.0+2.0*n*n*n)+1.0*n2);CHKERRQ(ierr);
+        ierr = SlepcLogGpuFlopsComplex(1.0*n+(2.0*n*n*n/3.0+2.0*n*n*n)+1.0*n2);CHKERRQ(ierr);
       }
     } else { /* complex */
       for (i=0;i<irsize;i++) { /* use partial fraction to get R(As) */
@@ -1588,7 +1579,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa_CUDAm(FN fn,Mat A,Ma
         mierr = magma_Cgesv_gpu(n,n,d_Maux,n,piv,d_RR,n,&info);CHKERRMAGMA(mierr);
         SlepcCheckLapackInfo("gesv",info);
         cberr = cublasXCaxpy(cublasv2handle,n2,&cone,d_RR,one,d_expmA,one);CHKERRCUBLAS(cberr);
-        ierr = SlepcLogFlopsComplex(1.0*n+(2.0*n*n*n/3.0+2.0*n*n*n)+1.0*n2);CHKERRQ(ierr);
+        ierr = SlepcLogGpuFlopsComplex(1.0*n+(2.0*n*n*n/3.0+2.0*n*n*n)+1.0*n2);CHKERRQ(ierr);
       }
     }
     for (i=0;i<iremainsize;i++) {
@@ -1600,13 +1591,13 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa_CUDAm(FN fn,Mat A,Ma
         for (j=1;j<i;j++) {
           cberr = cublasXCgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n,n,n,&cone,d_RR,n,d_RR,n,&czero,d_Maux,n);CHKERRCUBLAS(cberr);
           SWAP(d_RR,d_Maux,aux);
-          ierr = SlepcLogFlopsComplex(2.0*n*n*n);CHKERRQ(ierr);
+          ierr = SlepcLogGpuFlopsComplex(2.0*n*n*n);CHKERRQ(ierr);
         }
         cberr = cublasXCscal(cublasv2handle,n2,&remainterm[iremainsize-1-i],d_RR,one);CHKERRCUBLAS(cberr);
-        ierr = SlepcLogFlopsComplex(1.0*n2);CHKERRQ(ierr);
+        ierr = SlepcLogGpuFlopsComplex(1.0*n2);CHKERRQ(ierr);
       }
       cberr = cublasXCaxpy(cublasv2handle,n2,&cone,d_RR,one,d_expmA,one);CHKERRCUBLAS(cberr);
-      ierr = SlepcLogFlopsComplex(1.0*n2);CHKERRQ(ierr);
+      ierr = SlepcLogGpuFlopsComplex(1.0*n2);CHKERRQ(ierr);
     }
     ierr = PetscFree3(r,p,remainterm);CHKERRQ(ierr);
   } else { /* product form, default */
@@ -1629,7 +1620,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa_CUDAm(FN fn,Mat A,Ma
       mierr = magma_Cgesv_gpu(n,n,d_RR,n,piv,d_expmA,n,&info);CHKERRMAGMA(mierr);
       SlepcCheckLapackInfo("gesv",info);
       /* shift(n) + gemm + shift(n) + gesv */
-      ierr = SlepcLogFlopsComplex(1.0*n+(2.0*n*n*n)+1.0*n+(2.0*n*n*n/3.0+2.0*n*n*n));CHKERRQ(ierr);
+      ierr = SlepcLogGpuFlopsComplex(1.0*n+(2.0*n*n*n)+1.0*n+(2.0*n*n*n/3.0+2.0*n*n*n));CHKERRQ(ierr);
     }
     /* extra enumerator */
     for (i=minlen;i<irsize;i++) {
@@ -1637,7 +1628,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa_CUDAm(FN fn,Mat A,Ma
       ierr = shift_Cdiagonal(n,d_RR,n,-PetscRealPartComplex(rootp[i]),-PetscImaginaryPartComplex(rootp[i]));CHKERRQ(ierr);
       cberr = cublasXCgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n,n,n,&cone,d_RR,n,d_expmA,n,&czero,d_Maux,n);CHKERRCUBLAS(cberr);
       SWAP(d_expmA,d_Maux,aux);
-      ierr = SlepcLogFlopsComplex(1.0*n+2.0*n*n*n);CHKERRQ(ierr);
+      ierr = SlepcLogGpuFlopsComplex(1.0*n+2.0*n*n*n);CHKERRQ(ierr);
     }
     /* extra denominator */
     for (i=minlen;i<ipsize;i++) {
@@ -1645,10 +1636,10 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa_CUDAm(FN fn,Mat A,Ma
       ierr = shift_Cdiagonal(n,d_RR,n,-PetscRealPartComplex(rootq[i]),-PetscImaginaryPartComplex(rootq[i]));CHKERRQ(ierr);
       mierr = magma_Cgesv_gpu(n,n,d_RR,n,piv,d_expmA,n,&info);CHKERRMAGMA(mierr);
       SlepcCheckLapackInfo("gesv",info);
-      ierr = SlepcLogFlopsComplex(1.0*n+(2.0*n*n*n/3.0+2.0*n*n*n));CHKERRQ(ierr);
+      ierr = SlepcLogGpuFlopsComplex(1.0*n+(2.0*n*n*n/3.0+2.0*n*n*n));CHKERRQ(ierr);
     }
     cberr = cublasXCscal(cublasv2handle,n2,&mult,d_expmA,one);CHKERRCUBLAS(cberr);
-    ierr = SlepcLogFlopsComplex(1.0*n2);CHKERRQ(ierr);
+    ierr = SlepcLogGpuFlopsComplex(1.0*n2);CHKERRQ(ierr);
     ierr = PetscFree2(rootp,rootq);CHKERRQ(ierr);
   }
 
@@ -1662,7 +1653,7 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa_CUDAm(FN fn,Mat A,Ma
   for (i=0;i<s;i++) { /* final squaring */
     cberr = cublasXgemm(cublasv2handle,CUBLAS_OP_N,CUBLAS_OP_N,n,n,n,&sone,d_Ba2,n,d_Ba2,n,&szero,d_sMaux,n);CHKERRCUBLAS(cberr);
     SWAP(d_Ba2,d_sMaux,saux);
-    ierr = PetscLogFlops(2.0*n*n*n);CHKERRQ(ierr);
+    ierr = PetscLogGpuFlops(2.0*n*n*n);CHKERRQ(ierr);
   }
   if (d_Ba2!=d_Ba) {
     cerr = cudaMemcpy(d_Ba,d_Ba2,sizeof(PetscScalar)*n2,cudaMemcpyDeviceToDevice);CHKERRCUDA(cerr);
@@ -1671,19 +1662,21 @@ PetscErrorCode FNEvaluateFunctionMat_Exp_GuettelNakatsukasa_CUDAm(FN fn,Mat A,Ma
   if (shift) {
     expshift = PetscExpReal(shift);
     cberr = cublasXscal(cublasv2handle,n2,&expshift,d_Ba,one);CHKERRCUBLAS(cberr);
-    ierr = PetscLogFlops(1.0*n2);CHKERRQ(ierr);
+    ierr = PetscLogGpuFlops(1.0*n2);CHKERRQ(ierr);
   }
 
   cerr = cudaMemcpy(Ba,d_Ba,sizeof(PetscScalar)*n2,cudaMemcpyDeviceToHost);CHKERRCUDA(cerr);
+  ierr = PetscLogGpuTimeEnd();CHKERRQ(ierr);
 
   /* restore pointers */
   d_Maux = d_Maux2; d_expmA = d_expmA2; d_RR = d_RR2;
+  cerr = cudaFree(d_Ba);CHKERRCUDA(cerr);
   cerr = cudaFree(d_isreal);CHKERRCUDA(cerr);
+  cerr = cudaFree(d_sMaux);CHKERRCUDA(cerr);
   cerr = cudaFree(d_Maux);CHKERRCUDA(cerr);
+  cerr = cudaFree(d_expmA);CHKERRCUDA(cerr);
   cerr = cudaFree(d_As);CHKERRCUDA(cerr);
   cerr = cudaFree(d_RR);CHKERRCUDA(cerr);
-  cerr = cudaFree(d_expmA);CHKERRCUDA(cerr);
-  cerr = cudaFree(d_Ba);CHKERRCUDA(cerr);
   ierr = PetscFree(piv);CHKERRQ(ierr);
   ierr = PetscFree2(sMaux,Maux);CHKERRQ(ierr);
   ierr = MatDenseRestoreArray(A,&Aa);CHKERRQ(ierr);
