@@ -211,7 +211,7 @@ PetscErrorCode FNGetOptionsPrefix(FN fn,const char *prefix[])
 
    Logically Collective on fn
 
-   Input Parameter:
+   Input Parameters:
 +  fn   - the math function context
 -  type - a known type
 
@@ -299,7 +299,7 @@ PetscErrorCode FNSetScale(FN fn,PetscScalar alpha,PetscScalar beta)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
   PetscValidLogicalCollectiveScalar(fn,alpha,2);
-  PetscValidLogicalCollectiveScalar(fn,beta,2);
+  PetscValidLogicalCollectiveScalar(fn,beta,3);
   if (PetscAbsScalar(alpha)==0.0 || PetscAbsScalar(beta)==0.0) SETERRQ(PetscObjectComm((PetscObject)fn),PETSC_ERR_ARG_WRONG,"Scaling factors must be nonzero");
   fn->alpha = alpha;
   fn->beta  = beta;
@@ -336,9 +336,9 @@ PetscErrorCode FNGetScale(FN fn,PetscScalar *alpha,PetscScalar *beta)
 
    Logically Collective on fn
 
-   Input Parameter:
+   Input Parameters:
 +  fn   - the math function context
--  meth - an index indentifying the method
+-  meth - an index identifying the method
 
    Options Database Key:
 .  -fn_method <meth> - Sets the method
@@ -395,7 +395,7 @@ PetscErrorCode FNGetMethod(FN fn,PetscInt *meth)
 
    Logically Collective on fn
 
-   Input Parameter:
+   Input Parameters:
 +  fn    - the math function context
 -  pmode - the parallel mode
 
