@@ -47,8 +47,10 @@ static PetscErrorCode RGIntervalSetEndpoints_Interval(RG rg,PetscReal a,PetscRea
 
    Input Parameters:
 +  rg  - the region context
-.  a,b - endpoints of the interval in the real axis
--  c,d - endpoints of the interval in the imaginary axis
+.  a - left endpoint of the interval in the real axis
+.  b - right endpoint of the interval in the real axis
+.  c - bottom endpoint of the interval in the imaginary axis
+-  d - top endpoint of the interval in the imaginary axis
 
    Options Database Keys:
 .  -rg_interval_endpoints - the four endpoints
@@ -100,8 +102,10 @@ static PetscErrorCode RGIntervalGetEndpoints_Interval(RG rg,PetscReal *a,PetscRe
 .  rg - the region context
 
    Output Parameters:
-+  a,b - endpoints of the interval in the real axis
--  c,d - endpoints of the interval in the imaginary axis
++  a - left endpoint of the interval in the real axis
+.  b - right endpoint of the interval in the real axis
+.  c - bottom endpoint of the interval in the imaginary axis
+-  d - top endpoint of the interval in the imaginary axis
 
    Level: advanced
 
@@ -173,47 +177,62 @@ PetscErrorCode RGIsTrivial_Interval(RG rg,PetscBool *trivial)
 PetscErrorCode RGComputeContour_Interval(RG rg,PetscInt n,PetscScalar *cr,PetscScalar *ci)
 {
   RG_INTERVAL *ctx = (RG_INTERVAL*)rg->data;
-  PetscInt    i,pt,idx,j;
-  PetscReal   hr[4],hi[4],h,off,d[4],vr[4],vi[4];
+  PetscInt    i,N,Nv,Nh,k1,k0;
+  PetscReal   hv,hh,t;
 
   PetscFunctionBegin;
   if (!(ctx->a>-PETSC_MAX_REAL && ctx->b<PETSC_MAX_REAL && ctx->c>-PETSC_MAX_REAL && ctx->d<PETSC_MAX_REAL)) SETERRQ(PetscObjectComm((PetscObject)rg),PETSC_ERR_SUP,"Contour not defined in unbounded regions");
   if (ctx->a==ctx->b || ctx->c==ctx->d) {
-    if (ctx->a==ctx->b) {hi[0] = (ctx->d-ctx->c)/(n-1); hr[0] = 0.0;}
-    else {hr[0] = (ctx->b-ctx->a)/(n-1); hi[0] = 0.0;}
+    if (ctx->a==ctx->b) {hv = (ctx->d-ctx->c)/(n-1); hh = 0.0;}
+    else {hh = (ctx->b-ctx->a)/(n-1); hv = 0.0;}
     for (i=0;i<n;i++) {
 #if defined(PETSC_USE_COMPLEX)
-      cr[i] = PetscCMPLX(ctx->a+hr[0]*i,ctx->c+hi[0]*i);
+      cr[i] = PetscCMPLX(ctx->a+hh*i,ctx->c+hv*i);
 #else
-      cr[i] = ctx->a+hr[0]*i; ci[i] = ctx->c+hi[0]*i;
+      if (cr) cr[i] = ctx->a+hh*i;
+      if (ci) ci[i] = ctx->c+hv*i;
 #endif
     }
   } else {
-    d[1] = d[3] = ctx->d-ctx->c; d[0] = d[2] = ctx->b-ctx->a;
-    h = 2.0*(d[0]+d[1])/n;
-    vr[0] = ctx->a; vr[1] = ctx->b; vr[2] = ctx->b; vr[3] = ctx->a;
-    vi[0] = ctx->c; vi[1] = ctx->c; vi[2] = ctx->d; vi[3] = ctx->d;
-    hr[0] = h;   hr[1] = 0.0; hr[2] = -h;  hr[3] = 0.0;
-    hi[0] = 0.0; hi[1] = h;   hi[2] = 0.0; hi[3] = -h;
-    off = 0.0; idx = 0;
-    for (i=0;i<4;i++) {
+    if (n<4) SETERRQ(PetscObjectComm((PetscObject)rg),PETSC_ERR_SUP,"Minimum number of contour points: 4");
+    N = n/2;
+    t = ((ctx->d-ctx->c)/(ctx->d-ctx->c+ctx->b-ctx->a))*N;
+    Nv = t-PetscFloorReal(t)>0.5?PetscCeilReal(t):PetscFloorReal(t);
+    if (Nv==0) Nv++;
+    else if (Nv==N) Nv--;
+    Nh = N-Nv;
+    hh = (ctx->b-ctx->a)/Nh;
+    hv = (ctx->d-ctx->c)/Nv;
+    /* positive imaginary part first */
+    k1 = Nv/2+1;
+    k0 = Nv-k1;
+
+    for (i=k1;i<Nv;i++) {
 #if defined(PETSC_USE_COMPLEX)
-      cr[idx] = PetscCMPLX(vr[i]+off*(hr[i]/h),vi[i]+off*(hi[i]/h));
+      cr[i-k1]   = PetscCMPLX(ctx->b,ctx->c+i*hv);
+      cr[i-k1+N] = PetscCMPLX(ctx->a,ctx->d-i*hv);
 #else
-      cr[idx] = vr[i]+off*(hr[i]/h); ci[idx] = vi[i]+off*(hi[i]/h);
+      if (cr) {cr[i-k1] = ctx->b;      cr[i-k1+N] = ctx->a;}
+      if (ci) {ci[i-k1] = ctx->c+i*hv; ci[i-k1+N] = ctx->d-i*hv;}
 #endif
-      idx++;
-      pt = (PetscInt)((d[i]-off)/h)+1;
-      for (j=1;j<pt && idx<n;j++) {
+    }
+    for (i=0;i<Nh;i++) {
 #if defined(PETSC_USE_COMPLEX)
-        cr[idx] = cr[idx-1]+PetscCMPLX(hr[i],hi[i]);
+      cr[i+k0]   = PetscCMPLX(ctx->b-i*hh,ctx->d);
+      cr[i+k0+N] = PetscCMPLX(ctx->a+i*hh,ctx->c);
 #else
-        cr[idx] = cr[idx-1]+hr[i]; ci[idx] = ci[idx-1]+hi[i];
+      if (cr) {cr[i+k0] = ctx->b-i*hh; cr[i+k0+N] = ctx->a+i*hh;}
+      if (ci) {ci[i+k0] = ctx->d;      ci[i+k0+N] = ctx->c;}
+#endif
+    }
+    for (i=0;i<k1;i++) {
+#if defined(PETSC_USE_COMPLEX)
+      cr[i+k0+Nh]   = PetscCMPLX(ctx->a,ctx->d-i*hv);
+      cr[i+k0+Nh+N] = PetscCMPLX(ctx->b,ctx->c+i*hv);
+#else
+      if (cr) {cr[i+k0+Nh] = ctx->a; cr[i+k0+Nh+N] = ctx->b;}
+      if (ci) {ci[i+k0+Nh] = ctx->d+i*hv; ci[i+k0+Nh+N] = ctx->c-i*hv;}
 #endif
-        idx++;
-      }
-      off += pt*h-d[i];
-      if (off>=d[i+1]) {off -= d[i+1]; i++;}
     }
   }
   PetscFunctionReturn(0);
@@ -231,6 +250,51 @@ PetscErrorCode RGComputeBoundingBox_Interval(RG rg,PetscReal *a,PetscReal *b,Pet
   PetscFunctionReturn(0);
 }
 
+PetscErrorCode RGComputeQuadrature_Interval(RG rg,RGQuadRule quad,PetscInt n,PetscScalar *z,PetscScalar *zn,PetscScalar *w)
+{
+  RG_INTERVAL *ctx = (RG_INTERVAL*)rg->data;
+  PetscReal   theta,max_w=0.0,radius=1.0;
+  PetscScalar tmp,tmp2,center=0.0;
+  PetscInt    i,j;
+
+  PetscFunctionBegin;
+  if (quad == RG_QUADRULE_CHEBYSHEV) {
+    if ((ctx->c!=ctx->d || ctx->c!=0.0) && (ctx->a!=ctx->b || ctx->a!=0.0)) SETERRQ(PetscObjectComm((PetscObject)rg),PETSC_ERR_SUP,"Endpoints of the imaginary axis or the real axis must be both zero");
+    for (i=0;i<n;i++) {
+      theta = PETSC_PI*(i+0.5)/n;
+      zn[i] = PetscCosReal(theta);
+      w[i]  = PetscCosReal((n-1)*theta)/n;
+      if (ctx->c==ctx->d) z[i] = ((ctx->b-ctx->a)*(zn[i]+1.0)/2.0+ctx->a)*rg->sfactor;
+      else if (ctx->a==ctx->b) {
+#if defined(PETSC_USE_COMPLEX)
+        z[i] = ((ctx->d-ctx->c)*(zn[i]+1.0)/2.0+ctx->c)*rg->sfactor*PETSC_i;
+#else
+        SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"Integration points on a vertical line require complex arithmetic");
+#endif
+      }
+    }
+  } else {  /* RG_QUADRULE_TRAPEZOIDAL */
+#if defined(PETSC_USE_COMPLEX)
+    center = rg->sfactor*PetscCMPLX(ctx->b+ctx->a,ctx->d+ctx->c)/2.0;
+#else
+    center = rg->sfactor*(ctx->b+ctx->a)/2.0;
+#endif
+    radius = PetscSqrtReal(PetscPowRealInt(rg->sfactor*(ctx->b-ctx->a)/2.0,2)+PetscPowRealInt(rg->sfactor*(ctx->d-ctx->c)/2.0,2));
+    for (i=0;i<n;i++) {
+      zn[i] = (z[i]-center)/radius;
+      tmp = 1.0; tmp2 = 1.0;
+      for (j=0;j<n;j++) {
+        tmp *= z[j];
+        if (i != j) tmp2 *= z[j]-z[i];
+      }
+      w[i] = tmp/tmp2;
+      max_w = PetscMax(PetscAbsScalar(w[i]),max_w);
+    }
+    for (i=0;i<n;i++) w[i] /= (PetscScalar)max_w;
+  }
+  PetscFunctionReturn(0);
+}
+
 PetscErrorCode RGCheckInside_Interval(RG rg,PetscReal dx,PetscReal dy,PetscInt *inside)
 {
   RG_INTERVAL *ctx = (RG_INTERVAL*)rg->data;
@@ -247,6 +311,16 @@ PetscErrorCode RGCheckInside_Interval(RG rg,PetscReal dx,PetscReal dy,PetscInt *
   PetscFunctionReturn(0);
 }
 
+PetscErrorCode RGIsAxisymmetric_Interval(RG rg,PetscBool vertical,PetscBool *symm)
+{
+  RG_INTERVAL *ctx = (RG_INTERVAL*)rg->data;
+
+  PetscFunctionBegin;
+  if (vertical) *symm = (ctx->a == -ctx->b)? PETSC_TRUE: PETSC_FALSE;
+  else *symm = (ctx->c == -ctx->d)? PETSC_TRUE: PETSC_FALSE;
+  PetscFunctionReturn(0);
+}
+
 PetscErrorCode RGSetFromOptions_Interval(PetscOptionItems *PetscOptionsObject,RG rg)
 {
   PetscErrorCode ierr;
@@ -292,13 +366,15 @@ SLEPC_EXTERN PetscErrorCode RGCreate_Interval(RG rg)
   interval->d = PETSC_MAX_REAL;
   rg->data = (void*)interval;
 
-  rg->ops->istrivial      = RGIsTrivial_Interval;
-  rg->ops->computecontour = RGComputeContour_Interval;
-  rg->ops->computebbox    = RGComputeBoundingBox_Interval;
-  rg->ops->checkinside    = RGCheckInside_Interval;
-  rg->ops->setfromoptions = RGSetFromOptions_Interval;
-  rg->ops->view           = RGView_Interval;
-  rg->ops->destroy        = RGDestroy_Interval;
+  rg->ops->istrivial         = RGIsTrivial_Interval;
+  rg->ops->computecontour    = RGComputeContour_Interval;
+  rg->ops->computebbox       = RGComputeBoundingBox_Interval;
+  rg->ops->computequadrature = RGComputeQuadrature_Interval;
+  rg->ops->checkinside       = RGCheckInside_Interval;
+  rg->ops->isaxisymmetric    = RGIsAxisymmetric_Interval;
+  rg->ops->setfromoptions    = RGSetFromOptions_Interval;
+  rg->ops->view              = RGView_Interval;
+  rg->ops->destroy           = RGDestroy_Interval;
   ierr = PetscObjectComposeFunction((PetscObject)rg,"RGIntervalSetEndpoints_C",RGIntervalSetEndpoints_Interval);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)rg,"RGIntervalGetEndpoints_C",RGIntervalGetEndpoints_Interval);CHKERRQ(ierr);
   PetscFunctionReturn(0);
