@@ -12,6 +12,9 @@ static char help[] = "Test RG interface functions.\n\n";
 
 #include <slepcrg.h>
 
+#define NPOINTS 10
+#define NVERTEX 7
+
 int main(int argc,char **argv)
 {
   PetscErrorCode ierr;
@@ -19,7 +22,7 @@ int main(int argc,char **argv)
   PetscInt       i,inside,nv;
   PetscBool      triv;
   PetscReal      re,im,a,b,c,d;
-  PetscScalar    ar,ai,cr[10],ci[10],vr[7],vi[7],*pr,*pi;
+  PetscScalar    ar,ai,cr[NPOINTS],ci[NPOINTS],vr[NVERTEX],vi[NVERTEX],*pr,*pi;
 
   ierr = SlepcInitialize(&argc,&argv,(char*)0,help);if (ierr) return ierr;
   ierr = RGCreate(PETSC_COMM_WORLD,&rg);CHKERRQ(ierr);
@@ -27,11 +30,11 @@ int main(int argc,char **argv)
   /* ellipse */
   ierr = RGSetType(rg,RGELLIPSE);CHKERRQ(ierr);
   ierr = RGIsTrivial(rg,&triv);CHKERRQ(ierr);
-  if (!triv) SETERRQ(PETSC_COMM_WORLD,1,"Region should be trivial before setting parameters");
+  if (!triv) SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_PLIB,"Region should be trivial before setting parameters");
   ierr = RGEllipseSetParameters(rg,1.1,2,0.1);CHKERRQ(ierr);
   ierr = RGSetFromOptions(rg);CHKERRQ(ierr);
   ierr = RGIsTrivial(rg,&triv);CHKERRQ(ierr);
-  if (triv) SETERRQ(PETSC_COMM_WORLD,1,"Region should be non-trivial after setting parameters");
+  if (triv) SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_PLIB,"Region should be non-trivial after setting parameters");
   ierr = RGView(rg,NULL);CHKERRQ(ierr);
   ierr = RGViewFromOptions(rg,NULL,"-rg_ellipse_view");CHKERRQ(ierr);
   re = 0.1; im = 0.3;
@@ -47,8 +50,8 @@ int main(int argc,char **argv)
   ierr = PetscPrintf(PETSC_COMM_WORLD,"The bounding box is [%g,%g]x[%g,%g]\n",(double)a,(double)b,(double)c,(double)d);
 
   ierr = PetscPrintf(PETSC_COMM_WORLD,"Contour points: ");
-  ierr = RGComputeContour(rg,10,cr,ci);CHKERRQ(ierr);
-  for (i=0;i<10;i++) {
+  ierr = RGComputeContour(rg,NPOINTS,cr,ci);CHKERRQ(ierr);
+  for (i=0;i<NPOINTS;i++) {
 #if defined(PETSC_USE_COMPLEX)
     re = PetscRealPart(cr[i]);
     im = PetscImaginaryPart(cr[i]);
@@ -63,11 +66,11 @@ int main(int argc,char **argv)
   /* interval */
   ierr = RGSetType(rg,RGINTERVAL);CHKERRQ(ierr);
   ierr = RGIsTrivial(rg,&triv);CHKERRQ(ierr);
-  if (!triv) SETERRQ(PETSC_COMM_WORLD,1,"Region should be trivial before setting parameters");
+  if (!triv) SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_PLIB,"Region should be trivial before setting parameters");
   ierr = RGIntervalSetEndpoints(rg,-1,1,-0.1,0.1);CHKERRQ(ierr);
   ierr = RGSetFromOptions(rg);CHKERRQ(ierr);
   ierr = RGIsTrivial(rg,&triv);CHKERRQ(ierr);
-  if (triv) SETERRQ(PETSC_COMM_WORLD,1,"Region should be non-trivial after setting parameters");
+  if (triv) SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_PLIB,"Region should be non-trivial after setting parameters");
   ierr = RGView(rg,NULL);CHKERRQ(ierr);
   ierr = RGViewFromOptions(rg,NULL,"-rg_interval_view");CHKERRQ(ierr);
   re = 0.2; im = 0;
@@ -83,8 +86,8 @@ int main(int argc,char **argv)
   ierr = PetscPrintf(PETSC_COMM_WORLD,"The bounding box is [%g,%g]x[%g,%g]\n",(double)a,(double)b,(double)c,(double)d);
 
   ierr = PetscPrintf(PETSC_COMM_WORLD,"Contour points: ");
-  ierr = RGComputeContour(rg,10,cr,ci);CHKERRQ(ierr);
-  for (i=0;i<10;i++) {
+  ierr = RGComputeContour(rg,NPOINTS,cr,ci);CHKERRQ(ierr);
+  for (i=0;i<NPOINTS;i++) {
 #if defined(PETSC_USE_COMPLEX)
     re = PetscRealPart(cr[i]);
     im = PetscImaginaryPart(cr[i]);
@@ -116,11 +119,11 @@ int main(int argc,char **argv)
 #endif
   ierr = RGSetType(rg,RGPOLYGON);CHKERRQ(ierr);
   ierr = RGIsTrivial(rg,&triv);CHKERRQ(ierr);
-  if (!triv) SETERRQ(PETSC_COMM_WORLD,1,"Region should be trivial before setting parameters");
-  ierr = RGPolygonSetVertices(rg,7,vr,vi);CHKERRQ(ierr);
+  if (!triv) SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_PLIB,"Region should be trivial before setting parameters");
+  ierr = RGPolygonSetVertices(rg,NVERTEX,vr,vi);CHKERRQ(ierr);
   ierr = RGSetFromOptions(rg);CHKERRQ(ierr);
   ierr = RGIsTrivial(rg,&triv);CHKERRQ(ierr);
-  if (triv) SETERRQ(PETSC_COMM_WORLD,1,"Region should be non-trivial after setting parameters");
+  if (triv) SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_PLIB,"Region should be non-trivial after setting parameters");
   ierr = RGView(rg,NULL);CHKERRQ(ierr);
   ierr = RGViewFromOptions(rg,NULL,"-rg_polygon_view");CHKERRQ(ierr);
   re = 5; im = 0.9;
@@ -136,8 +139,8 @@ int main(int argc,char **argv)
   ierr = PetscPrintf(PETSC_COMM_WORLD,"The bounding box is [%g,%g]x[%g,%g]\n",(double)a,(double)b,(double)c,(double)d);
 
   ierr = PetscPrintf(PETSC_COMM_WORLD,"Contour points: ");
-  ierr = RGComputeContour(rg,10,cr,ci);CHKERRQ(ierr);
-  for (i=0;i<10;i++) {
+  ierr = RGComputeContour(rg,NPOINTS,cr,ci);CHKERRQ(ierr);
+  for (i=0;i<NPOINTS;i++) {
 #if defined(PETSC_USE_COMPLEX)
     re = PetscRealPart(cr[i]);
     im = PetscImaginaryPart(cr[i]);
@@ -151,14 +154,14 @@ int main(int argc,char **argv)
 
   /* check vertices */
   ierr = RGPolygonGetVertices(rg,&nv,&pr,&pi);CHKERRQ(ierr);
-  if (nv!=7) SETERRQ1(PETSC_COMM_WORLD,1,"Wrong number of vertices: %D",nv);
+  if (nv!=NVERTEX) SETERRQ1(PETSC_COMM_WORLD,PETSC_ERR_PLIB,"Wrong number of vertices: %D",nv);
   for (i=0;i<nv;i++) {
 #if !defined(PETSC_USE_COMPLEX)
     if (pr[i]!=vr[i] || pi[i]!=vi[i])
 #else
     if (pr[i]!=vr[i])
 #endif
-       SETERRQ1(PETSC_COMM_WORLD,1,"Vertex number %D does not match",i);
+       SETERRQ1(PETSC_COMM_WORLD,PETSC_ERR_PLIB,"Vertex number %D does not match",i);
   }
 
   ierr = PetscFree(pr);CHKERRQ(ierr);
