@@ -39,7 +39,7 @@ typedef struct {
 
 .seealso: STShellSetContext()
 @*/
-PetscErrorCode STShellGetContext(ST st,void **ctx)
+PetscErrorCode STShellGetContext(ST st,void *ctx)
 {
   PetscErrorCode ierr;
   PetscBool      flg;
@@ -48,8 +48,8 @@ PetscErrorCode STShellGetContext(ST st,void **ctx)
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidPointer(ctx,2);
   ierr = PetscObjectTypeCompare((PetscObject)st,STSHELL,&flg);CHKERRQ(ierr);
-  if (!flg) *ctx = 0;
-  else      *ctx = ((ST_SHELL*)(st->data))->ctx;
+  if (!flg) *(void**)ctx = NULL;
+  else      *(void**)ctx = ((ST_SHELL*)(st->data))->ctx;
   PetscFunctionReturn(0);
 }
 
@@ -276,13 +276,13 @@ PetscErrorCode STShellSetBackTransform(ST st,PetscErrorCode (*backtr)(ST,PetscIn
 }
 
 /*MC
-   STSHELL - Creates a new spectral transformation class.
-          This is intended to provide a simple class to use with EPS.
-          You should not use this if you plan to make a complete class.
+   STSHELL - User-defined spectral transformation via callback functions
+   for the application of the operator to a vector and (optionally) the
+   backtransform operation.
 
-  Level: advanced
+   Level: advanced
 
-  Usage:
+   Usage:
 $             extern PetscErrorCode (*apply)(void*,Vec,Vec);
 $             extern PetscErrorCode (*applytrans)(void*,Vec,Vec);
 $             extern PetscErrorCode (*backtr)(void*,PetscScalar*,PetscScalar*);
