@@ -14,9 +14,11 @@
 #if defined(PETSC_HAVE_FORTRAN_CAPS)
 #define slepcgetversion_              SLEPCGETVERSION
 #define slepcgetversionnumber_        SLEPCGETVERSIONNUMBER
+#define slepchasexternalpackage_      SLEPCHASEXTERNALPACKAGE
 #elif !defined(PETSC_HAVE_FORTRAN_UNDERSCORE)
 #define slepcgetversion_              slepcgetversion
 #define slepcgetversionnumber_        slepcgetversionnumber
+#define slepchasexternalpackage_      slepchasexternalpackage
 #endif
 
 SLEPC_EXTERN void slepcgetversion_(char *version,PetscErrorCode *ierr,PETSC_FORTRAN_CHARLEN_T len1)
@@ -25,7 +27,7 @@ SLEPC_EXTERN void slepcgetversion_(char *version,PetscErrorCode *ierr,PETSC_FORT
   FIXRETURNCHAR(PETSC_TRUE,version,len1);
 }
 
-SLEPC_EXTERN void slepcgetversionnumber_(PetscInt *major,PetscInt *minor,PetscInt *subminor,PetscInt *release,PetscInt *ierr)
+SLEPC_EXTERN void slepcgetversionnumber_(PetscInt *major,PetscInt *minor,PetscInt *subminor,PetscInt *release,PetscErrorCode *ierr)
 {
   CHKFORTRANNULLINTEGER(major);
   CHKFORTRANNULLINTEGER(minor);
@@ -34,3 +36,12 @@ SLEPC_EXTERN void slepcgetversionnumber_(PetscInt *major,PetscInt *minor,PetscIn
   *ierr = SlepcGetVersionNumber(major,minor,subminor,release);
 }
 
+SLEPC_EXTERN void slepchasexternalpackage_(char* pkg,PetscBool *has,PetscErrorCode *ierr,PETSC_FORTRAN_CHARLEN_T len)
+{
+  char *t1;
+
+  FIXCHAR(pkg,len,t1);
+  *ierr = SlepcHasExternalPackage(t1,has);if (*ierr) return;
+  FREECHAR(pkg,t1);
+}
+
