@@ -27,7 +27,7 @@ SLEPC_EXTERN PetscErrorCode PCCreate_HPDDM(PC);
     Output Parameter:
 .   version - version string
 
-    Level: developer
+    Level: intermediate
 
 .seealso: SlepcGetVersionNumber()
 @*/
@@ -64,7 +64,7 @@ PetscErrorCode SlepcGetVersion(char version[],size_t len)
 
     This function can be called before SlepcInitialize().
 
-    Level: developer
+    Level: intermediate
 
 .seealso: SlepcGetVersion(), SlepcInitialize()
 @*/
@@ -117,8 +117,9 @@ static PetscErrorCode SlepcPrintHelpIntro(MPI_Comm comm)
    Indicates whether SLEPc started PETSc, or whether it was
    already started before SLEPc was initialized.
 */
-PetscBool SlepcBeganPetsc = PETSC_FALSE;
+PetscBool SlepcBeganPetsc       = PETSC_FALSE;
 PetscBool SlepcInitializeCalled = PETSC_FALSE;
+PetscBool SlepcFinalizeCalled   = PETSC_FALSE;
 
 #if defined(PETSC_HAVE_DYNAMIC_LIBRARIES) && defined(PETSC_USE_SHARED_LIBRARIES)
 static PetscErrorCode SlepcLoadDynamicLibrary(const char *name,PetscBool *found)
@@ -234,7 +235,7 @@ PetscErrorCode SlepcCitationsInitialize()
   ierr = PetscCitationsRegister("@TechReport{slepc-manual,\n"
     "   author = \"J. E. Roman and C. Campos and L. Dalcin and E. Romero and A. Tomas\",\n"
     "   title = \"{SLEPc} Users Manual\",\n"
-    "   number = \"DSIC-II/24/02 - Revision 3.15\",\n"
+    "   number = \"DSIC-II/24/02 - Revision 3.16\",\n"
     "   institution = \"D. Sistemes Inform\\`atics i Computaci\\'o, Universitat Polit\\`ecnica de Val\\`encia\",\n"
     "   year = \"2021\"\n"
     "}\n",NULL);CHKERRQ(ierr);
@@ -267,10 +268,9 @@ PetscErrorCode SlepcInitialize(int *argc,char ***args,const char file[],const ch
   PetscErrorCode ierr;
   PetscBool      flg;
 
-  PetscFunctionBegin;
-  if (SlepcInitializeCalled) PetscFunctionReturn(0);
-  ierr = PetscSetHelpVersionFunctions(SlepcPrintHelpIntro,SlepcPrintVersion);CHKERRQ(ierr);
-  ierr = PetscInitialized(&flg);CHKERRQ(ierr);
+  if (SlepcInitializeCalled) return 0;
+  ierr = PetscSetHelpVersionFunctions(SlepcPrintHelpIntro,SlepcPrintVersion);if (ierr) return ierr;
+  ierr = PetscInitialized(&flg);if (ierr) return ierr;
   if (!flg) {
     ierr = PetscInitialize(argc,args,file,help);CHKERRQ(ierr);
     SlepcBeganPetsc = PETSC_TRUE;
@@ -282,8 +282,9 @@ PetscErrorCode SlepcInitialize(int *argc,char ***args,const char file[],const ch
   ierr = SlepcInitialize_DynamicLibraries();CHKERRQ(ierr);
 
   SlepcInitializeCalled = PETSC_TRUE;
+  SlepcFinalizeCalled   = PETSC_FALSE;
   ierr = PetscInfo(0,"SLEPc successfully started\n");CHKERRQ(ierr);
-  PetscFunctionReturn(0);
+  return 0;
 }
 
 /*@C
@@ -301,12 +302,21 @@ PetscErrorCode SlepcFinalize(void)
   PetscErrorCode ierr = 0;
 
   PetscFunctionBegin;
-  ierr = PetscInfo(0,"SlepcFinalize() called\n");CHKERRQ(ierr);
+  if (PetscUnlikely(!SlepcInitializeCalled)) {
+    fprintf(PETSC_STDOUT,"SlepcInitialize() must be called before SlepcFinalize()\n");
+    PetscStackClearTop;
+    return PETSC_ERR_ARG_WRONGSTATE;
+  }
+  ierr = PetscInfo(NULL,"SlepcFinalize() called\n");CHKERRQ(ierr);
   if (SlepcBeganPetsc) {
     ierr = PetscFinalize();
+    SlepcBeganPetsc = PETSC_FALSE;
   }
   SlepcInitializeCalled = PETSC_FALSE;
-  PetscFunctionReturn(ierr);
+  SlepcFinalizeCalled   = PETSC_TRUE;
+  /* To match PetscFunctionBegin() at the beginning of this function */
+  PetscStackClearTop;
+  return ierr;
 }
 
 /*@C
@@ -340,11 +350,24 @@ PetscErrorCode SlepcInitializeNoArguments(void)
 PetscErrorCode SlepcInitialized(PetscBool *isInitialized)
 {
   PetscFunctionBegin;
-  PetscValidBoolPointer(isInitialized,1);
   *isInitialized = SlepcInitializeCalled;
   PetscFunctionReturn(0);
 }
 
+/*@
+   SlepcFinalized - Determine whether SlepcFinalize() has been called.
+
+   Level: developer
+
+.seealso: SlepcFinalize()
+@*/
+PetscErrorCode SlepcFinalized(PetscBool *isFinalized)
+{
+  PetscFunctionBegin;
+  *isFinalized = SlepcFinalizeCalled;
+  PetscFunctionReturn(0);
+}
+
 PETSC_EXTERN PetscBool PetscBeganMPI;
 
 /*
@@ -367,6 +390,6 @@ PetscErrorCode SlepcInitializeNoPointers(int argc,char **args,const char *filena
   ierr = SlepcInitialize(&myargc,&myargs,filename,help);CHKERRQ(ierr);
   ierr = PetscPopSignalHandler();CHKERRQ(ierr);
   PetscBeganMPI = PETSC_FALSE;
-  PetscFunctionReturn(ierr);
+  PetscFunctionReturn(0);
 }
 
